/* +--------------------------------------------------------------------------+
// � 2002-2004 PMB Services / www.sigb.net pmb@sigb.net et contributeurs (voir www.sigb.net)
// +-------------------------------------------------+
// $Id: navbar.css,v 1.22 2014-01-08 10:10:32 touraine37 Exp $ */

/* navbar : �cran de login */
#navbar-index{
	float:left;
	margin:0;
	margin-right:20px;
	padding:0px 0px 0px 14px;
	border-top:2px solid #765;
	border-left:2px solid #765;
	border-bottom:1px solid #A6DCDC;
	background: #A6DCDC;
	}
#navbar-index a {
	float:left;
	padding:5px 15px 2px 6px;
	border-right:2px solid #765;
	border-bottom:0px solid #765;
	height: 100%;
	text-decoration:none;
	}
#navbar-index.current {
	border-bottom:1px solid #A6DCDC;
	}
#navbar-index.current a {
	color: #000;
	border-bottom:0px ;
	padding-bottom:2px;
	}

#navbar-opac{
	float:left;
	margin:0;
	margin-right:20px;
	padding:0px 0px 0px 14px;
	border-top:2px solid #765;
	border-left:2px solid #765;
	border-bottom:1px solid #765;
	background: #DDF0A7;
	}
#navbar-opac a {
	float:left;
	padding:5px 15px 2px 6px;
	border-right:2px solid #765;
	border-bottom:0px solid #765;
	height: 100%;
	text-decoration:none;
	}
#navbar-opac.current {
	border-bottom:1px solid #F6DCDC;
	}
#navbar-opac.current a {
	color: #000;
	border-bottom:0px ;
	padding-bottom:2px;
	}


#navbar-circ {
	float:left;
	margin:0;
	margin-right:5px;
	padding:0px 0px 0px 10px;
	border-top:2px solid #765;
	border-left:2px solid #765;
	border-bottom:1px solid #765;
	background: #DDF0A7;
	}
#navbar-circ a {
	float:left;
	padding:5px 13px 2px 6px;
	border-right:2px solid #765;
	border-bottom:0px solid #765;
	height: 100%;
	text-decoration:none;
	}
#navbar-circ.current {
	border-bottom:1px solid #DDF0A7;
	}
#navbar-circ.current a {
	color: #000;
	border-bottom:0px ;
	padding-bottom:2px;	}


#navbar-catalog {
	float:left;
	margin:0;
	margin-right:5px;
	padding:0px 0px 0px 10px;
	border-top:2px solid #765;
	border-left:2px solid #765;
	border-bottom:1px solid #765;
	background: #FAF5BC;
	}
#navbar-catalog a {
	float:left;
	padding:5px 13px 2px 6px;
	border-right:2px solid #765;
	border-bottom:0px solid #765;
	height: 100%;
	text-decoration:none;
	}
#navbar-catalog.current {
	border-bottom:1px solid #FAF5BC;
	}
#navbar-catalog.current a {
	color: #000;
	border-bottom:0px ;
	padding-bottom:2px;	}


#navbar-autorites {
	float:left;
	margin:0;
	margin-right:5px;
	padding:0px 0px 0px 10px;
	border-top:2px solid #765;
	border-left:2px solid #765;
	border-bottom:1px solid #765;
	background: #E0D9FF;
	}
#navbar-autorites a {
	float:left;
	padding:5px 13px 2px 6px;
	border-right:2px solid #765;
	border-bottom:0px solid #765;
	height: 100%;
	text-decoration:none;
	}
#navbar-autorites.current {
	border-bottom:1px solid #E0D9FF;
	}
#navbar-autorites.current a {
	color: #000;
	border-bottom:0px ;
	padding-bottom:2px;	}


#navbar-edit {
	float:left;
	margin:0;
	margin-right:5px;
	padding:0px 0px 0px 10px;
	border-top:2px solid #765;
	border-left:2px solid #765;
	border-bottom:1px solid #765;
	background: #FEFFA3;
	}
#navbar-edit a {
	float:left;
	padding:5px 13px 2px 6px;
	border-right:2px solid #765;
	border-bottom:0px solid #765;
	height: 100%;
	text-decoration:none;
	}
#navbar-edit.current {
	border-bottom:1px solid #FEFFA3;	
	}
	
#navbar-edit.current a {
	color: #000;
	border-bottom:0px ;
	padding-bottom:2px;	}


#navbar-admin,#navbar-extensions {
	float:left;
	margin:0;
	margin-right:5px;
	padding:0px 0px 0px 10px;
	border-top:2px solid #765;
	border-left:2px solid #765;
	border-bottom:1px solid #765;
	background: #F6DCDC;
	}
#navbar-admin a,#navbar-extensions a {
	float:left;
	padding:5px 13px 2px 6px;
	border-right:2px solid #765;
	border-bottom:0px solid #765;
	height: 100%;
	text-decoration:none;
	}
#navbar-admin.current, #navbar-extensions.current {
	border-bottom:1px solid #F6DCDC;
	}
#navbar-admin.current a, #navbar-extensions.current a {
	color: #000;
	border-bottom:0px ;
	padding-bottom:2px;
	}

#navbar-dsi {
	float:left;
	margin:0;
	margin-right:5px;
	padding:0px 0px 0px 10px;
	border-top:2px solid #765;
	border-left:2px solid #765;
	border-bottom:1px solid #765;
	background: #FFC587;
	}
#navbar-dsi a {
	float:left;
	padding:5px 13px 2px 6px;
	border-right:2px solid #765;
	border-bottom:0px solid #765;
	height: 100%;
	text-decoration:none;
	}
#navbar-dsi.current {
	border-bottom:1px solid #FFC587;
	}
#navbar-dsi.current a {
	color: #000;
	border-bottom:0px ;
	padding-bottom:2px;	}


#navbar-acquisition {
	float:left;
	margin:0;
	margin-right:5px;
	padding:0px 0px 0px 10px;
	border-top:2px solid #765;
	border-left:2px solid #765;
	border-bottom:1px solid #765;
	background: #C0F1C3;
	}
#navbar-acquisition a {
	float:left;
	padding:5px 13px 2px 6px;
	border-right:2px solid #765;
	border-bottom:0px solid #765;
	height: 100%;
	text-decoration:none;
	}
#navbar-acquisition.current {
	border-bottom:1px solid #C0F1C3;
	}
#navbar-acquisition.current a {
	color: #000;
	border-bottom:0px ;
	padding-bottom:2px;	}


#navbar-demandes {
	float:left;
	margin:0;
	margin-right:5px;
	padding:0px 0px 0px 10px;
	border-top:2px solid #765;
	border-left:2px solid #765;
	border-bottom:1px solid #765;
	background: #FFF0A7;
	}
#navbar-demandes a {
	float:left;
	padding:5px 13px 2px 6px;
	border-right:2px solid #765;
	border-bottom:0px solid #765;
	height: 100%;
	text-decoration:none;
	}
#navbar-demandes.current {
	border-bottom:1px solid #C0F1C3;
	}
#navbar-demandes.current a {
	color: #000;
	border-bottom:0px ;
	padding-bottom:2px;
}


#navbar-fichier {
	float:left;
	margin:0;
	margin-right:5px;
	padding:0px 0px 0px 10px;
	border-top:2px solid #765;
	border-left:2px solid #765;
	border-bottom:1px solid #765;
	background: #FFF0A7;
	}
#navbar-fichier a {
	float:left;
	padding:5px 13px 2px 6px;
	border-right:2px solid #765;
	border-bottom:0px solid #765;
	height: 100%;
	text-decoration:none;
	}
#navbar-fichier.current {
	border-bottom:1px solid #C0F1C3;
	}
#navbar-fichier.current a {
	color: #000;
	border-bottom:0px ;
	padding-bottom:2px;	}


#navbar-cms {
	float:left;
	margin:0;
	margin-right:5px;
	padding:0px 0px 0px 10px;
	border-top:2px solid #765;
	border-left:2px solid #765;
	border-bottom:1px solid #765;
	background: #6BCEE7;
	}
#navbar-cms a {
	float:left;
	padding:5px 13px 2px 6px;
	border-right:2px solid #765;
	border-bottom:0px solid #765;
	height: 100%;
	text-decoration:none;
	}
#navbar-cms.current {
	border-bottom: 1px solid #6BCEE7;
	}
#navbar-cms.current a {
	color: #000;
	border-bottom:0px ;
	padding-bottom:2px;	
	}
	
#navbar-dashboard {
	float:left;
	margin:0;
	margin-right:5px;
	padding:0px 0px 0px 10px;
	border-top:2px solid #765;
	border-left:2px solid #765;
	border-bottom:1px solid #765;
	background: #FFF0A7;
	}
#navbar-dashboard a {
	float:left;
	padding:5px 13px 2px 6px;
	border-right:2px solid #765;
	border-bottom:0px solid #765;
	height: 100%;
	text-decoration:none;
	}
#navbar-dashboard.current {
	border-bottom: 1px solid #FFF0A7;
	}
#navbar-dashboard.current a {
	color: #000;
	border-bottom:0px ;
	padding-bottom:2px;	
	}
