/* +--------------------------------------------------------------------------+
//  2002-2010 PMB Services / www.sigb.net pmb@sigb.net et contributeurs (voir www.sigb.net)
// +-------------------------------------------------+
// $Id: visionneuse.css,v 1.3 2010-11-04 16:20:58 arenou Exp $
*/

#visionneuse #visionneuseIframe {
	-moz-border-radius : 20px;
	-webkit-border-radius : 20px;
	border : 2px solid black;
	border-style : inset;
	overflow : hidden;
}

#next, #previous {
	cursor : pointer;
}

#visionneuseBackground{
	background-color : gray;
	-moz-opacity : 0.5;
	opacity : 0.5;
	filter : alpha(opacity=50);
	width : 100%;
	height : 100%;
	position : absolute;
	top : 0;
	left : 0;
	z-index:9001;
}

.linkFullscreen {
	position : absolute;
	right : 2%;
	bottom : 1%;
}

.close{
	position : absolute;
	right : 2%;
	top : 0%;
}

#visio_navigator{
	height : 40px;
	width : 100%;
	margin-top : 0.8em;
}

#visio_current_description{
	text-align : left;
	margin-top : 1em;
}

#visio_current_object{
	padding:1em;
	margin-top:1.4em;
	text-align:center;
}

#wait {
	position : absolute;
	top : 200px;
	left : 50%;
	margin-left : -16px;
}
