/* +--------------------------------------------------------------------------+
//  2002-2004 PMB Services / www.sigb.net pmb@sigb.net et contributeurs (voir www.sigb.net)
// +-------------------------------------------------+
// $Id$
*/

/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                         ATTRIBUTS GENERAUX                                 */
/*                                                                            */
/*  attributs generaux de la page                                             */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/

a img{
	border:none;
}

body { 
	font-family : Verdana, Arial, Helvetica, sans-serif;
	font-size : 11px;
	background:white;
}

/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                            ID FIXES                                        */
/*                                                                            */
/*  feuilles de styles appliquees a des id fixes                              */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/

/* #container : partie d'affichage principale a droite de l'ecran */
#pmbopac {
	background-image:url('images/bordure_h.png');
	background-repeat:repeat-x;
	padding:0;
	margin:0;
}
#container{
	background-image:url('images/bordure_g.png');
	background-repeat:repeat-y; 
	padding-left:58px;	
	padding-top:133px;
}

/*************************
	Iframe panier
*************************/
iframe#iframe_resume_panier {
	width:100%;
	height:35px;
	border:none;
	margin-bottom:10px;
}

#intro {
	position:absolute;
	top:160px;
	left:75px;	
	width:150px;
}
#intro_pmb {}
#search_result{padding-bottom:100px;}
	#intro_pmb h1{
	}
	#intro_pmb h2 {		
	}
	#intro_pmb h3 {	
		
	}

#intro_message {}

	#intro_message .p1 {
		position:absolute;
		top:0;
		left:0;
		height:43px;
		width:376px;
		border:none;	
		background-image:url('images/ban_p1.png');
		background-repeat:no-repeat;
		padding:115px 0 0 400px;
		color:#ca0000;
		font-size:13px;
		font-weight:bold;
	}		
	#intro_message .p2 {
		position:absolute;
		right:0px;
		top:0px;
		height:40px;
		width:256px;
		background-image:url('images/ban_p2.png');
		background-repeat:no-repeat;
		background-position:top right;
		padding:124px 90px 0 0;
		text-align:right;
		font-size:14px;
		font-weight:bold;
		color:#23338f;
	}
	#intro_message img {
		position:absolute;
		top:45px;
		left:70px;
		width:300px;
		height:90px;
		z-index:2000;
		border:none;
	}
	map_lien_retour{
		z-index:2000;
	}

#intro_bibli {
	margin-bottom:10px;
	background:white url('images/menu_milieu.png') repeat-y;	
}
	#intro_bibli h3{
		background-image:url('images/menu_haut.png');	
		background-repeat:no-repeat;
		padding:10px 5px 5px 15px;
		font-size:12px;
		color:#222;
		font-weight:normal;
	}
	#intro_bibli h3:first-letter{
		color:white;
		font-weight:bold;
	}
	#intro_bibli .p1{
		text-indent:16px;
		margin:0 10px;
		padding-bottom:7px;
		border-bottom:1px dashed #eee;
	}
	#intro_bibli .p2{
		text-indent:16px;
		background-image:url('images/menu_bas.png');
		background-position:bottom left;
		background-repeat:no-repeat;
		padding:10px 10px 50px 10px;
	}
	#intro_bibli .p2 img{
		width:auto!important;
		width:100px;
		max-width:100px;
		overflow:hidden;
	}
		
#all_footer {
	position:absolute;
	top:460px;
	padding-left:10px;
	left:65px;
}

	#main {
		display: block;
		padding:30px 80px 0 20px;
		background-image: url('images/bordure_d.png');
		background-repeat: repeat-y; 
		background-position:right;
		margin:0;
		margin-left:165px;
	}
	#main_hors_footer{
		min-height:600px;
		height:auto!important;
		height:600px;
		margin:0;
		padding-bottom:20px;
	}
	#main h3 { 
		margin-top:15px;
		margin-bottom:10px;
		font-size:14px;
	}

	#main h3 span {
		font-size:14px;
		color:#8888aa; 
	}

    #main  #search_crl {
    	clear:both;
    	}      

.div_clr {
    	clear:both;
    	}  

	#location {
		clear:both;
	}

	#search, #onglets_list {
		margin-top:10px;
    	padding:5px;
    	background:white url('images/p_haut.png') repeat-x;
    	margin:20px 0;
		border:1px solid #e0e0dd;
	}
	
	#search ul.search_tabs, #onglets_list ul.list_tabs{
		margin:0;
		padding:0;
        list-style:none;
        clear:right;
        height:24px;
	}
	
	#onglets_list{
		margin-top:40px;	
	}
	#search ul.search_tabs li, #onglets_list ul.list_tabs li{
		position:relative;
		top:-37px;
		float:left;
       	margin-right:4px;
		margin-bottom:5px;
       	height:19px;
		padding:16px 10px 0 20px;
		background-image:url('images/papillon2.png');
		background-repeat:no-repeat;
	}
	#search input, #search select {
		border: 1px solid #cececb;
	}
	#search p{position:relative; top:-30px;}
	#search form{position:relative; top:-20px;}
	#search #simple_search_zone{position:relative; top:10px;}
	#search ul.search_tabs li a,  #onglets_list ul.list_tabs li a{
		text-decoration:none;
		font-weight:normal;
		background-image:url('images/search_search_tabs.png');
		background-repeat:no-repeat;
		background-position:top right;
		padding:2px 7px 0 0;
		color:#222;
	}
	#search ul.search_tabs li a:hover,  #onglets_list ul.list_tabs li a:hover{font-style:italic;}     
	#search ul.search_tabs li#current, #onglets_list ul.list_tabs li#current{
		background-image:url('images/papillon1.png');
		background-repeat:no-repeat;
		font-weight:bold;
	}
	input, select, textarea{
		border:1px solid #ccc;
		background:white;
	}

	#aut_see {
		border-top:2px solid #8888aa;
		border-bottom:2px solid #8888aa;
    	margin-top:-1px;
    	padding:5px;
    	background:#eee url('images/cercles.png') no-repeat bottom right;
    	margin-bottom:10px;
		color:#222;
	}
	#aut_see h3{font-size:13px;padding-left:10px}
	#aut_see ul, #aut_details ul{list-style-type:none;padding:10px}
	#aut_see a{color:#222;}
	#aut_see a:hover{color:#000;}

	#navigator {
		display:table;
		margin:-25px 0 0 100px;
		z-index:200;
		position:relative;
	}
	#navigator strong { display:none;}

	#navigator td {
		padding-right:10px;
		text-align:left;
		font-size:11px;
		font-weight:italic;
	}
	#navigator a{text-decoration:none;color:#23338f;}
	#navigator a:hover{text-decoration:underline;}

/* informations � ajouter pour afficher les cat�gories */
div.row_categ {
 display: block;
 clear: left;
}

#categories {margin-bottom:30px; }
	
#categories h1  
	{ }
#categories h3 {
	margin:0px;
	margin-top:0px;
	padding-left:5px;
	font-size:20px;
	font-weight:bold;
	color:#ffffff;
	}	

#categories a {
	color:#ffffff;
	text-decoration:none;
}

#categories A:hover {
	color:#ffffff;
	text-decoration:underline;
}

/* informations a ajouter pour afficher les categories */
#categories-container {
	padding:20px 0 0 10px;
	display:block;
	padding-bottom:5px;
	margin-left:100px;
	border:1px solid #cececb;
	background:white url('images/p_haut') repeat-x;
}

div.category {	
	color:white;
	padding:2px;
}
		
#categories-container h2 {
	font-size:13px;
	color:white;
}
		
#categories-container h2 {
	font-size:12px;
	padding-bottom :0px;
	padding-left:25px;
	color:#333;
	background-image: url('images/folder.png');
	background-repeat:no-repeat;

}

#categories-container h2 img {display:none;}
#categories-container h2 a {color:#333;}
#categories-container h2 a:hover {color:#333;}
#categories-container ul {margin:2px;padding:0;}
#categories-container li  {display: inline;}
#categories-container li a {text-decoration:none;color:#777;}
#categories-container li a:hover {text-decoration:underline;color:#555;}
#categories-container li:after  {content: " - "; }

#categories ul.search_tabs {
	height:0px;
	border:none;
	float:left;
	display:block;
	text-align:right;
	list-style-type:none;
	width:100px;
	margin:0;
	padding:0;
}	

#categorie ul.search_tabs li{
	margin-right:10px;
	background:#5ab9f9;
	color:#5ab9f9;
	width:80px;
}

#categories ul.search_tabs li a{
	background:white url('images/categ_menu.png') no-repeat right;
	text-decoration:none;
	font-weight:normal;
	color:#4f5f88;
	padding-right:10px;
	height:16px;
	display:block;
	padding-top:2px;
	margin-bottom:3px;
	font-weight:bold;
	font-style:normal;
}
#categories ul.search_tabs li a:hover{font-style:italic;}
#categories ul.search_tabs li#current{
	background:white url('images/categ_current.png') no-repeat right;
	padding-right:10px;
	padding-top:2px;
	height:16px;
	margin-bottom:3px;
	color:#cb0000;
	font-weight:bold;
}          	

/* Mise en page des colonnes d'affichage des recherches 
   par auteurs, editeurs, collections , sous-collections et categories */
.categ_colonne {
}
/* reset des largeurs de #categories */
/* apres un float:left; l'element bloc suivant doit avoir l'attribut clear:both selectionne pour eviter un bug d'affichage */

#last_entries { clear:both; }

#bandeau { 
	position:absolute;
	clear:both;
	top:40px;
	right:130px;
	padding:5px;
	text-align:right;
	width:100%;
}
	#bandeau input, #bandeau select{
		background:white;
		border:1px solid #ddd;
		margin-bottom:2px;
		font-size:10px;
	}
	#bandeau div {
		padding-left:5px;
		padding-right:5px;
	}
	
	#bandeau h3 {
		font-weight:bold;
		font-size:11px;
	}

	#bandeau p.centered {
		text-align:center;
	}

	#bandeau span {
		font-size:9px;
	}
		
	#bandeau h3 span {
		font-size:11px;
	}
	#bandeau li {}
	#bandeau #adresse, #bandeau img, #bandeau h3, #bandeau label{display:none;}
	#bandeau #lang_select{
		position:absolute;
		top:-35px;
		left:260px;
		text-align:right;
		min-width:230px;
	}
	#bandeau #accueil #lang_select h3 {
		display:block;
		float:left;
		margin:2px 15px 0 0;
		color:white;
	}

#footer {
	clear:both;
	padding-bottom: 60px;
	text-align:center;
	position:absolute;
	left:0px;
	background:white url('images/footer_bas.png');
	display:block;
	width:100%;
	padding-right:0px!important;
	padding-right:324px;
}
#footer .conteneur_liens{
	margin:0 78px;
}
#footer .liens{
	display:block;
	width:100%;
	background:white url('images/footer_bas2.png');
	position:relative;
	top:-18px;
}
#footer a {
	color:#444;
	padding-left:10px;
	text-decoration:none;
	position:relative;
	top:-20px;
}
#footer a img{
	position:relative;
	left:-105px;
}
#footer a:hover {color:#222;}
#footer_coin_gauche{
	position:absolute;
	left:0px;
	margin-top:-24px;
}
#footer_coin_droit{
	position:absolute;
	right:0px;
	margin-top:-24px;
}
#footer .lien_pmb_footer{display:none;}
#rss{
	padding-bottom:80px;
	margin-bottom:20px;
	background:white url('images/chronomontage.png') no-repeat 50% bottom;
}

#notice 
	{  }

	#notice h3
	{ }
		
	#notice span 
	{ }

/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                            BALISES HTML                                    */
/*                                                                            */
/*  feuilles de styles appliquees a des balises sans classes ni id specifies  */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/

A 	{
	color:#444444;
	}

A:hover {
	}

.categmouseout {
	border: solid 2px #555555;
	background-color: #fff;
	color: #000000;
	position: absolute;
	visibility:hidden;
	z-index: 2000;
}

.categmouseover {
	border: solid 2px #555555;
	background-color: #fff;
	color: #000000;
	position: absolute;
	visibility:visible;
	z-index: 2000;
	margin-top: 2px;
}

.listedescription {
	border: solid 2px #555555;
	background-color: #fff;
	color: #000000;
	position: absolute;
	visibility:hidden;
	z-index: 2000;
}

/*------------------------------------
/*	tableaux
/------------------------------------*/
table
	{ }

tr
	{ }

th
	{ text-align: left ;}

td {
	font-size : 11px;	
	}

td.jauge
	{	}

td.visible
	{ }

td.visible-centered
	{ }

tr.even {
	background: #E0E0E0;
	}
tr.surbrillance {
	background: #EECCCC;
	}
tr.odd
	{ }

/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                            CLASSES GENERIQUES                              */
/*                                                                            */
/*  feuilles de styles appliquees a classes de balises                        */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/


/* divers pour les affichages simples de texte   */
/*-----------------------------------------------*/

.row
	{ clear: both; }

.right,
.right-50,
.right-15,
.right-85 
	{	float: right; }

.right-50 {	width: 50%; }

.right-15 {	width: 15%; }

.right-85 {	width: 85%; }


.right-clear-right,
.right-50-clear-right
	{	float: right;
		clear: right; }

.left-clear-left,
.left-50-clear-left
	{	float: left;
		clear: left; }

.left,
.left-50,
.left-15
	{	float: left;}

.left-50
	{	width: 50%;}

.left-15
	{	width: 15%;}

.left-85
	{	width: 85%;}

.spacer
	{	clear: both;
		visibility: hidden;
		display: none;
		margin-bottom: -10px;
		margin-top: -10px; }

.p1 {	}
	
.text_query 
	{  }

.fond-mere {
	}

.fond-article {
	}

/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                            CLASSES LIEES A L'APPLICATION                   */
/*                                                                            */
/*  feuilles de styles appliquees a des balises sans classes ni id specifies  */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/

input.bouton 
	{ }

input.numero_page 
	{ }


/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                       ONGLETS DE L'AFFICHAGE PUBLIC/ISBD                   */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/

ul.onglets_isbd_public {
    list-style-type: none;
    padding-bottom: 24px;
    border-bottom: 1px solid #aaaaaa;
    margin: 0;
    padding-left:2px;
}

ul.onglets_isbd_public li {
    float: left;
    height: 21px;
    margin: 2px 2px 0 2px;
    border: 1px solid #aaaaaa;
    background-color: #cccccc;
}

ul.onglets_isbd_public li.isbd_public_active {
    border-bottom: 1px solid #ffffff;
    background-color: #ffffff;
}

ul.onglets_isbd_public a {
    float: left;
    display: block;
    color: #666;
    text-decoration: none;
    padding: 4px;
    cursor: default ;
}

ul.onglets_isbd_public li.isbd_public_inactive a:hover {
    background: #FFF;
    cursor: pointer ;
    }

ul.onglets_isbd_public li.onglet_basket,
ul.onglets_isbd_public li.onglet_basket a {
    border: none;
	background:none;
    cursor: pointer ;
	width:25px;
	}

ul.onglets_isbd_public li.onglet_tags,
ul.onglets_isbd_public li.onglet_tags a {
    border: none;
	background:none;
    cursor: pointer ;
	text-decoration:underline;
	}

/* Colonnes */
.colonne2 {
  float: left;
  width: 50%;
}

.colonne_suite {
  float: left;
}

.bg-grey {
  background-color: #eeeeee;
}

/* Etageres */

#etageres { clear:both; }

.etagere {
	background:white url('images/p_bas.png') repeat-x bottom;
	padding-bottom:15px;
	margin-bottom:30px;
	margin-left:30px;
}

#etagere-titre h1 {
	font-size : 13px;
	margin-bottom:15px;
	border-bottom : 1px dotted #999;
	padding:15px 0 4px 15px;
	background:#FFFFFF url(images/papillon1.png) no-repeat -1px 1px;
}
#etagere-titre h1 a {
	color:#333;
	text-decoration:none;
}
#etagere-titre h1 a:hover {
	color:#222;
	text-decoration:underline;
}

#etagere-titre a {
}

#etagere-comment h2 {
	background:white url('images/puce1.png') no-repeat 10px 3px;
	font-size:11px;
	color:#444;
	padding-left:25px;
	padding-bottom:3px;
}

#etagere-notice-list {
	padding-left:5px;
	background:white;
}

/* barre de navigation */

.liste_bulletins {
    padding-left: 3px;
    padding-right: 3px;
    	}  
.notice-heada {
    font-family: verdana, helvetica, arial, geneva, sans-serif;
	text-decoration: none;
    font-size: 11px;
    font-weight: bold;
	padding-top:5px;
}
.notice-parent {
    font-family: verdana, helvetica, arial, geneva, sans-serif;
    color: #000000;
    margin-left: 0px;
    font-size: 8pt;
    text-decoration: none
}
.img_plus {
	background-color: #ddd;
}
.notice-child {
    font-family: arial, helvetica, geneva, sans-serif;
    margin-left: 25px;
    width: 98%;
    padding-left: 4px;
    padding-right: 4px;
    text-align: justify;
    border-bottom-style: solid;
    border-bottom-width: 1px;
    border-bottom-color: #c0c0c0;
    border-left-style: solid;
    border-left-width: 1px;
    border-left-color: #c0c0c0;
    border-right-style: none;
    border-top-style: none;
}
.notice-child td.bg-grey{
	width:20%;
	min-width:150px;
}

.heada {
    font-family: verdana, helvetica, arial, geneva, sans-serif;
	text-decoration: none;
    font-weight: bold;
}
.parent {
    font-family: verdana, helvetica, arial, geneva, sans-serif;
    color: #000000;
    margin-left: 0px;
    text-decoration: none
}
.child {
    font-family: arial, helvetica, geneva, sans-serif;
    margin-left: 25px;
    width: 98%;
    padding-left: 4px;
    padding-right: 4px;
    text-align: justify;
    border-bottom-style: solid;
    border-bottom-width: 1px;
    border-bottom-color: #c0c0c0;
    border-left-style: solid;
    border-left-width: 1px;
    border-left-color: #c0c0c0;
    border-right-style: none;
    border-top-style: none;
}

iframe#iframe_resume_panier {
	width:100%;
	height:35px;
	border:none;
	}

/* Bannettes */
#bannette {
	background:#EEEEFF; 
	border:#cccccc 1px solid;
}

.bannette-titre h1 {
	background: url("liens.png") top left;
	width:99%;
	margin:0px;
	padding:5px;
	font-size:13px;
	font-weight:bold;
}
.bannette-titre h1 a {
	color:#000000;
}

.bannette-titre a {
}

#bannette-comment h2 {
	width:97%;
	text-align:right;
	font-style:italic;
	font-size:16px;
	color:#ffffff;
	margin:0px;
	padding:0px;
	margin-top:-3px;
	padding-bottom:5px;
}

#bannette-notice-list {
	padding-left:5px;

}

#bannette-notice-list A {
}
#bannette-notice-list A:hover {
}

.alerte {
	color: red;
	font-size:14px;
	}

.echelle_avis {
	background-color: #eeeeee;
	padding: 7px;
	margin: 3px;
	border:1px solid #BBBBCC;
}

.text_search0 {
	background-color: yellow;
	text-decoration: underline;
}

.text_search1 {
	background-color: #dd9797;
	text-decoration: underline;
}

.text_search2 {
	background-color: #ddb397;
	text-decoration: underline;
}

.text_search3 {
	background-color: #cd97dd;
	text-decoration: underline;
}

.text_search4 {
	background-color: #97c2dd;
	text-decoration: underline;
}

.text_search5 {
	background-color: #97ddae;
	text-decoration: underline;
}

#titre-popup {
		margin-top:5px;
		padding-top: 5px;
		padding-bottom: 5px;
		background:#CCCCEE;
		border:1px solid #BBBBCC;
		color: #fee064;
	}

.etiq_champ {
	font-weight:bold;
	}

#websubscribe h1 {
	font-size : 13px;
	margin-bottom:15px;
	border-bottom : 1px dotted #999;
	padding:15px 0 4px 15px;
	background:#FFFFFF url(images/papillon1.png) no-repeat -1px 1px;
}

.subsform {
	width:200px;
}

#websubscribe .erreur {
	color: #FF0000 ;
	font-size:14px;
}

/*Suggestion Multiple*/

.tab_sug{
	table-layout: fixed;
}

table{
	border-collapse:collapse;
	width:100%;
}
.tab_sug th, .tab_sug td{
	border:1px solid #CCCCCC;
	border-collapse:collapse;
	overflow:hidden;	
	vertical-align:center;
	text-align: center;
	width : 100%;
}

.tab_sug  input, .tab_sug textarea{
   width:95%;
   height:100%;
}
.tab_sug select{
	width:95%;
}

.erreur_saisie {
	background-color: #ff0000;
}

/*---------------------------------------------------------------*
 *---------------------------------------------------------------* 
 * 		      Mise en forme de la fiche emprunteur				 *
 *---------------------------------------------------------------*
 *---------------------------------------------------------------*/

#empr_onglet {
		margin-top:10px;
    	padding:5px;
    	background:white url('images/p_haut.png') repeat-x;
    	margin:20px 0;
		border:1px solid #e0e0dd;
	}
	
	#empr_onglet ul.empr_tabs{
		margin:0;
		padding:0;
        list-style:none;
        clear:right;
        height:24px;
	}
	
	#empr_onglet ul.empr_tabs li{
		position:relative;
		top:-37px;
		float:left;
       	margin-right:4px;
		margin-bottom:5px;
       	height:19px;
		padding:16px 10px 0 20px;
		background-image:url('images/papillon2.png');
		background-repeat:no-repeat;
	}
	
	#empr_onglet ul.empr_tabs li a{
		text-decoration:none;
		background-image:url('images/search_search_tabs.png');
		background-repeat:no-repeat;
		background-position:top right;
		padding:2px 7px 0 0;
		color:#222;
	}
	#empr_onglet ul.empr_tabs li a:hover{font-style:italic;}     
	#empr_onglet ul.empr_tabs li#current{
		background-image:url('images/papillon1.png');
		background-repeat:no-repeat;
		font-weight: bold;
	}
	
 ul.empr_subtabs{
		margin:0;
		padding:0;
		list-style:none;
        clear:right;
        height:24px;
	}
 ul.empr_subtabs li{
		position:relative;
 		float:left;
 		margin-right:7px;
		top:-25px;
       	height:15px;
		padding:10px 5px 10px 5px;
	}
	
	 ul.empr_subtabs li a{
		text-decoration:none;
		padding:3px;
		color:#222;
		background:#fff;
		border:1px solid #8888AA;
		color:#B1B8DA;
		-moz-border-radius:3px;
	}
	
	#empr_onglet ul.empr_subtabs li a:hover{
		border:1px solid #8888AA;
		color:#8888AA;
		-moz-border-radius:3px;
	}     
	#empr_onglet ul.empr_subtabs li#current a{
		font-weight: bold;
		color:#8888AA;
	}

/***********************
 * Carroussel bulletin *
 ***********************/
.carroussel_bulletin{
	text-align : center;
	/*border : 1px solid black;*/
}

.carroussel_bulletin .active{
	border : 1px solid black;
	cursor : pointer;
}

.carroussel_bulletin .current_bull_carroussel{
	border : 1px solid black;
	font-weight : bold;
}

.authorities{
	background : #A8A8A8;
}

.vignetteimg {
  max-width: 140px;
  max-height: 200px;
  width: expression(this.width > 140 ? "140px" : true);
  height: expression(this.height > 200 ? "200px" : true);
}

#search_onglet ul.search_tabs {
	list-style: none;
	padding-left: 0px;
	margin-left: 0px;
	margin-top: 0px;
	margin-bottom: 10px;	
}

#search_onglet ul.search_tabs li {
	background-image: url("images/papillon2.png");
    background-repeat: no-repeat;
    display: inline;
    margin-bottom: 5px;
    margin-right: 4px;
    padding-top: 16px;
    padding-right: 10px;
    padding-bottom: 0px;
    padding-left: 20px;
}

#search_onglet ul.search_tabs li a {
	text-decoration: none;
	background-image: url("images/search_search_tabs.png");
    background-position: right top;
    background-repeat: no-repeat;
    color: #222222;
    padding: 2px 7px 0 0;
}

#search_onglet ul.search_tabs li a:hover {
	font-style: italic;
}

#search_onglet ul.search_tabs li.current a {
	background-image: none;
    color: #000000;
    font-weight: bold;
}

#search_onglet ul.search_tabs li.current a:hover {
	font-style: normal;
}


/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                               Liens Sociaux                                */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/


table td div.addthis_toolbox {
	margin-bottom: 10px;
}

a.addthis_button_facebook_like iframe {
	height: 20px !important;
    width: 60px !important;
}

a.addthis_button_tweet iframe {
    width: 105px !important;
}


/* -----------------------------------------------------*/
/*                 Liste p�riodiques                    */
/* -----------------------------------------------------*/


#perio_a2z {
	margin-top: 20px
}
	
#perio_a2z #perio_a2z_search {
	margin-bottom: 5px;
	width :	50%;
}

table.a2z_contens {
	margin-top: 10px;
}

table.a2z_contens td {
	vertical-align: top;
}

table.a2z_perio_list {
	width: 220px;
	margin-right: 10px;
}

table.a2z_perio_list tr td {
    padding-bottom: 3px;
    padding-top: 2px;
}

#a2z_perio b .header_title {
	font-size: 16px;
	text-transform: uppercase;
}

#a2z_perio .navbar {
	margin-top: 10px;
}

input#a2z_abt_actif {
	vertical-align: middle;
	margin-left: 2px;
	margin-right: 2px;
}

#form_search_bull form {
	margin-top: 10px;
}

#form_search_bull form table td {
	vertical-align: middle;
}

