/* +--------------------------------------------------------------------------+
// © 2002-2004 PMB Services / www.sigb.net pmb@sigb.net et contributeurs (voir www.sigb.net)
// +-------------------------------------------------+
// $Id: layout.css,v 1.7 2008-12-19 15:01:20 ngantier Exp $
*/

/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                         ATTRIBUTS GENERAUX                                 */
/*                                                                            */
/*  attributs généraux de la page                                             */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/* concerne : body */
body
	{
      background: #FFF0A7;
      margin:0;
      padding:0;
      color:#000;
      font:x-small/1.5em Verdana, Georgia, Sans-Serif;
      voice-family: "\"}\""; voice-family:inherit;
      font-size:small;
	  direction:rtl;
      } 
a,
a:visited,
a:hover {
	color: #000;
	text-decoration: underline;
	}
.index {
	background: #A6DCDC;
	}
.index #contenu .bouton {
	color: #FFFFFF;
	font-size:13pt ;
	border: 1px outset #CCCCCC;
	background-color: #D0686F;
	}
#login-box .form-contenu {
	border-bottom: 0px;
	border-top: 0px;
	padding: 0px;
	margin-bottom: 1em;
	margin-top: 1em;
	}



.circ,
.circ #contenu table   {
	background: #DDF0A7;
	}
	
.circ #contenu h3, 
.circ #contenu h1 {
	color: #5DA40A;
	}

.circ #contenu .bouton, .circ .bouton  {
	color: #FFFFFF;
	font-size:13pt ;
	border: 1px outset #CCCCCC;
	background-color: #D0686F;
	}
.circ #contenu tr.even {
	background: #D3E795;
	}

.categ_browser, .categ_browser #contenu-frame table, .publisher_browser, publisher_browser #contenu-frame table,
.z_progression_visible, .z_progression_visible #contenu-frame table,
.term_search, .term_search #contenu-frame table,
.term_show, .term_show #contenu-frame table,
.catalog,
.catalog #contenu table,
.catalog #contenu-frame table  {
	background: #FAF5BC;
	}

.categ_browser #contenu-frame, .publisher_browser #contenu-frame, .z_progression_visible h3 #contenu-frame h1,
.z_progression_visible #contenu-frame, .z_progression_visible h3 #contenu-frame h1,
.term_search #contenu-frame, .term_search h3 #contenu-frame h1,
.term_show #contenu-frame, .term_show h3 #contenu-frame h1,
.catalog #contenu h3, 
.catalog #contenu h1 {
	color: #C9B90B;
	}
	
.categ_browser #contenu-frame .bouton, .publisher_browser #contenu-frame .bouton,
.z_progression_visible #contenu-frame .bouton,
.catalog #contenu-frame .bouton,
.term_search #contenu-frame .bouton,
.term_show #contenu-frame .bouton,
.catalog #contenu .bouton {
	color: #FFFFFF;
	font-size:13pt ;
	border: 1px outset #CCCCCC;
	background-color: #816492;
	}
	
.categ_browser #contenu-frame tr.even, .publisher_browser #contenu-frame tr.even,
.z_progression_visible #contenu-frame tr.even,
.term_search #contenu-frame tr.even,
.term_show #contenu-frame tr.even,
.catalog #contenu tr.even {
	background: #E8E086;
	}

.autorites,
.autorites #contenu table  {
	background: #E0D9FF;
	}
.autorites #contenu h3, 
.autorites #contenu h1 {
	color: #806CD6;
	}
.autorites #contenu .bouton {
	color: #FFFFFF;
	font-size:13pt ;
	border: 1px outset #CCCCCC;
	background: #BCB964;
	}
.autorites #contenu tr.even {
	background: #CDC1FF;
	}

.edit,
.edit #contenu table  {
	background: #FEFFA3;
	}
.edit #contenu h3, 
.edit #contenu h1 {
	color: #C4C612;
	}
.edit #contenu .bouton {
	color: #FFFFFF;
	font-size:13pt ;
	border: 1px outset #CCCCCC;
	background-color: #6C75AC;
	}
.edit #contenu tr.even {
	background: #E9EA96;
	}

.dsi,
.dsi #contenu table.dsi  {
	background: #FFC587; 
	}
.dsi #contenu h3, 
.dsi #contenu h1 {
	color: #3C65A2;
	}
.dsi #contenu .bouton {
	color: #FFFFFF;
	font-size:13pt ;
	border: 1px outset #CCCCCC;
	background: #87B7FF;
	}
.dsi #contenu tr.even,
.dsi #contenu td.even {
	background: #CDC1FF;
	}

.acquisition,
.acquisition #contenu table  {
	background: #C0F1C3;
}
.acquisition #contenu h3, 
.acquisition #contenu h1 {
	color: #236827;
}
.acquisition #contenu .bouton {
	color: #FFFFFF;
	font-size:13pt ;
	border: 1px outset #CCCCCC;
	background: #BCB964;
}
.acquisition #contenu tr.even {
	background: #a6d1a9;
}



.launch,
.launch #contenu-frame table,
.clean,
.clean #contenu-frame table,
.alter,
.alter #contenu-frame table,
.export,
.export #contenu-frame table,
.import,
.import #contenu-frame table,
.iimport_expl,
.import_expl #contenu-frame table,
.pointage_expl,
.pointage_expl #contenu-frame table,
.admin,
.admin table,
.admin #contenu tr.odd {
	background: #F6DCDC;
	}
.admin #contenu h3, 
.admin #contenu-frame h3, 
.admin #contenu h1,
.admin #contenu-frame h1, 
.clean #contenu h3, 
.clean #contenu-frame h3, 
.clean #contenu h1,
.launch #contenu h3, 
.launch #contenu-frame h3, 
.launch #contenu h1,
.clean #contenu-frame h1, 
.alter #contenu h3, 
.alter #contenu-frame h3, 
.alter #contenu h1,
.alter #contenu-frame h1, 
.import #contenu h3, 
.import #contenu-frame h3, 
.import #contenu h1,
.import #contenu-frame h1, 
.pointage_expl #contenu h3,
.pointage_expl #contenu-frame h3,
.pointage_expl #contenu h1,
.pointage_expl #contenu-frame h1,
.iimport_expl #contenu h3, 
.iimport_expl #contenu-frame h3, 
.iimport_expl #contenu h1,
.iimport_expl #contenu-frame h1 {
	color: #CD7171;
	}
.admin #contenu .bouton,
.admin #contenu-frame .bouton,
.clean #contenu .bouton,
.clean #contenu-frame .bouton,
.launch #contenu .bouton,
.launch #contenu-frame .bouton,
.alter #contenu .bouton,
.alter #contenu-frame .bouton,
.import #contenu .bouton,
.import #contenu-frame .bouton,
.iimport_expl #contenu .bouton,
.iimport_expl #contenu-frame .bouton,
.pointage_expl #contenu .bouton,
.pointage_expl #contenu-frame .bouton
	{
	color: #FFFFFF;
	font-size:13pt ;
	border: 1px outset #CCCCCC;
	background-color: #4A9DA2;
	}
	
.clean #contenu-frame tr.even,
.alter #contenu-frame tr.even,
.export #contenu-frame tr.even,
.import #contenu-frame tr.even,
.iimport_expl #contenu-frame tr.even,
.admin #contenu tr.even {
	background: #EBC7C7;
	}

.form-circ {
background: #BCDD95;
}
.form-circ h3 {
color: #5DA40A;
}

.form-retour-expl {
background: #BB0000;
color: #DDF0A7;
}
.form-retour-expl h3 {
color: #DDF0A7;
}

.form-catalog {
background: #F4EC92;
}
.form-catalog h3 {
color: #C9B90B;
}

.form-autorites {
background: #B6A5FD;
}
.form-autorites h3 {
color: #806CD6;
}

.form-edit {
background: #E9EA6C;
}
.form-edit h3 {
color: #C4C612;
}

.form-dsi {
background: #B6A5FD;
}
.form-dsi h3 {
color: #806CD6;
}

.form-acquisition {
	background: #72c177;
}


.form-launch,
.form-clean,
.form-alter,
.form-export,
.form-import,
.form-admin,
.form-iimport_expl,
.form-pointage_expl {
	background: #EFC7C7;
	}
.form-launch h3,
.form-clean h3,
.form-alter h3,
.form-export h3,
.form-import h3,
.form-admin h3,
.form-iimport_expl h3,
.form-pointage_expl h3
	{
	color: #CD7171;
	}


.form- {
background: #222222;
}
html>body {font-size:small;}

/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                            ID FIXES                                        */
/*                                                                            */
/*  feuilles de styles appliquées à des id fixes                              */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/* Concerne : #navbar, #menu, iframe#alerte, #conteneur, #contenu, #login-form
   #extra, #deconnexion, #footer, #logo */

/* BARRE DE NAGIVATION #navbar */
#navbar
	{   position: absolute;
		top: 0; float:right;
		width:100%;
		background:transparent url("bg.gif");
		background-position: 0% -66px;
		background-repeat: repeat-x;
		}
    
        #navbar h3 { display: none;	}
        
        #navbar ul {
        list-style:none;
        margin-top:4px;  
		}
        
/* /BARRE DE NAGIVATION #navbar */

/*	MENU : #menu	*/
#menu
{   position: absolute;
	top: 0%;
	right: 0;
	width: 11em;
	text-align: right;
	padding: 0em;}

      #menu ul
      { background: transparent;
      	padding: 0px 0px 0px 0px;
      	margin-right: .5em;
      	margin-top: 0px;
      	list-style-type: none;}
      
      #menu a
      { display: block;
      	font-size: 8pt;
      	text-decoration: none;
      	color: #000000;
      	background: transparent;
      	width: 12em; }
      
      #menu a:hover
      {	color: #000000;
      	text-decoration: underline; }
      
      #menu a:visited
      { color: #000000;}
      
      #menu li
      { text-transform: lowercase;
      	font-size: 8pt;
      	display: block;
      	padding-bottom: .2em;
      	color: #000000;
      	padding-right: 20px;}
      
      #menu ul li a
      {	font-size: 8pt;
      	text-decoration: underline;}
      
      #menu h3
      {	padding: 0px 0px 0px 0px;
      	margin : 0px 0px 0px 0px;
      	font-size: 11pt;
      	font-weight: bold;
      	color :#000000;
      	padding-right: 10px;}
      /*	/MENU	*/

/*    MENU : #menu_horizontal    */
#hmenu {
    padding-bottom: 0.5em;
   }

#hmenu a {
         }

#hmenu a:hover {
      }

#hmenu a:visited {
      }


iframe#alerte
	{ visibility:visible;position:absolute;right:0;top:510px;width:150px;border-style:none;border-width:0px;border-color:#000000;background:transparent; }

/* Conteneur */
#conteneur
      {	position: absolute;
      	top: 3em;
      	width: 100%;
      	z-index:10;  }
      
      #conteneur a
      {	color: #000;
      	/* font-weight: bold; */
      	font-size: 10pt;
      	text-decoration: underline;
      	/*padding: 0 10px 0 0;*/
      	}
      
      #conteneur a:hover
      { text-decoration: underline; }
/*  /Conteneur */

/*	Contenu	*/
#contenu
	{
	position: absolute;
	top: 5%;
	left: 0;
	right: 12.5em;
	width: 80%;
	}
	
#contenu a
	{
	color: #000000;
	text-decoration: underline;
	}

#contenu .hidelink a:link	
	{
	text-decoration: none;
	}
#contenu .hidelink a:visited
	{
	text-decoration: none;
	}
/* utilisé pour les paniers : c'est un tag img avec un javascript onmousedown (pas un tag a) */
#contenu .hidelink img
	{
	cursor: pointer;
	}
     
#contenu a.lien_gestion {
      	font-size: 8pt;
	text-decoration: none;
	}
#contenu a.lien_gestion:hover {
	text-decoration: underline;
	}


      
#contenu label
	{
	font-size: 9pt;
	font-weight: bold;
      	}

#contenu h1 {
	color :#E87111;
	padding-top: .5em;
	font-size: 14pt;
	}
      
#contenu h2
	{
	color : #000;
      	font-size: 12pt;
      	}
/*	/Contenu	*/

/* Login-box */
#login-box
	{
	width: 50%;
	margin-right: 25%;
	margin-left: 25%;
	}
   
#login-box
	{
	margin-top: 10%;
	}
   
#login-box label
	{
	font-size: 9pt;
	font-weight: bold;
	}

#login-box h1,
#contenu h1
	{
	color :#E87111;
      	padding-top: .5em;
      	font-size: 14pt;
      	}
/*    /Login-box    */	

/*	Contenu	frame*/
#contenu-frame {
	width: 100%;
	}


#contenu-frame a 
	{
   	color: #000;
   	text-decoration: underline;
   	}
#contenu-frame a:visited {
	text-decoration: underline;
   	color: #000000;
   	}
   
#contenu-frame a:hover
	{
	text-decoration: underline;
   	color: #000000;
   	}
  
#contenu-frame h1
	{
	color : #AB3F03;
   	padding-top: .5em;
   	font-size: 11pt;
   	}
   
#contenu-frame h2
	{
	color : #000000;
   	font-size: 10pt;
   	}
   	
/*	/Contenu-frame	*/

/*	Déconnexion : #deconnexion #extra	*/
#extra
      {	position: absolute;
      	top: 0;
      	left: 0;
      	color: #000;
      	text-transform: lowercase;
      	padding: 10px 0px 0 10px;
      	z-index: 100;}
      
      #deconnexion a {	color: #ff0000;}
      
      #extra a { color: #000;}
      
      #extra a:hover { text-decoration: none; }
	  
	  #extra img { padding:2px }
      
      /*	/Déconnexion	*/

/* footer */
#footer
{   	display: none;
      	float: left;
      	padding: 0;
      	margin: 0;
      	z-index: 0;  }
      
      #footer span,
      #footer span a
      {	
      	color:#b8da75;
      	font-size: 9pt;
      	padding : 10px 5px 0 0;
      	margin: 0 10px 0 0px;}
      
      #footer a
      {text-decoration: none;}
      
/* logo */
#logo
      { position: absolute;
      	bottom: 0;
      	right: -60px;
      	/*background: transparent no-repeat bottom right url("books_small.gif");*/
      	padding: 5px;
      	margin: 0px auto;
      	width: 200px;
      	height:150px;
      	z-index: 0; }
      
      #logo span
      { display:none; }
/* /footer et logo */

/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                            BALISES HTML                                    */
/*                                                                            */
/*  feuilles de styles appliquées à des balises sans classes ni id spécifiés  */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/* Concerné : form ; select ; table (tr th td) ; hr ; img ; h3                */

/*	Forms  */
form {
	margin: 0px auto;
	width: 98%;
	padding: 5px;
}

.form-contenu {
	border-bottom: 2px solid #CCCCCC;
	border-top: 2px solid #CCCCCC;
	padding: 5px;
	margin-bottom: 1em;
	padding-bottom: 1em;
	padding-top: 1em;
	}

form a {
	color: #000;
	text-decoration: underline;
}

form a:hover {
	text-decoration: none;
}


/*	/row	*/

select option,
select
{
	text-transform: lowercase;
	font-weight: bold;
}

.liste_choix_db_login {
	text-transform: none;
      	color:#BB0000;
      	font-size: 1.4em;
	font-weight: normal;
}

.liste_choix {
	text-transform: none;
      	font-size: 1.2em;
	font-weight: normal;
}

/*------------------------------------
/*	tableaux
/------------------------------------*/
table {
	margin: 0px auto;
	padding: 5px;
	margin-bottom: 0.2em;
	padding-bottom: 0.2em;
	padding-top: 0.1em;
	background: #fff;
   	border-collapse: collapse;
   	border: 0;
   	width: 100%;
   	}
   
   tr
   { }
   
   th { 
   	background: #EEEEEE;
   	border-bottom: 2px solid #CCCCCC;
   	border-top: 2px solid #CCCCCC;
   	font-size: 9pt;
   	font-style: italic;
   	text-align: right; 
   	}
   
   td {	
   	text-align: right; }
   
   tr.surbrillance, td.surbrillance {
	background: #7FA5DE;
	}

   .table-no-border {
	border: none; }

/* Documents numériques dans les tableaux */
table.docnum
	{	background: none;
	border-collapse: collapse;
	border-left: 0px ;
	border-right: 0px ;
	border-top: 0px ;
	border-bottom: 0px ;
	width: 98%;}

td.docnum
	{	border-bottom: 0px ;
	border-top: 0px ;
	text-align: center;}

/*------------------------------------
/	/Tableaux
/------------------------------------*/

hr
	{ width:96%;
	height: 0;
	color: #000000;
	padding: 0;
	margin-bottom: 10px;
	margin-top: 10px;
	}

.row hr
	{ width:96%;
	height: 0;
	color: #000000;
	padding: 0;
	margin-bottom: 10px;
	margin-top: 10px;
	}

#contenu-frame .row hr
	{ width:96%;
	height: 0;
	color: #000000;
	padding: 0;
	margin-bottom: 10px;
	margin-top: 10px;
	}

img
	{ border: 0; }

h3
{	clear: both;
	display: block;
	margin-bottom: 2px;
	margin-top: 4px;
	padding-bottom: 1px;
	padding-top: 1px;
	color: #3740B4;}

/* les elXParent restent ici avec les h3 pour faciliter la lecture */
#el0Parent h3, 
#el1Parent h3,
#el2Parent h3,
#el3Parent h3,
#el230Parent h3,
#el4Parent h3,
#el5Parent h3,
#el6Parent h3,
#el7Parent h3,
#el8Parent h3,
#el9Parent h3,
#el10Parent h3,
#el30Parent h3,
#el41Parent h3,
#elbulParent h3  {
	font-size: 11pt;
	margin-bottom: 0px;
	margin-top: -1px;
	}

/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                            CLASSES GENERIQUES                              */
/*                                                                            */
/*  feuilles de styles appliquées à classes de balises                        */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/* Concerne :           .erreur .hide                                         */
/*     .aide .astuce .bool .row .etiquette .saisie-inline . saisie-XXXem      */
/*     .saisie-XXXemr .right .right-... .left .left-... .spacer               */
/*     .saisie-contenu .bouton .



/* ***********************/
.col
{	float: right;
	width: 100%;
	padding: 1em;
	margin: 1em; }

.erreur
{	color: #f00;
	font-weight: bold;}

.hide { display: none; }

.aide
{ cursor: help; }

.astuce
{ 	
	font-size: 10pt;
	margin-top: 1em; }

.bool
{ 	font-family: fixed;
	font-weight: bold; }

.row {   clear: both; }

.row .etiquette
{  /* float: left; */
  /*text-align: right;*/}

/*.row img {	display: inline; }*/

.saisie-inline {	width: 80%; }

.saisie-5em {	width: 5em; }
.saisie-10em {	width: 7.5em;}
.saisie-15em {	width: 10em; }
.saisie-20em {	width: 15em;}
.saisie-30em {	width: 20em; }
.saisie-50em {	width: 30em;}
.saisie-80em {	width: 40em;}

/* pour les champs en readonly, avec bouton parcourir */
.saisie-5emr,
.saisie-10emr,
.saisie-15emr,
.saisie-20emr,
.saisie-30emr,
.saisie-50emr,
.saisie-80emr
{	background-color: #DFB;
	border: 1px solid #684;
}

.saisie-5emr {	width: 5em;}
.saisie-10emr {	width: 7.5em;}
.saisie-15emr {	width: 10em;}
.saisie-20emr {	width: 15em;}
.saisie-30emr {	width: 20em;}
.saisie-50emr {	width: 30em;}
.saisie-80emr {	width: 40em;}

.saisie-85 {	width: 94%;}

.right,
.right-50,
.right-15,
.right-85
{	float: left;}

.right-50 { width: 50%;}
.right-15 { width: 15%; }
.right-85 { width: 85%; }


.right-clear-right,
.right-50-clear-right
{ 	float: left;
	clear: left; }

.left-clear-left,
.left-50-clear-left
{ 	float: right;
	clear: right; }

.left,
.left-50,
.left-15
{ 	float: right; }

.left-50 { 	width: 50%; }

.left-15 { 	width: 15%; }

.left-85
{	width: 85%;}

.spacer
{	clear: both;
	visibility: hidden;
	display: none;
	margin-bottom: -10px;
	margin-top: -10px;
	}

.saisie-contenu
{	padding-right: 12px;
	padding-top: .3em;
	margin-top: .2em;
	}

.fond-mere {
	background-color: #4f72ff;
	}

.fond-article {
	background-color: #68df00;
	}

/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                            CLASSES LIEES A L'APPLICATION                   */
/*                                                                            */
/*  feuilles de styles appliquées à des balises sans classes ni id spécifiés  */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
.notice-perio
{	border-top: 1px solid #684;
	border-bottom: 1px solid #684;
	border-right: 1px solid #684;
	border-left: 1px solid #684;
	padding: 1em;
	margin-bottom: 1em;
	margin-top: 1em;}

.bulletins-perio
{	border-top: 1px solid #684;
	border-bottom: 1px solid #684;
	border-right: 1px solid #684;
	border-left: 1px solid #684;
	padding: 1em;
	margin-bottom: 1em;
	margin-top: 1em;} 
	
.depouillements-perio
{   border-top: 1px solid #684;
	border-bottom: 1px solid #684;
	border-right: 1px solid #684;
	border-left: 1px solid #684;
	padding: 1em;
	margin-bottom: 1em;
	margin-top: 1em; }
	
.msg-perio {
	font-size: 150%;
	font-weight: bold;
	color: #f00;	}
	
/* barre fléchée en pério */
.perio-barre {
	font-size: 120%;
	font-weight: bold;
}

/* classes pour l'affichage de liste dépliantes en résultat de recherche*/
.notice-heada {
	text-decoration: none;
	font-size: 10pt;
	font-weight: bold;
}
.notice-parent {
    color: #000000;
    margin-right: 0px;
    font-size: 8pt;
    text-decoration: none
}
.notice-child {
    font-size: 0.9em;
    margin-right: 30px;
    width: 98%;
    padding-right: 4px;
    padding-left: 4px;
    text-align: justify;
    border-bottom-style: solid;
    border-bottom-width: 1px;
    border-bottom-color: #c0c0c0;
    border-right-style: solid;
    border-right-width: 1px;
    border-right-color: #c0c0c0;
    border-left-style: none;
    border-top-style: none;
}
.notice-bu {
	margin-top: 0px;
	background-color: transparent;
	border-style: none; }

/* classes pour l'affichage de liste dépliantes en formulaire de saisie de notice */
.heada {
		font-size: 10pt;
		font-weight: bold;
		}
.parent {
	color: #000000;
	margin-right: 0px;
	font-size: 8pt;
	text-decoration: none
	}
.child {
	margin-right: 30px;
	}
.bu {
	margin-top: 15px;
	}

.titre-panier
{ border-top: 1px solid #684;
	border-bottom: 1px solid #684;
	border-right: 1px solid #684;
	border-left: 1px solid #684;
	padding: 1em;
	margin-bottom: 1em;
	margin-top: 1em;
	}

#history_table {
	border:0px;
	padding:0px;
	margin:0px;
	background:transparent;
}

#history_table td {
	padding:0px;
	margin:0px;
	border:0px;
}

/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                       MODIFICATIONS POUR L'IMRPESSION                      */
/*                                                                            */
/* pour l'impression, masquage de #navbar, #menu, #deconnexion, #extra,       */
/* iframe#alerte et des boutons de classe .bouton; #contenu collé à gauche    */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/


@media print {
  #navbar
	{ display: none; }
  #menu
	{ display: none;}
  #contenu
	{
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	width: 100%;
		}
  /*	Contenu	frame*/
  #contenu-frame {
	position: absolute;
	top: 0;
	left: 0;
	right: 0em;
	width: 100%;
	}


  /*	Menu	*/
  #deconnexion 
	{ display: none; }
  #extra
	{ display: none; }
  .bouton
	{ display:none; }

  iframe#alerte
	{ visibility:hidden;	}
}
iframe#history {
	width:30%;
	height:97%;
	position:absolute; 
	top:1%; 
	right:1%;
	z-index:1000;
	}
	
* HTML iframe#history {
	height:580px;
	}
/* pour affichage de pavés de couleur pour disinction des statuts de notices */
.statutnot1 {
	}
.statutnot2 {
	background-color: #BB0000;
	}
.statutnot3 {
	background-color: #00BB00;
	}
.statutnot4 {
	background-color: #0000BB;
	}
.statutnot5 {
	background-color: #D0686F;
	}
.statutnot6 {
	background-color: #A6DCDC;
	}
.statutnot7 {
	background-color: #816492;
	}
.statutnot8 {
	background-color: #BCB964;
	}
.statutnot9 {
	background-color: #6C75AC;
	}
.statutnot10 {
	background-color: #FFC587;
	}
.statutnot11 {
	background-color: #70C173;
	}
.statutnot12 {
	background-color: #660000;
	}
.statutnot13 {
	background-color: #006600;
	}
.statutnot14 {
	background-color: #000066;
	}
.statutnot15 {
	background-color: #80181F;
	}
.statutnot16 {
	background-color: #668C8C;
	}
.statutnot17 {
	background-color: #311442;
	}
.statutnot18 {
	background-color: #7C7914;
	}
.statutnot19 {
	background-color: #2C356C;
	}
.statutnot20 {
	background-color: #BF8547;
	}
	
.message_important {
	color: #f00;
	font-weight: bold;
	font-size: 1.5em;
	padding:5px;
	margin:5px;
	}
	