/* +--------------------------------------------------------------------------+
// ? 2002-2007 PMB Services / www.sigb.net pmb@sigb.net et contributeurs (voir www.sigb.net)
// +-------------------------------------------------+
// $Id: dashboard.css,v 1.3 2014-01-13 08:07:15 arenou Exp $ */

#navbar ul {
	width : calc(100% - 80px);
}

#dashboards .dashboard {
	border-radius : 10px;
	box-shadow: 10px 10px 10px #aaa; 
}

#dashboards .dashboard h3{
	color : white;
	padding :10px;
	border-top-left-radius: 10px;
	border-top-right-radius: 10px;
	vertical-align: middle;
	background-color : #E87111;
}

