/* +--------------------------------------------------------------------------+
// ? 2002-2004 PMB Services / www.sigb.net pmb@sigb.net et contributeurs (voir www.sigb.net)
// +-------------------------------------------------+
// $Id: layout.css,v 1.72.4.1 2016-09-06 13:25:38 cgil Exp $
*/

/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                         ATTRIBUTS GENERAUX                                 */
/*                                                                            */
/*  attributs g�n�raux de la page                                             */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/* concerne : body */
body
{     background:#f5f6c2;
      background-image:none; 
      margin:0;
      padding:0;
      color:#000;
      font-size:10pt;
      font-family:inherit;}
      
body.circ,
body.catalog,
body.autorites,
body.edit,
body.dsi,
body.acquisition,
body.cms,
body.admin
{     background:#f5f6c2 repeat-y bottom left url("fond.gif");
  } 
      
/*.circ #menu
{background:#FFFFFF repeat-y bottom left url("circulation.gif");}

.catalog  #menu
{background:#FFFFFF repeat-y bottom left url("catalogue.gif");}

.autorites  #menu
{background:#FFFFFF repeat-y bottom left url("autorites.gif");}

.edit  #menu
{background:#FFFFFF repeat-y bottom left url("editions.gif");}

.admin  #menu
{background:#FFFFFF repeat-y bottom left url("administration.gif");}*/

input, select {
    font-family: inherit;
}

/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                            ID FIXES                                        */
/*                                                                            */
/*  feuilles de styles appliqu?es ? des id fixes                              */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/* Concerne : #navbar, #menu, iframe#alerte, #conteneur, #contenu, #login-form
   #extra, #deconnexion, #footer, #logo */

/* BARRE DE NAGIVATION #navbar */
#navbar
	{   position: absolute;
		top: 0; float:left;
		width:100%;
		background:#FFF bottom left url(sky.jpg);
		border-bottom:#999 solid 1px;
		font-weight:bold;
		line-height:normal;
		z-index:10;}
    
        #navbar h3 { display: none;	}
        
        #navbar ul {
          margin:0;
          padding:10px 10px 0;
          list-style:none;}
          
        #navbar li {
          float:left;
          margin:0;
          margin-bottom:2px;
          padding:0px 0px 0px 14px;
          }
          
        #navbar a {
          float:left;
          display:block;
          width:.1em;
          padding:5px 15px 4px 6px;
          text-decoration:none;
          font-weight:semibold; 
          color:#999;}
          
        #navbar > ul a {width:auto;}

        #navbar a {float:none;}

        #navbar a:hover {
          color:#444;
          }
        #navbar .current {
          border-width:0;
          }
        #navbar .current a {
          color: #080;
          }
        #navbar li.current  {
          border-bottom:#080 solid 3px;}
          
        #navbar li:hover, #header li:hover a {
          color:#000;
          border-bottom:#444 solid 3px;
          }
        #navbar li:hover a {
          }
		/* /BARRE DE NAGIVATION #navbar */

/*	MENU : #menu	*/
#menu
{   position: absolute;
	top: 10px;
	left: 0;
	width: 165px;
	text-align: left;
	padding: 0em;}

      #menu ul
      { background: transparent;
      	padding: 0px 0px 0px 0px;
      	margin-left: .5em;
      	margin-top: 0px;
       	list-style-type: none;}
      
      #menu a
      { display: block;
      	text-decoration: none;
      	color: #000000;
      	background: transparent;
      	width: 12em; }
      
      #menu a:hover
      {	color: #000000;
      	text-decoration: underline; }
      
      #menu a:visited
      { color: #000000;}
      
      #menu li
      { display: block;
      	padding-bottom: .2em;
      	color: #000000;
      	padding-left: 0px;}
      
      #menu ul li a
      {	text-decoration: underline;}
      
      #menu h3
      {	padding: 0px 0px 0px 0px;
      	margin : 0px 0px 0px 0px;
      	font-weight: bold;
      	background:#9bc08a;
      	color :#cbf0ba;
      	padding-left: 7px;}
      /*	/MENU	*/

/*    MENU : #menu_horizontal    */
	.hmenu span{
		padding:0 5px;
   	}
	.vmenu span{
		display:block;
   	}
	/* General. setpref sert lors de l'enregistrement des preferences de disposition du menu. */
	#menu h3.setpref{background:#98ba55;}

iframe#alerte
	{ visibility:visible;position:absolute;left:0;top:600px;width:150px;border-style:none;border-width:0px;border-color:#000000;background:#EEEEEE; }

/* Conteneur */
@media screen {
#conteneur
      {	position: absolute;
      	top: 3em;
      	width: 100%;
      	z-index:10;  }
#contenu
	{ position: absolute;
	  top: 5%;
	  right: 20px;
	  left: 190px;
	  /*width: 80%;*/}
}      
      #conteneur a
      {	color: #000;
      	/* font-weight: bold; */
      	text-decoration: underline;
      	/*padding: 0 10px 0 0; */  }
      
      #conteneur a:hover
      { text-decoration: underline; }
/*  /Conteneur */

/*	Contenu	*/

      #contenu a
      {	color: #000;
      	/* font-weight: bold; */
      	text-decoration: underline;}

		#contenu .hidelink a:link		{ text-decoration: none; }
		#contenu .hidelink a:visited	{ text-decoration: none; }
/*
		#contenu .hidelink a:hover		{ text-decoration: underline; }
*/
		/* utilis? pour les paniers : c'est un tag img avec un javascript onmousedown (pas un tag a) */
		#contenu .hidelink img			{ cursor: pointer; }
     

      /*.catalog #contenu .row a
      { background:#e0ad70;
      padding: 2px 6px 6px 6px;
      margin:4px 4px 4px 4px;
      border:#a06030 solid 1px;}*/

      .catalog #contenu form .row a
      { background:transparent;
      padding: 0px 0px 0px 0px;
      margin:0px 0px 0px 0px;
      border:none;}
      
      #contenu label {
      	font-weight: bold;     	}

      #contenu h1
      {	color :#E87111;
      	padding-top: .5em;
      	/*border-bottom: 1px dotted #b8da75;*/}
      
      .autorites #contenu h1
      {	padding-left:40px;
	background: no-repeat bottom left url(autorites-icon.gif);}
      
      
      #contenu h2
      { color : #000;
      	}
      /*	/Contenu	*/

/* Login-box */
#login-box
   {	width: 50%;
   	margin-left: 25%;
   	margin-right: 25%;}
   
   #login-box
   {	margin-top: 10%;}
   
   #login-box label {
       font-weight: bold;     	}

   #login-box h1,
   #contenu h1 {
   		color :#E87111;
     	padding-top: .5em;
     	}

/*    /Login-box    */	

/*	Contenu	frame*/
#contenu-frame {
	position: absolute;
	top: 4px;
	right: 0;
	left: 0em;
	width:98%;
	}


   #contenu-frame a {
   	color: #000;
   	text-decoration: underline;
   	padding: 0 10px 0 0;	}
   #contenu-frame a:visited
   {	text-decoration: underline;
   	color: #000000;}
   
   #contenu-frame a:hover
   {	text-decoration: underline;
   	color: #000000;}
   
   #contenu-frame h1
   {	color : #AB3F03;
   	padding-top: .5em;
   	/*border-bottom: 1px dotted #684;*/}
   
   #contenu-frame h2
   {	color : #000000;
   	font-size: 10pt; }
   	
	#contenu-frame table {
		border:none;
		background:transparent;
	}
	#contenu-frame td {
		border:none;
		background:transparent;
	}
	/*	/Contenu-frame	*/

/*	D?connexion : #deconnexion #extra	*/
#extra
      {	position: absolute;
      	top: 4px;
      	right: 0;
      	color: #000;
      	padding: 10px 10px 0 0;
      	z-index: 100;}
      	
      
      #deconnexion a {	color: #ff0000;}
      
      #extra a { 
      padding:5px 6px 6px 6px;
      color: #999;
      text-decoration: none; }
      
      #extra a:hover { 
      color:#444;
      border-bottom:#444 solid 3px;}
      
      /*	/D?connexion	*/

/* footer */
#footer
{   	display: none;
      	float: right;
      	padding: 0;
      	margin: 0;
      	z-index: 0;  }
      
      #footer span,
      #footer span a
      {	color:#b8da75;
      	padding : 10px 0 0 5px;
      	margin: 0 0 0 10px;}
      
      #footer a
      {text-decoration: none;}
      
/* logo */
#logo
      { position: absolute;
      	bottom: 0;
      	left: -60px;
      	/*background: transparent no-repeat bottom right url("books_small.gif");*/
      	padding: 5px;
      	margin: 0px auto;
      	width: 200px;
      	height:150px;
      	z-index: 0; }
      
      #logo span
      { display:none; }
/* /footer et logo */

.form-acquisition>.form-contenu #tot_ht, #tot_tva, #tot_ttc, #adr_fou, #adr_liv, #adr_fac, #tot_expl, #devise[class=saisie-5emd]{	
	border: 1px solid #684;
}
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                            BALISES HTML                                    */
/*                                                                            */
/*  feuilles de styles appliqu?es ? des balises sans classes ni id sp?cifi?s  */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/* Concern? : form ; select ; table (tr th td) ; hr ; img ; h3                */

/*	Forms  */
form
{
	background-color: #F0E0BA;
	margin: 0px auto;
	width: 98%;
	padding: 5px;
}

form a
{
	color: #000;
	text-decoration: underline;
}

form a:hover
{
	text-decoration: none;
}

/* formulaire de retour de document */
.form-retour-expl {
background: #BB0000;
color: #111111;
}
.form-retour-expl h3 {
color: #f5f6c2;
}

/*	/row	*/

select option,
select
{
	font-weight: bold;
}

/*------------------------------------
/*	tableaux
/------------------------------------*/
table
   {
	margin: 0px auto;
    padding: 5px;
	margin-bottom: 2em;
	padding-bottom: 2em;
	padding-top: 1em;
	background: #fff;
   	border-collapse: collapse;
   	border-bottom: 3px solid #8a6b1d;
	border-top: 3px solid #8a6b1d;
   	border-right: 1px solid #8a6b1d;
   	border-left: 1px solid #8a6b1d;
   	width: 100%;}
   
   tr {
   font-style: normal;
   }
   
   th
   { background: #f0f0f0;
   	border-bottom: 2px solid #8a6b1d;
   	border-top: 2px solid #8a6b1d;
   	text-align: left; 
   	}
   
   td
   {	border-bottom: 1px solid #8a6b1d;
   	border-top: 1px solid #8a6b1d;
   	text-align: left; }
   
   tr.even
   {	background: #e0ad70;
   	color: #000; }
   
   tr.odd { }
   
   tr.surbrillance 
   {	background-color: #f0cd90;}
   
tr.justmodified {
background-color: #A06C30;
color: #ffffff;
}

   .table-no-border {
	border: none; }

/* Documents num?riques dans les tableaux */
table.docnum
	{	background: none;
	border-collapse: collapse;
	border-right: 0px ;
	border-left: 0px ;
	border-top: 0px ;
	border-bottom: 0px ;
	width: 98%;}

td.docnum
	{	border-bottom: 0px ;
	border-top: 0px ;
	text-align: center;}

/*------------------------------------
/	/Tableaux
/------------------------------------*/

hr
	{ width:96%;
	height: 0;
	color: #fff;
	margin: 0;
	padding: 0;
	/*border-bottom: 1px solid #000;*/}

img {
	border: 0;
	vertical-align: middle;
}

h3
{	clear: both;
	display: block;
	margin-bottom: 2px;
	margin-top: 4px;
	padding-bottom: 1px;
	padding-top: 1px;}

/* les elXParent restent ici avec les h3 pour faciliter la lecture */
#el0Parent h3, 
#el1Parent h3,
#el2Parent h3,
#el3Parent h3,
#el230Parent h3,
#el4Parent h3,
#el5Parent h3,
#el6Parent h3,
#el7Parent h3,
#el8Parent h3,
#el9Parent h3,
#el10Parent h3,
#el11Parent h3,
#el30Parent h3,
#el41Parent h3,
#elbulParent h3,
#el14Parent h3  {
	margin-bottom: 0px;
	margin-top: -1px;
	}

/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                            CLASSES GENERIQUES                              */
/*                                                                            */
/*  feuilles de styles appliqu?es ? classes de balises                        */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/* Concerne : .roundedCornerSpace .borderBR BL TR TL .content .erreur .hide   */
/*     .aide .astuce .bool .row .etiquette .saisie-inline . saisie-XXXem      */
/*     .saisie-XXXemr .right .right-... .left .left-... .spacer               */
/*     .saisie-contenu .bouton .


 /* ***********************/
.col
{	float: left;
	width: 100%;
	padding: 1em;
	margin: 1em; }

.erreur {
	color: #f00;
	font-weight: bold;
	font-size: 16px;
}

.erreur-child
{
	display:none;
	margin-left: 12%;
    padding:0;
    color:#000;
    font-weight:normal;
}	

.hide { display: none; }

.aide
{ cursor: help; }

.astuce
{ 	margin-top: 1em; }

.bool
{
	font-weight: bold; }

.row {   clear: both; }

.row img {	display: inline; }

.saisie-inline {	width: 80%; }

.saisie-5emr,
.saisie-10emr,
.saisie-15emr,
.saisie-20emr,
.saisie-30emr,
.saisie-50emr,
.saisie-80emr {	
	background-color: #DFB;
	border: 1px solid #684;
}

.spacer
{	clear: both;
	visibility: hidden;
	display: none;
	margin-bottom: -10px;
	margin-top: -10px;}

.saisie-contenu
{	padding-left: 12px;
	padding-top: .3em;
	margin-top: .2em;}

.bouton
{	color: #fff;
	font-weight: bold;
	border: 1px outset #D47800;
	background-color: #E46B00;}

.bouton:hover
{	border-style: inset;
	background-color: #FF7C42;
 	border: 1px solid #ED8600;	}

.fond-mere {
	background-color: #4f72ff;
	}

.fond-article {
	background-color: #68df00;
	}

/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                            CLASSES LIEES A L'APPLICATION                   */
/*                                                                            */
/*  feuilles de styles appliqu?es ? des balises sans classes ni id sp?cifi?s  */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
.notice-perio
{	border-top: 1px solid #684;
	border-bottom: 1px solid #684;
	border-left: 1px solid #684;
	border-right: 1px solid #684;
	padding: 1em;
	margin-bottom: 1em;
	margin-top: 1em;}

.onglets-perio {
	border:2px #684 solid;
    border-bottom:0px #776655 solid;
    text-align:center;
    background:#F4EC92;
    padding:4px;
    margin-left:4px;
	cursor:pointer;
}

.onglet-perio-selected {
	border:2px #684 solid;
	border-bottom:1px #FAF5BC solid;
    text-align:center;
    background:#FAF5BC;
    padding:4px;
    margin-left:4px;
    cursor:default;
}

#content_onglet_perio {
	margin:0px;
	padding:0px;
}
	#content_onglet_perio a{text-decoration:none;}
	#content_onglet_perio a:hover{text-decoration:none;}
	
.bulletins-perio
{	border-top: 1px solid #684;
	border-bottom: 1px solid #684;
	border-left: 1px solid #684;
	border-right: 1px solid #684;
	padding: 1em;
	margin-bottom: 1em;
	margin-top: 0.3em;} 
	
.bulletins-perio h2 blockquote {
		font-size:0.8em;
		font-weight: normal;
}	

.depouillements-perio
{   border-top: 1px solid #684;
	border-bottom: 1px solid #684;
	border-left: 1px solid #684;
	border-right: 1px solid #684;
	padding: 1em;
	margin-bottom: 1em;
	margin-top: 1em; }
	
.msg-perio {
	font-size: 150%;
	font-weight: bold;
	color: #f00;	}
	
/* barre fl?ch?e en p?rio */
.perio-barre {
	font-size: 120%;
	font-weight: bold;
}

/* classes pour l'affichage de liste d?pliantes en r?sultat de recherche */
.notice-heada {
	text-decoration: none;
    font-weight: bold;
}
.notice-parent {
    color: #000000;
    margin-left: 0px;
    text-decoration: none
}
.notice-child {
	font-size: 0.9em;
    margin-left: 30px;
    margin-bottom: 15px;
    width: 98%;
    padding-left: 4px;
    padding-right: 4px;
    text-align: justify;
    border-bottom-style: solid;
    border-bottom-width: 1px;
    border-bottom-color: #c0c0c0;
    border-left-style: solid;
    border-left-width: 1px;
    border-left-color: #c0c0c0;
    border-right-style: none;
    border-top-style: none;
}

.notice-child table td img.img_notice {
    max-width: 140px;
	max-height: 200px;
	width: expression(this.width > 140 ? "140px" : true);
	height: expression(this.height > 200 ? "200px" : true);
}

table td .img_notice {
    max-width: 140px;
	max-height: 200px;
	width: expression(this.width > 140 ? "140px" : true);
	height: expression(this.height > 200 ? "200px" : true);
}

.notice-bu {
	margin-top: 0px;
	background-color: transparent;
	border-style: none; }

/* classes pour l'affichage de liste d?pliantes en formulaire de saisie de notice */
.heada {
		font-weight: bold;
		}
.parent {
	color: #000000;
	margin-left: 0px;
	font-size: 8pt;
	text-decoration: none
	}
.child {
	margin-left: 30px;
	}
.bu {
	margin-top: 15px;
	}

.titre-panier
{ border-top: 1px solid #684;
	border-bottom: 1px solid #684;
	border-left: 1px solid #684;
	border-right: 1px solid #684;
	padding: 1em;
	margin-bottom: 1em;
	margin-top: 1em; }


.othersearchinfo
	{ padding-top:10px;
	}
	
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                       MODIFICATIONS POUR L'IMRPESSION                      */
/*                                                                            */
/* pour l'impression, masquage de #navbar, #menu, #deconnexion, #extra,       */
/* iframe#alerte et des boutons de classe .bouton; #contenu coll? ? gauche    */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/


@media print {
  #conteneur 	{
		position: relative;
		clear:both;
		}

  #navbar
	{ display: none; }
  #menu
	{ display: none;}


  /*	Menu	*/
  #deconnexion 
	{ display: none; }
  #extra
	{ display: none; }
  .bouton
	{ display:none; }

  iframe#alerte
	{ visibility:hidden;	}
}
iframe#history {
	width:40%;
	height:97%;
	position:absolute; 
	top:1%; 
	left:1%;
	z-index:1000;
	}
	
* HTML iframe#history {
	height:580px;
	}

/* pour affichage de pav�s de couleur pour disinction des statuts de notices */
.statutnot1 {
	}
.statutnot2 {
	background-color: #BB0000;
	}
.statutnot3 {
	background-color: #00BB00;
	}
.statutnot4 {
	background-color: #0000BB;
	}
.statutnot5 {
	background-color: #D0686F;
	}
.statutnot6 {
	background-color: #A6DCDC;
	}
.statutnot7 {
	background-color: #816492;
	}
.statutnot8 {
	background-color: #BCB964;
	}
.statutnot9 {
	background-color: #6C75AC;
	}
.statutnot10 {
	background-color: #FFC587;
	}
.statutnot11 {
	background-color: #70C173;
	}
.statutnot12 {
	background-color: #660000;
	}
.statutnot13 {
	background-color: #006600;
	}
.statutnot14 {
	background-color: #000066;
	}
.statutnot15 {
	background-color: #80181F;
	}
.statutnot16 {
	background-color: #668C8C;
	}
.statutnot17 {
	background-color: #311442;
	}
.statutnot18 {
	background-color: #7C7914;
	}
.statutnot19 {
	background-color: #2C356C;
	}
.statutnot20 {
	background-color: #BF8547;
	}

.gris {
	color: grey;
}

.message_important {
	color: #f00;
	font-weight: bold;
	font-size: 1.5em;
	padding:5px;
	margin:5px;
	}

	
ul.sel_navbar {
      margin:5px;
      padding:0;
      list-style:none;
      clear:right;
      height:23px;
      float:left;
      margin-bottom:-1px;
	  border-bottom:1px solid #666666;  
}

ul.sel_navbar li {
	float:left;
	padding:3px 6px 0px 6px;
    border:1px solid #666666;  
    margin-right:4px;
	margin-bottom:5px;
    height:19px;
	background:#999999;
	color:#000000;
}

ul.sel_navbar li a {
	text-decoration:none;
	font-weight:normal;
	color:#000000;
}
      
ul.sel_navbar li.sel_navbar_current {
  	float:left;
  	padding:3px 6px 0px 6px;
  	background:#f5f6c2;
	border :1px solid #666666;  
	border-bottom:1px solid #f5f6c2;
	margin-bottom:4px;
    height:19px;
}

.dsi table tr td {
	border-left:1px solid #d09d60;
	border-right:1px solid #d09d60;
}

.dsi table.dsi tr td:hover {
	background:#ffdda0;
}

#frame_notice_preview {
 border:2px solid #777799;
 border-radius:5px 5px; 
 -moz-border-radius:10px;
 padding:10px;
 z-Index:1000;
 position:absolute;
 background: #F4EC92;
 display:none;
 width:680px;
 height:500px;
}

#frame_periodique {
 border:2px solid #777799;
border-radius:5px 5px;
 -moz-border-radius:10px;
 padding:10px;
 z-Index:1000;
 position:absolute;
 background: #FFF0A7;
 display:none;
 width:190px;
 height:250px;
}

#expl-form {
 background: #F5F6C2;
}

#expl-form select {
	width: 215px;
}
	
#frame_abts {
 border:2px solid #777799;
 border-radius:5px 5px;
 -moz-border-radius:10px;
 padding:10px;
 z-Index:1000;
 position:absolute;
 background: #FFF0A7;
 display:none;
 width:190px;
 height:250px;
}

#frame_trans_expls {
 border:2px solid #777799;
 border-radius:5px 5px;
 -moz-border-radius:10px;
 padding:10px;
 z-Index:1000;
 position:absolute;
 background: #ddf0a7;;
 display:none;
 width:500px;
 height:250px;
}

.edit #contenu tr.group_title {
	background: #bec0ce;
}
	
#a_recevoirChild .colonne_suite input {
	margin-right:20px;
}

.req_cell {
	table-layout:fixed;
}
.req_cell th,
.req_cell td {
	border:1px solid #000000;
	border-collapse:collapse;
	padding-right:4px;	
}
.req_cell .col_ali {
	width:10%;
}
.req_cell .col_get,
.req_cell .col_vis,
.req_cell .col_grp,
.req_cell .col_tri {
	width:20px;
	padding-right:0px;
}
.req_cell .col_act,
.req_cell .col_obl {
	width:50px;
	padding-right:0px;
}
.req_cell .up_bt {
	vertical-align:top;
	cursor:pointer;	
}
.req_cell .down_bt {
	vertical-align:bottom;
	margin-left:-16px;
	cursor:pointer;	
}
.req_cell .stop_bt,
.req_cell .cross_bt {
	vertical-align:middle;
	width:16px;
	cursor:pointer;	
}
.in_cell,
.in_cell_nb,
.in_cell_ro,
.in_cell_nb_ro {
	width:99%;
	border:1px solid;
}
.in_cell_nb,
.in_cell_nb_ro { 
	text-align:right;
}
.in_cell_ro,
.in_cell_nb_ro {	
	background-color: #DFB;
	border: 1px solid #684;
}

.in_cell_text {
	width:95%;
	border:1px solid;
}
.in_cell_rd,
.in_cell_ld {
	width:100%;	
	background-color:transparent;
	border-color:transparent;
	border-width:0;
}
.in_cell_rd {
	text-align:right;	
}
.in_cell_ld {
	text-align:left;
}

.req_ajax_div {
	border:1px #000 solid;
	left:0px;
	top:0px;
	position:absolute;
	background-color:#FFFFFF;
	z-Index:1000;
	height:200px;
	overflow:auto;
	display:none;
}

.req_row_handler {
	margin-left:5px;
	top:0px;
	cursor:pointer;	
}

#req_frame {
	border:2px solid #777799;
	border-radius:5px 5px;
	-moz-border-radius:10px;
	padding:5px;
	z-Index:1000;
	position:absolute;
	background: #FFF0A7;
	display:none;
 }

 .req_cell .bt_cross_elt {
 	vertical-align:bottom;
 	width:8px;
	cursor:pointer;
 }
 
.act_cell {
	table-layout:fixed;
}
.act_cell th,
.act_cell td {
	border:1px solid #000000;
	border-collapse:collapse;
	padding-left:2px;
	padding-right:2px;
	vertical-align:top;	
	overflow:hidden;
}
.act_cell_chkbox {
	width:25px;
}
.img_plus{background:#8cc6ff;}

.act_cell_img_plus {
	background:#8cc6ff;
	margin-left:-20px;
}
.act_cell_chkbox2 {
	margin-right:-20px;
}
.act_cell_comments table,
.act_cell_reminders table
{
	margin-top:0px;
	margin-bottom:0px;
}
/**
 *  Couleur de fond et de liens du calendrier
 *
 **/
#calendrier_tab td.lien_date a{
	color:white;
}
#calendrier_tab td.lien_date {
	background:green;
}
#calendrier_tab td.lien_date_hs {
	background:red;
}
#calendrier_tab td.lien_date_hs_p {
	background:orange;
}

#up_frame{
	display:none;
	border:2px solid #777799;
	-moz-border-radius:10px;
	-webkit-border-radius:10px;
	border-radius:10px;
	padding:10px;
	z-Index:1000;
	position:absolute;
	background: #eee;
}
.recorded {
	color: #cc0000;
	font-weight: bold;
}
.pbar {
	width:710px;
	text-align:center;
}
.pbar_frame {
	border:#000000 1px solid;
	padding:4px;
}
.pbar_gauge {
	text-align:left;
}
#pbar_img {
	height: 16px;
	width:0px;
}
.dom_div {
	overflow:auto;
}
.dom_tab {
	table-layout:fixed;	
}
.dom_col {
	overflow:hidden;
	width:200px;
}
.dom_cell_tab {
	border:#000000 1px solid;
	overflow:hidden;
}

/*Suggestions multiples */
.tab_sug{
	table-layout: fixed;
}

table{
	border-collapse:collapse;
	margin: 10px 0;
	width:100%;
}
.tab_sug th, .tab_sug td{
	border:1px solid #CCCCCC;	
	/*vertical-align:center;*/
	text-align: center;
	overflow:scroll;
	width:100%;
}

.tab_sug  input, .tab_sug textarea{
   width:95%;
   height:100%;
   background:#F3F3F3;
}
.tab_sug select{
	width:95%;
}


.erreur_saisie {
	background-color: #ff0000;
}

table.sortable tr td {
	padding-top: 0px;
	padding-bottom: 0px;
	padding-left: 5px;
	padding-right: 5px;	
}

#recept_frame {
	border:2px solid #777799;
	border-radius:5px 5px;
	-moz-border-radius:10px;
	padding:5px;
	z-Index:1000;
	position:absolute;
	background: #F5F6C2;
	display:none;
}
	
#f_ex_note, #f_ex_comment {
	width: 90%;
}

body.alter h2 .bdd_version {
	font-size: 15px;
}

.notice-parent .left {
	margin-left: 5px;
    float: none;
}

.notice-parent .right {
	margin-top: -15px;
    text-align: right;
    float: none;
}

/***************************
* CATALOGUE - SEGMENTATION *
***************************/

body.catalog #conteneur #contenu form #speech_timeline #speech_timeline_edit_menu ul {
	background-color: #F0E0BA;
    box-shadow: -1px 0 3px #999999 inset;
    border-radius: 5px;
    color: #000000;
    padding: 1px 3px;
    margin-left: -190px;
    margin-top: calc(-1.84em - 14pt);
}

body.catalog #conteneur #contenu form #speech_timeline #speech_timeline_edit_menu ul li {
	background-color: #CBF0BA;
    box-shadow: -1px 0 3px #999999 inset;
    padding: 3px 10px;
    margin-bottom: 2px;
    margin-top: 2px;
    cursor: pointer;
    list-style-type: none;
    text-decoration: underline;
}