@charset "utf-8";
/*Calendar  
-------------------------------------------------------------------------
--------------------------------------------------------------------------
---------------------------------------------------------------------------*/

.tundra .dijitCalendarMonthContainer th {
	background-image: none!important;
}

.tundra .dijitCalendarIncrementControl {
	width: 11px;
	height: 16px;
	background-image: url(../images/calendar_arrow.png);
	background-repeat: no-repeat;
}
.tundra .dijitCalendarIncrease {
  background-position: -12px 0;
}
.tundra .dijitButtonNode {
	border: 0px solid transparent;
}

.tundra .dijitDropDownButtonHover .dijitButtonNode {
	border-bottom-color: #6c6c6c;
}
.tundra .dijitDropDownButtonHover .dijitCalendarMonthLabel{
	color:#fff!important;
}

.dijitCalendarMonthMenu .dijitCalendarMonthLabel {
	text-align: center;
	color: #243C5F;
}

.dijitCalendarMonthMenu .dijitCalendarMonthLabel {
	text-align: center;
	color: #243C5F!important;
	font-family: arial;
	font-weight: 600;
	font-size: 90%;
	line-height: 22px;
}

.tundra .dijitCalendarMonthMenu .dijitCalendarMonthLabelHover {
	background-color: rgba(0,0,0,0.2);
	color: #fff!important;
}

.tundra .dijitArrowButtonInner {
	background: url(images/spriteArrows.png) no-repeat scroll 0 center;
}

.tundra .dijitCalendarMonthLabel {
	color: #FFFFFF!important;
	text-transform: uppercase;
}

.tundra .dijitCalendarDayLabelTemplate {
	/* color: #FF8A00!important; */
	background-image: none!important;
	background-color: #F9F9F9!important;
	line-height: 35px;
	border-top: 0px solid #eeeeee!important;
	font-weight: 800;
	padding: 0px 0px;
}

.tundra .dijitCalendarMonthContainer th {
	background-image: none!important;
	/* background-color: #F9F9F9!important; */
	padding: 5px 0px;
}
.dijitCalendarMonthContainer{
	/* background-color: #e94e1b!important; */
	/* outline: solid 1px #e94e1b; */
}
.tundra .dijitCalendarContainer {
		margin-bottom: 5px;
		border: none;
		border-bottom: 2px solid #f2f2f2;
		font-size: 0.9em;
}

.tundra .dijitCalendarBodyContainer td {
	border: solid 2px #fff;
	border-top: solid 1px #fff;
	border-left: solid 1px #ffff;
	/* box-shadow: 2px 0px 0px 1px #fff inset,0px 2px 0px 1px #FFF inset,0px 0px 0px 3px #e0e0e0 inset,0px 0px 0px 2px #e0e0e0 inset; */
	color: #a7a7a7;
	padding: 1px 0px;
	background: #fff;
	transition-duration: 0.3s;
	transition-timing-function: cubic-bezier(0.21, 0.35, 0.2, 0.6);
}
.tundra td.dijitCalendarEnabledDate {

}
.tundra td[class^='cms_module_agenda_event_']{
    color: #fff;
}
.tundra td.dijitCalendarPreviousMonth ,
.tundra td.dijitCalendarNextMonth 		{/* days that are part of the previous or next month */
	color: #d3d3d3;
	background-color: #fbfbfb;
	border-color: #F9F9F9;
	box-shadow: 0px 0px 0px 1px #FBFBFB inset;
}
/*jour*/

.tundra .dijitCalendarHoveredDate {
	background-color: #F3F3F3;
	color: #777777!important;
	box-shadow: 0px 0px 0px 50px rgba(21, 21, 21, 0.1) inset;
}
.tundra td[class^='cms_module_agenda_event_'].dijitCalendarHoveredDate {
	color: #fff!important;
	box-shadow: 0px 0px 0px 20px rgba(0, 0, 0, 0.13) inset;
}
.tundra td[class^='cms_module_agenda_event_'].dijitCalendarNextMonth {
	transition-duration:0s;
}
span.dijitCalendarDateLabel {
	min-width: 17px;
	display: inline-block;
	padding: 4px 0px;
}
/*Année*/

.tundra .dijitCalendarSelectedYear {
	color: #fff;
	background-color: #a9a9a9!important;
	border-radius: 0px;
}
.tundra .dijitCalendarYearContainer {
	background: #F9F9F9;
	border-top: 1px solid #ccc;
}
.tundra .dijitCalendarYearLabel{
	
padding: 0 0 5px;
	
font-size: 0.85em;
}
/*fleche*/
.tundra .dijitCalendarIncrementControl{
	
}
/*menu*/
.tundra .dijitMenu,
.tundra .dijitMenuBar {
	border: 1px solid rgba(0, 0, 0, 0.13);
	margin: 0;
	padding: 0;
	background-color: #E94E1B;
}

#cms_module_agenda_85 {
	width: auto;
	max-width: 275px;
	overflow: hidden;
	min-height: 335px;
	background-color: #fff;
	box-shadow: 0px 0px 4px 1px rgba(51, 51, 51, 0.08);
	margin: 1px 5px 15px 5px;
	padding: 10px;
	border: solid 1px #c2c2c2;
	float: none;
	margin: 0;
	margin-left: 63%;
}
#cms_module_agenda_85 > div.row > div > div:first-child {
	border-radius:50%;
	width: 0.8em!important;
	height: 0.8em!important;
	margin-top: 3px;
}
#cms_module_agenda_85 > div.row > div{
	padding: 0px;
	font-size:0.8em;
}
.cms_module_agenda_view_calendar_eventslist{
	margin:0px;
}
/*960 responsive
========================================================================== */
#cms_module_agenda_85 td.cms_module_agenda_event_13,
#cms_module_agenda_85 td.cms_module_agenda_event_3,
#cms_module_agenda_85 > div.row > div > div:first-child {
}
#cms_module_agenda_85 td.cms_module_agenda_event_3{
	box-shadow: 30px 30px 0px 0px rgba(102, 102, 102, 0.23) inset;
}
#cms_module_agenda_85 > div.row > div+div > div:first-child {
	box-shadow:0px 0px 0px 20px rgba(0,0,0,0.23) inset;
}
#cms_module_agenda_85 td.cms_module_agenda_event_13{

}
/*960 responsive
========================================================================== */
@media screen and (max-width: 980px) {
	#cms_module_agenda_85{
		margin-left: 72%;
	}
}

/*767 responsive
========================================================================== */
@media screen and (max-width: 767px) {
	#cms_module_agenda_85{
		max-width: 100%;
		margin-left: 0%;
	}	
}