/* +--------------------------------------------------------------------------+
// � 2002-2007 PMB Services / www.sigb.net pmb@sigb.net et contributeurs (voir www.sigb.net)
// +-------------------------------------------------+
// $Id: layout.css,v 1.151.4.1 2016-09-06 13:25:38 cgil Exp $
*/

/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                         ATTRIBUTS GENERAUX                                 */
/*                                                                            */
/*  attributs generaux de la page                                             */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/* concerne : body */
body
	{
      background: #FFF0A7;
      margin:0;
      padding:0;
      color:#000;
      font:x-small/1.5em Verdana, Sans-Serif, Helvetica, Georgia;
      voice-family: "\"}\""; voice-family:inherit;
      font-size:small;
} 

input, select {
	font-family: Verdana, Sans-Serif, Helvetica, Georgia;
}

a,
a:visited,
a:hover {
	color: #000;
	text-decoration: underline;
}
.index {
	background: #A6DCDC;
}
.index #contenu .bouton {
	color: #FFFFFF;
	font-size:13pt ;
	border: 1px outset #CCCCCC;
	background-color: #D0686F;
}
#login-box .form-contenu {
	border-bottom: 0px;
	border-top: 0px;
	padding: 0px;
	margin-bottom: 1em;
	margin-top: 1em;
}
.circ, .mailing,
.circ #contenu table,
.mailing #contenu table   {
	background: #DDF0A7;
}
	
.circ #contenu h3, 
.circ #contenu h1,
.mailing #contenu h3, 
.mailing #contenu h1 {
	color: #5DA40A;
}

.circ #contenu .bouton, .circ .bouton,
.mailing #contenu .bouton, .mailing .bouton,
.mailing #contenu-frame .bouton {
	color: #FFFFFF;
	font-size:13pt ;
	border: 1px outset #CCCCCC;
	background-color: #D0686F;
}
	
.circ #contenu .bouton_small, .circ .bouton_small,
.mailing #contenu .bouton_small, .mailing .bouton_small,
.mailing #contenu-frame .bouton_small {
	color: #FFFFFF;
	font-size:8pt ;
	border: 1px outset #CCCCCC;
	background-color: #D0686F;
	}
.circ #contenu tr.even {
	background: #D3E795;
	}

.categ_browser, .categ_browser #contenu-frame table, .publisher_browser, publisher_browser #contenu-frame table,
.z_progression_visible, .z_progression_visible #contenu-frame table, .cart, .transferts_popup, .transferts_popup #contenu-frame table, .cart #contenu-frame table,
.term_search, .term_search #contenu-frame table,
.term_show, .term_show #contenu-frame table,
.catalog, .select, .account, .print_cart, 
.print_cart table,
.catalog #contenu table,
.catalog #contenu-frame table  {
		background: #FAF5BC;
	}

.categ_browser #contenu-frame, .publisher_browser #contenu-frame, .z_progression_visible h3 #contenu-frame h1,
.z_progression_visible #contenu-frame, .z_progression_visible h3 #contenu-frame h1,
.term_search #contenu-frame, .term_search h3 #contenu-frame h1,
.term_show #contenu-frame, .term_show h3 #contenu-frame h1,
.catalog #contenu h3, 
.catalog #contenu h1 {
	color: #C9B90B;
	}
	
.categ_browser #contenu-frame .bouton, .publisher_browser #contenu-frame .bouton,
.z_progression_visible #contenu-frame .bouton,
.catalog #contenu-frame .bouton, .cart #contenu-frame .bouton, .print_cart .bouton,
.select .bouton, .account .bouton,
.term_search #contenu-frame .bouton,
.term_show #contenu-frame .bouton,
.transferts_popup .bouton ,
.catalog #contenu .bouton {
	color: #FFFFFF;
	font-size:13pt ;
	border: 1px outset #CCCCCC;
	background-color: #816492;
	}
	
.catalog #contenu .bouton_small, .cart #contenu-frame .bouton_small,
.modele_parution_edition .bouton_small,
.select .bouton_small, .account .bouton_small,
.category_browse .bouton_small,
.category .bouton_small,
.transferts_popup .bouton_small ,
.pointage_exemplarise .bouton_small,
.abonnement_parution_edition .bouton_small {
	color: #FFFFFF;
	font-size:8pt ;
	border: 1px outset #CCCCCC;
	background-color: #816492;
}
	
.categ_browser #contenu-frame tr.even, .publisher_browser #contenu-frame tr.even,
.z_progression_visible #contenu-frame tr.even,
.term_search #contenu-frame tr.even,
.term_show #contenu-frame tr.even,
.catalog #contenu tr.even, .catalog tr.even {
	background-color: #E8E086;
	}

.autorites,
.autorites #contenu table  {
	background-color: #E0D9FF;
	}
.autorites #contenu h3, 
.autorites #contenu h1 {
	color: #806CD6;
	}
.autorites #contenu .bouton {
	color: #FFFFFF;
	font-size:13pt ;
	border: 1px outset #CCCCCC;
	background-color: #BCB964;
	}
.autorites #contenu .bouton_small {
	color: #FFFFFF;
	font-size:8pt ;
	border: 1px outset #CCCCCC;
	background-color: #BCB964;
	}
.autorites #contenu tr.even {
	background-color: #CDC1FF;
	}

.form-autorites>.form-contenu #numero_thesaurus, #lib_langue{	
	border: 1px solid #684;
}

.edit,
.edit #contenu table  {
	background-color: #FEFFA3;
	}
.edit #contenu h3, 
.edit #contenu h1 {
	color: #C4C612;
	}
.edit #contenu .bouton {
	color: #FFFFFF;
	font-size:13pt ;
	border: 1px outset #CCCCCC;
	background-color: #6C75AC;
	}
.edit #contenu .bouton_small {
	color: #FFFFFF;
	font-size:8pt ;
	border: 1px outset #CCCCCC;
	background-color: #6C75AC;
	}
.edit #contenu tr.even {
	background-color: #E9EA96;
	}
.edit #contenu tr.group_title {
	background-color: #bec0ce;
	}
.dsi,
.dsi #contenu table.dsi  {
	background-color: #FFC587; 
	}
.dsi #contenu table td,
.dsi #contenu table th {
	border-left: 1px solid #000000; 
	border-right: 1px solid #000000; 
	border-bottom: 1px solid #000000; 
	}
.dsi #contenu h3, 
.dsi #contenu h1 {
	color: #3C65A2;
	}
.dsi #contenu .bouton {
	color: #FFFFFF;
	font-size:13pt ;
	border: 1px outset #CCCCCC;
	background: #87B7FF;
	}
.dsi #contenu .bouton_small {
	color: #FFFFFF;
	font-size:8pt ;
	border: 1px outset #CCCCCC;
	background: #87B7FF;
	}
.dsi #contenu tr.even,
.dsi #contenu td.even {
	background: #CDC1FF;
	}

.acquisition,
.receptions_frame,
.acquisition,	
.acquisition #contenu table  {
	background: #C0F1C3;
}
.acquisition #contenu h3, 
.acquisition #contenu h1 {
	color: #236827;
}
.acquisition #contenu .bouton, .acquisition .bouton {
	color: #FFFFFF;
	font-size:13pt ;
	border: 1px outset #CCCCCC;
	background-color: #BCB964;
	}
.acquisition #contenu .bouton_small, .acquisition .bouton_small {
	color: #FFFFFF;
	font-size:8pt ;
	border: 1px outset #CCCCCC;
	background-color: #BCB964;
	}
.acquisition #contenu tr.even {
	background-color: #a6d1a9;
}

.acquisition .tab_sep {
	background-color: #72c177;
}

.cms,
.cms #contenu table  {
	background-color: #6BCEE7;
	}
.cms #contenu h3, 
.cms #contenu h1 {
	color: #806CD6;
	}
.cms #contenu .bouton {
	color: #FFFFFF;
	font-size:13pt ;
	border: 1px outset #CCCCCC;
	background-color: #BCB964;
	}
.cms #contenu .bouton_small {
	color: #FFFFFF;
	font-size:8pt ;
	border: 1px outset #CCCCCC;
	background-color: #BCB964;
	}
.cms #contenu tr.even {
	background-color: #CDC1FF;
	}


.launch,
.launch #contenu-frame table,
.clean,
.clean #contenu-frame table,
.alter,
.alter #contenu-frame table,
.export,
.export #contenu-frame table,
.import,
.import #contenu-frame table,
.iimport_expl,
.import_expl #contenu-frame table,
.pointage_expl,
.pointage_expl #contenu-frame table,
.admin,
.admin table,
.admin #contenu tr.odd {
	background-color: #F6DCDC;
	}
.admin #contenu h3, 
.admin #contenu-frame h3, 
.admin #contenu h1,
.admin #contenu-frame h1, 
.clean #contenu h3, 
.clean #contenu-frame h3, 
.clean #contenu h1,
.launch #contenu h3, 
.launch #contenu-frame h3, 
.launch #contenu h1,
.clean #contenu-frame h1, 
.alter #contenu h3, 
.alter #contenu-frame h3, 
.alter #contenu h1,
.alter #contenu-frame h1, 
.import #contenu h3, 
.import #contenu-frame h3, 
.import #contenu h1,
.import #contenu-frame h1, 
.pointage_expl #contenu h3,
.pointage_expl #contenu-frame h3,
.pointage_expl #contenu h1,
.pointage_expl #contenu-frame h1,
.iimport_expl #contenu h3, 
.iimport_expl #contenu-frame h3, 
.iimport_expl #contenu h1,
.iimport_expl #contenu-frame h1 {
	color: #CD7171;
	}
.admin #contenu .bouton,
.admin #contenu-frame .bouton,
.clean #contenu .bouton,
.clean #contenu-frame .bouton,
.launch #contenu .bouton,
.launch #contenu-frame .bouton,
.alter #contenu .bouton,
.alter #contenu-frame .bouton,
.import #contenu .bouton,
.import #contenu-frame .bouton,
.iimport_expl #contenu .bouton,
.iimport_expl #contenu-frame .bouton,
.pointage_expl #contenu .bouton,
.pointage_expl #contenu-frame .bouton
	{
	color: #FFFFFF;
	font-size:13pt ;
	border: 1px outset #CCCCCC;
	background-color: #4A9DA2;
	}
	
.admin #contenu .bouton_small,
.admin #contenu-frame .bouton_small,
.clean #contenu .bouton_small,
.clean #contenu-frame .bouton_small,
.launch #contenu .bouton_small,
.launch #contenu-frame .bouton_small,
.alter #contenu .bouton_small,
.alter #contenu-frame .bouton_small,
.import #contenu .bouton_small,
.import #contenu-frame .bouton_small,
.iimport_expl #contenu .bouton_small,
.iimport_expl #contenu-frame .bouton_small,
.pointage_expl #contenu .bouton_small,
.pointage_expl #contenu-frame .bouton_small
	{
	color: #FFFFFF;
	font-size:8pt ;
	border: 1px outset #CCCCCC;
	background-color: #4A9DA2;
	}

.sort #contenu-frame tr.even,	
.clean #contenu-frame tr.even,
.alter #contenu-frame tr.even,
.export #contenu-frame tr.even,
.import #contenu-frame tr.even,
.iimport_expl #contenu-frame tr.even,
.admin #contenu tr.even {
	background: #EBC7C7;
	}

.form-circ, .form-mailing {
background: #BCDD95;
}
.form-circ h3,.form-mailing h3 {
color: #5DA40A;
}

.form-retour-expl {
background: #BB0000;
color: #DDF0A7;
}
.form-retour-expl h3 {
color: #DDF0A7;
}

.form-catalog {
background: #F4EC92;
}
.form-catalog h3 {
color: #C9B90B;
}

.form-autorites {
background: #B6A5FD;
}
.form-autorites h3 {
color: #806CD6;
}

.form-edit {
background: #E9EA6C;
}
.form-edit h3 {
color: #C4C612;
}

.form-dsi {
background: #B6A5FD;
}
.form-dsi h3 {
color: #806CD6;
}

.form-acquisition {
	background: #72c177;
}

.form-launch,
.form-clean,
.form-alter,
.form-export,
.form-import,
.form-admin,
.form-iimport_expl,
.form-pointage_expl {
	background: #EFC7C7;
	}
.form-launch h3,
.form-clean h3,
.form-alter h3,
.form-export h3,
.form-import h3,
.form-admin h3,
.form-iimport_expl h3,
.form-pointage_expl h3
	{
	color: #CD7171;
	}
.form-admin .usercheckbox {
	background-color: #f6dcdc;
	border-width:thin;
	border-color:#f6dcdc;
	border-style: inset;
}

.form-circ .usercheckbox {
	background-color: #CCEDA5;
	border-width:thin;
	border-color:#CCEDA5;
	border-style: inset;
}

.form-catalog .usercheckbox {
	background-color: #F4FCA2;
	border-width:thin;
	border-color:#F4FCA2;
	border-style: inset;
}

.form-dsi .usercheckbox {
	background-color: #C6B5FD;
	border-width:thin;
	border-color:#C6B5FD;
	border-style: inset;
}

.form- {
background: #222222;
}
html>body {font-size:small;}

/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                            ID FIXES                                        */
/*                                                                            */
/*  feuilles de styles appliqu�es � des id fixes                              */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/* Concerne : #navbar, #menu, iframe#alerte, #conteneur, #contenu, #login-form
   #extra, #deconnexion, #footer, #logo */

/* BARRE DE NAGIVATION #navbar */
#navbar
	{   position: absolute;
		top: 0; float:left;
		width:100%;
		background:transparent url("bg.gif");
		background-position: 0% -66px;
		background-repeat: repeat-x;
		}
    
        #navbar h3 { display: none;	}
        
        #navbar ul {
        list-style:none;
        margin-top:4px;  
		}
        
/* /BARRE DE NAGIVATION #navbar */

/*	MENU : #menu	*/
#menu
{   position: absolute;
	top: 0px;
	left: 0;
	width: 11em;
	text-align: left;
	padding: 0em;}

      #menu ul
      { background: transparent;
      	padding: 0px 0px 0px 0px;
      	margin-left: .5em;
      	margin-top: 0px;
		margin-bottom: 5px;
      	list-style-type: none;}
      
      #menu a
      { display: block;
      	font-size: 8pt;
      	text-decoration: none;
      	color: #000000;
      	background: transparent;
      	width: 11em; }
      
      #menu a:hover
      {	color: #000000;
      	text-decoration: underline; }
      
      #menu a:visited
      { color: #000000;}
      
      #menu li
      { font-size: 8pt;
      	display: block;
      	color: #000000;
      	padding-left: 12px;
      	padding-bottom: 2px;}
      
      #menu ul li a
      {	font-size: 8pt;
      	text-decoration: underline;}
      
      #menu h3
      {	padding: 0px 0px 0px 0px;
      	margin : 0px 0px 0px 0px;
      	font-size: 10pt;
      	font-weight: bold;
      	color :#000000;
      	padding-left: 5px;}
      /*	/MENU	*/

/*    MENU : #menu_horizontal    */
	.hmenu span{
		padding-right:4px;
   	}
   	
/*    MENU : #menu_horizontal    */
	.vmenu span{
		display:block;
   	}
	/* General. setpref sert lors de l'enregistrement des preferences de disposition du menu. */
	#menu h3.setpref{background:#f4ec92;}
	.circ #menu h3.setpref{background:#bcdd95;}
	.catalog #menu h3.setpref{background:#f4ec92;}
	.autorites #menu h3.setpref{background:#b6a5fd;}
	.edit #menu h3.setpref{background:#e9ea6c;}
	.dsi #menu h3.setpref{background:#b6a5fd;}
	.acquisition #menu h3.setpref{background:#72c177;}
	.admin #menu h3.setpref{background:#ebc7c7;}


iframe#alerte { 
	visibility:visible;
	position:absolute;
	left:0;
	top:600px;
	width:150px;
	border-style:none;
	border-width:0px;
	border-color:#000000;
	background:transparent;
}
.img_plus{background:#8cc6ff;}
@media screen {
/* Conteneur */
#conteneur
      {	position: absolute;
      	top: 3em;
      	width: 100%;
      	z-index:10;  }
      
/*	Contenu	*/
#contenu
	{
	position: absolute;
	top: 5%;
	right: 0;
	right: 20px;
	left: 13em;
/*	width: 80%;*/
	}
}	

     #conteneur a
      {	color: #000;
      	/* font-weight: bold; */
      	font-size: 10pt;
      	text-decoration: underline;
      	/*padding: 0 10px 0 0;*/
      	}
      
      #conteneur a:hover
      { text-decoration: underline; }

#contenu a
	{
	color: #000000;
	text-decoration: underline;
	}

#contenu .hidelink a:link	
	{
	text-decoration: none;
	}
#contenu .hidelink a:visited
	{
	text-decoration: none;
	}
/* utilise pour les paniers : c'est un tag img avec un javascript onmousedown (pas un tag a) */
#contenu .hidelink img
	{
	cursor: pointer;
	}
     
#contenu a.lien_gestion {
      	font-size: 8pt;
	text-decoration: none;
	}
#contenu a.lien_gestion:hover {
	text-decoration: underline;
	}


      
#contenu label
	{
	font-size: 9pt;
	font-weight: bold;
      	}

#contenu h1 {
	color :#E87111;
	padding-top: .5em;
	font-size: 14pt;
	}
      
#contenu h2
	{
	color : #000;
      	font-size: 12pt;
      	}
/*	/Contenu	*/

/* Login-box */
#login-box
	{
	width: 50%;
	margin-left: 25%;
	margin-right: 25%;
	}
   
#login-box
	{
	margin-top: 10%;
	}
   
#login-box label
	{
	font-size: 9pt;
	font-weight: bold;
	}

#login-box h1,
#contenu h1
	{
	color :#E87111;
      	padding-top: .5em;
      	font-size: 14pt;
      	}
/*    /Login-box    */	

/*	Contenu	frame*/
#contenu-frame {
	width: 100%;
	}


#contenu-frame a 
	{
   	color: #000;
   	text-decoration: underline;
   	}
#contenu-frame a:visited {
	text-decoration: underline;
   	color: #000000;
   	}
   
#contenu-frame a:hover
	{
	text-decoration: underline;
   	color: #000000;
   	}
  
#contenu-frame h1
	{
	color : #AB3F03;
   	padding-top: .5em;
   	font-size: 11pt;
   	}
   
#contenu-frame h2
	{
	color : #000000;
   	font-size: 10pt;
   	}
   	
/*	/Contenu-frame	*/

/*	D�connexion : #deconnexion #extra	*/
#extra
      {	position: absolute;
      	top: 0;
      	right: 0;
      	color: #000;
      	padding: 1px 10px 0 0;
      	z-index: 100;}
      
      #deconnexion a {	color: #ff0000;}
      
      #extra a { color: #000;}
      
      #extra a:hover { text-decoration: none; }
      
      /*	/Deconnexion	*/

/* footer */
#footer
{   	display: none;
      	float: right;
      	padding: 0;
      	margin: 0;
      	z-index: 0;  }
      
      #footer span,
      #footer span a
      {	
      	color:#b8da75;
      	font-size: 9pt;
      	padding : 10px 0 0 5px;
      	margin: 0 0 0 10px;}
      
      #footer a
      {text-decoration: none;}
      
/* logo */
#logo
      { position: absolute;
      	bottom: 0;
      	left: -60px;
      	/*background: transparent no-repeat bottom right url("books_small.gif");*/
      	padding: 5px;
      	margin: 0px auto;
      	width: 200px;
      	height:150px;
      	z-index: 0; }
      
      #logo span
      { display:none; }
/* /footer et logo */

/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                            BALISES HTML                                    */
/*                                                                            */
/*  feuilles de styles appliquees a des balises sans classes ni id specifiees  */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/* Concernes : form ; select ; table (tr th td) ; hr ; img ; h3                */

/*	Forms  */
form {
	margin: 0px auto;
	width: 98%;
	padding: 5px;
}

.form-contenu {
	border-bottom: 2px solid #CCCCCC;
	border-top: 2px solid #CCCCCC;
	padding: 5px;
	margin-bottom: 1em;
	padding-bottom: 1em;
	padding-top: 1em;
	}

form a {
	color: #000;
	text-decoration: underline;
}

form a:hover {
	text-decoration: none;
}


/*	/row	*/

select option,
select
{
	font-weight: bold;
}

.liste_choix_db_login {
	text-transform: none;
      	color:#BB0000;
      	font-size: 1.4em;
	font-weight: normal;
}

.liste_choix {
	text-transform: none;
      	font-size: 1.2em;
	font-weight: normal;
}

/*------------------------------------
	tableaux
/------------------------------------*/
table {
	margin: 0px auto;
	padding: 5px;
	margin-bottom: 0.2em;
	padding-bottom: 0.2em;
	padding-top: 0.1em;
	background: #fff;
   	border-collapse: collapse;
   	border: 0;
   	width: 100%;
   	}
   
   tr {
   font-style: normal;
   }
   
   th { 
   	background: #EEEEEE;
   	border-bottom: 2px solid #CCCCCC;
   	border-top: 2px solid #CCCCCC;
   	font-size: 9pt;
   	font-style: italic;
   	text-align: left; 
   	}
   
   td {	
   	text-align: left; }
   
   tr.surbrillance {
	background-color: #7FA5DE;
	}
	
	tr.justmodified {
	background-color: #7FA5DE !important;
	}

   .table-no-border {
	border: none; }

/* Documents numeriques dans les tableaux */
table.docnum
	{	background: none;
	border-collapse: collapse;
	border-right: 0px ;
	border-left: 0px ;
	border-top: 0px ;
	border-bottom: 0px ;
	width: 98%;}

td.docnum
	{	border-bottom: 0px ;
	border-top: 0px ;
	text-align: center;}

/*------------------------------------
/	/Tableaux
/------------------------------------*/

hr
	{ width:96%;
	height: 0;
	color: #000000;
	padding: 0;
	margin-bottom: 10px;
	margin-top: 10px;
	}

.row hr
	{ width:96%;
	height: 0;
	color: #000000;
	padding: 0;
	margin-bottom: 10px;
	margin-top: 10px;
	}

#contenu-frame .row hr
	{ width:96%;
	height: 0;
	color: #000000;
	padding: 0;
	margin-bottom: 10px;
	margin-top: 10px;
	}

img {
	border: 0; 
	vertical-align: middle;
}

h3
{	clear: both;
	display: block;
	margin-bottom: 2px;
	margin-top: 4px;
	padding-bottom: 1px;
	padding-top: 1px;
	color: #3740B4;}

/* les elXParent restent ici avec les h3 pour faciliter la lecture */
#el0Parent h3, 
#el1Parent h3,
#el2Parent h3,
#el3Parent h3,
#el230Parent h3,
#el4Parent h3,
#el5Parent h3,
#el6Parent h3,
#el7Parent h3,
#el8Parent h3,
#el9Parent h3,
#el10Parent h3,
#el11Parent h3,
#el30Parent h3,
#el41Parent h3,
#elbulParent h3,
#el14Parent h3
  {
	font-size: 11pt;
	margin-bottom: 0px;
	margin-top: -1px;
	}

/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                            CLASSES GENERIQUES                              */
/*                                                                            */
/*  feuilles de styles appliqu�es � classes de balises                        */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/* Concerne :           .erreur .hide                                         */
/*     .aide .astuce .bool .row .etiquette .saisie-inline . saisie-XXXem      */
/*     .saisie-XXXemr .right .right-... .left .left-... .spacer               */
/*     .saisie-contenu .bouton .



/* ***********************/
.col
{	float: left;
	width: 100%;
	padding: 1em;
	margin: 1em; }

.erreur {
	color: #f00;
	font-weight: bold;
	font-size: 16px;
}	

.erreur-child
{
	display:none;
	margin-left: 12%;
    padding:0;
    color:#000;
    font-weight:normal;
}	


.hide { display: none; }

.aide
{ cursor: help; }

.astuce
{ 	
	font-size: 10pt;
	margin-top: 1em; }

.bool
{ 	font-family: fixed;
	font-weight: bold; }

.row {   clear: both; }

.saisie-5emr,
.saisie-10emr,
.saisie-15emr,
.saisie-20emr,
.saisie-30emr,
.saisie-50emr,
.saisie-80emr {	
	background-color: #DFB;
	border: 1px solid #684;
}

.spacer
{	clear: both;
	visibility: hidden;
	display: none;
	margin-bottom: -10px;
	margin-top: -10px;
	}

.saisie-contenu
{	padding-left: 12px;
	padding-top: .3em;
	margin-top: .2em;
	}

.fond-mere {
	background-color: #4f72ff;
	}

.fond-article {
	background-color: #68df00;
	}

/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                            CLASSES LIEES A L'APPLICATION                   */
/*                                                                            */
/*  feuilles de styles appliqu�es � des balises sans classes ni id sp�cifi�es  */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
.notice-perio
{	border-top: 1px solid #684;
	border-bottom: 1px solid #684;
	border-left: 1px solid #684;
	border-right: 1px solid #684;
	padding: 1em;
	margin-bottom: 1em;
	margin-top: 1em;}

.onglets-perio {
	border:2px #684 solid;
    border-bottom:0px #776655 solid;
    text-align:center;
    background:#F4EC92;
    padding:4px;
    margin-left:4px;
	cursor:pointer;
}

.onglet-perio-selected {
	border:2px #684 solid;
	border-bottom:1px #FAF5BC solid;
    text-align:center;
    background:#FAF5BC;
    padding:4px;
    margin-left:4px;
    cursor:default;
}

#content_onglet_perio {
	margin:0px;
	padding:0px;
}
	#content_onglet_perio a{text-decoration:none;}
	#content_onglet_perio a:hover{text-decoration:none;}
.bulletins-perio
{	border-top: 1px solid #684;
	border-bottom: 1px solid #684;
	border-left: 1px solid #684;
	border-right: 1px solid #684;
	padding: 1em;
	margin-bottom: 1em;
	margin-top: 2px;} 

.bulletins-perio h2 blockquote {
		font-size:0.8em;
		font-weight: normal;
}	
.depouillements-perio
{   border-top: 1px solid #684;
	border-bottom: 1px solid #684;
	border-left: 1px solid #684;
	border-right: 1px solid #684;
	padding: 1em;
	margin-bottom: 1em;
	margin-top: 1em; }
	
.msg-perio {
	font-size: 150%;
	font-weight: bold;
	color: #f00;	}
	
/* barre fl�ch�e en p�rio */
.perio-barre {
	font-size: 120%;
	font-weight: bold;
}

/* classes pour l'affichage de liste d�pliantes en r�sultat de recherche*/
.notice-heada {
	text-decoration: none;
	font-size: 10pt;
	font-weight: bold;
}
.notice-parent {
    color: #000000;
    margin-left: 0px;
    padding-bottom: 4px;
    padding-top: 4px;
    text-decoration: none;
}
.notice-child {
    font-size: 0.9em;
    margin-left: 30px;
    margin-bottom: 15px;
    width: 98%;
    padding-left: 4px;
    padding-right: 4px;
    text-align: justify;
    border-bottom-style: solid;
    border-bottom-width: 1px;
    border-bottom-color: #c0c0c0;
    border-left-style: solid;
    border-left-width: 1px;
    border-left-color: #c0c0c0;
    border-right-style: none;
    border-top-style: none;
}

.notice-child table td img.img_notice {
    max-width: 140px;
	max-height: 200px;
	width: expression(this.width > 140 ? "140px" : true);
	height: expression(this.height > 200 ? "200px" : true);
}

table td .img_notice {
    max-width: 140px;
	max-height: 200px;
	width: expression(this.width > 140 ? "140px" : true);
	height: expression(this.height > 200 ? "200px" : true);
}

.notice-bu {
	margin-top: 0px;
	background-color: transparent;
	border-style: none; }

/* classes pour l'affichage de liste d�pliantes en formulaire de saisie de notice */
.heada {
		font-size: 10pt;
		font-weight: bold;
		}
.parent {
	color: #000000;
	margin-left: 0px;
	font-size: 8pt;
	text-decoration: none
	}
.child {
	margin-left: 30px;
	}
.bu {
	margin-top: 15px;
	}

.titre-panier
{ border-top: 1px solid #684;
	border-bottom: 1px solid #684;
	border-left: 1px solid #684;
	border-right: 1px solid #684;
	padding: 1em;
	margin-bottom: 1em;
	margin-top: 1em;
	}

#history_table {
	border:0px;
	padding:0px;
	margin:0px;
	background:transparent;
}

#history_table td {
	padding:0px;
	margin:0px;
	border:0px;
}

/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                       MODIFICATIONS POUR L'IMRPESSION                      */
/*                                                                            */
/* pour l'impression, masquage de #navbar, #menu, #deconnexion, #extra,       */
/* iframe#alerte et des boutons de classe .bouton; #contenu colles a gauche    */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/


@media print {
  #conteneur 	{
		position: relative;
		clear:both;
		}

  #navbar
	{ display: none; }
  #menu
	{ display: none;}


  /*	Menu	*/
  #deconnexion 
	{ display: none; }
  #extra
	{ display: none; }
  .bouton
	{ display:none; }
  .bouton_small
	{ display:none; }

  iframe#alerte
	{ visibility:hidden;	}
}
iframe#history {
	width:40%;
	height:97%;
	position:absolute; 
	top:1%; 
	left:1%;
	z-index:1000;
	}
	
* HTML iframe#history {
	height:580px;
	}
/* pour affichage de pav�s de couleur pour disinction des statuts de notices */
.statutnot1 {
	}
.statutnot2 {
	background-color: #BB0000;
	}
.statutnot3 {
	background-color: #00BB00;
	}
.statutnot4 {
	background-color: #0000BB;
	}
.statutnot5 {
	background-color: #D0686F;
	}
.statutnot6 {
	background-color: #A6DCDC;
	}
.statutnot7 {
	background-color: #816492;
	}
.statutnot8 {
	background-color: #BCB964;
	}
.statutnot9 {
	background-color: #6C75AC;
	}
.statutnot10 {
	background-color: #FFC587;
	}
.statutnot11 {
	background-color: #70C173;
	}
.statutnot12 {
	background-color: #660000;
	}
.statutnot13 {
	background-color: #006600;
	}
.statutnot14 {
	background-color: #000066;
	}
.statutnot15 {
	background-color: #80181F;
	}
.statutnot16 {
	background-color: #668C8C;
	}
.statutnot17 {
	background-color: #311442;
	}
.statutnot18 {
	background-color: #7C7914;
	}
.statutnot19 {
	background-color: #2C356C;
	}
.statutnot20 {
	background-color: #BF8547;
	}

.gris {
	color: grey;
}

.message_important {
	color: #f00;
	font-weight: bold;
	font-size: 1.5em;
	padding:5px;
	margin:5px;
	}
	
ul.sel_navbar {
	width:100%;
      margin-top:-5px;
      margin-left:-5px;
      margin-bottom:1px;
      padding:0px;
      list-style:none;
	  border-bottom:1px solid #666666;  
      clear:right;
      float:left;
}

ul.sel_navbar li {
	float:left;
	padding:3px 6px 0px 6px;
    border:1px solid #666666;  
    margin-left:3px;
    margin-bottom:-1px;
    background:#999999;
	color:#000000;
}

ul.sel_navbar li a {
	text-decoration:none;
	font-weight:normal;
	color:#000000;
}
      
ul.sel_navbar li.sel_navbar_current {
	float:left;
  	padding:3px 6px 0px 6px;
  	background:#FFF0A7;
	border :1px solid #666666;  
	border-bottom:1px solid #FFF0A7;
}

.dsi table.dsi tr td:hover {
	background:#5F85BE;
}


#frame_notice_preview {
 border:2px solid #777799;
 border-radius:5px 5px; 
 -moz-border-radius:10px;
 padding:10px;
 z-Index:1000;
 position:absolute;
 background: #F4EC92;
 display:none;
 width:680px;
 height:500px;
}

#frame_periodique {
 border:2px solid #777799;
border-radius:5px 5px;
 -moz-border-radius:10px;
 padding:10px;
 z-Index:1000;
 position:absolute;
 background: #FFF0A7;
 display:none;
 width:190px;
 height:250px;
}

#expl-form select {
	width: 215px;
}
	
#frame_abts {
 border:2px solid #777799;
 border-radius:5px 5px;
 -moz-border-radius:10px;
 padding:10px;
 z-Index:1000;
 position:absolute;
 background: #FFF0A7;
 display:none;
 width:190px;
 height:250px;
}

#frame_trans_expls {
 border:2px solid #777799;
 border-radius:5px 5px;
 -moz-border-radius:10px;
 padding:10px;
 z-Index:1000;
 position:absolute;
 background: #ddf0a7;;
 display:none;
 width:500px;
 height:250px;
}

#a_recevoirChild .colonne_suite input {
	margin-right:20px;
}

.form-acquisition>.form-contenu #tot_ht, #tot_tva, #tot_ttc, #adr_fou, #adr_liv, #adr_fac, #tot_expl, #devise[class=saisie-5emd]{	
	border: 1px solid #aaa;
}

.req_cell {
	table-layout:fixed;
}
.req_cell th,
.req_cell td {
	border:1px solid #000000;
	border-collapse:collapse;
	padding-right:4px;	
	vertical-align: top;
}
.req_cell .col_ali {
	width:10%;
}
.req_cell .col_get,
.req_cell .col_vis,
.req_cell .col_grp,
.req_cell .col_tri {
	width:20px;
	padding-right:0px;
}
.req_cell .col_act,
.req_cell .col_obl {
	width:50px;
	padding-right:0px;
}
.req_cell .up_bt {
	vertical-align:top;
	cursor:pointer;	
}
.req_cell .down_bt {
	vertical-align:bottom;
	margin-left:-16px;
	cursor:pointer;	
}
.req_cell .stop_bt,
.req_cell .cross_bt,
.req_cell .add_bt {
	vertical-align:middle;
	width:16px;
	cursor:pointer;	
}

.in_cell,
.in_cell_nb,
.in_cell_ro,
.in_cell_nb_ro {
	width:99%;
	border:1px solid;
}
.in_cell_nb,
.in_cell_nb_ro {
	text-align:right;
}
.in_cell_ro,
.in_cell_nb_ro {	
	background-color: #DFB;
	border: 1px solid #684;
}

.in_cell_text {
	width:95%;
	border:1px solid;
}
.in_cell_rd,
.in_cell_ld {
	width:100%;	
	background-color:transparent;
	border-color:transparent;
	border-width:0;
}
.in_cell_rd {
	text-align:right;	
}
.in_cell_ld {
	text-align:left;
}

.req_ajax_div {
	border:1px #000 solid;
	left:0px;
	top:0px;
	position:absolute;
	background-color:#FFFFFF;
	z-Index:1000;
	height:200px;
	overflow:auto;
	display:none;
}

.req_row_handler {
	margin-left:5px;
	top:0px;
	cursor:pointer;	
}

#req_frame {
	border:2px solid #777799;
	border-radius:5px 5px;
	-moz-border-radius:10px;
	padding:5px;
	z-Index:1000;
	position:absolute;
	background: #FFF0A7;
	display:none;
}

 .req_cell .bt_cross_elt,
 .req_cell .bt_add_arg {
 	vertical-align:bottom;
 	width:12px;
	cursor:pointer;
 }
 .req_cell .bt_cross_fct {
	vertical-align:bottom;
	margin-left:-10px;
 	width:12px;
	cursor:pointer;
  }

 .req_container  {
 	margin-left:5px;
 	padding-left:3px;
 	/*border-bottom:1px inset black;*/
 	border-left:1px dashed #ACACAC;
 	font-size: 5pt; 	
 	font-weight: bold;
 }
 
.act_cell {
	table-layout:fixed;
}
.act_cell th,
.act_cell td {
	border:1px solid #000000;
	border-collapse:collapse;
	padding-left:2px;
	padding-right:2px;
	vertical-align:top;	
	overflow:hidden;
}
.act_cell_chkbox {
	width:25px;
} 
.act_cell_img_plus {
	background:#8cc6ff;
	margin-left:-20px;
}
.act_cell_chkbox2 {
	margin-right:-20px;
}
.act_cell_comments table,
.act_cell_reminders table
{
	margin-top:0px;
	margin-bottom:0px;
}

.act_cell_comments tr,
.act_cell_reminders tr {
	background : #A6D1A9;
}
.act_cell_comments td,
.act_cell_reminders td
{
	margin-top:0px;
	margin-bottom:0px;
	border:none;
}

/**
 *  Couleur de fond et de liens du calendrier
 *
 **/
#calendrier_tab td.lien_date a{
	color:white;
}
#calendrier_tab td.lien_date {
	background:green;
}
#calendrier_tab td.lien_date_hs {
	background:red;
}
#calendrier_tab td.lien_date_hs_p {
	background:orange;
}
#up_frame{
	display:none;
	border:2px solid #777799;
	-moz-border-radius:10px;
	-webkit-border-radius:10px;
	border-radius:10px;
	padding:10px;
	z-Index:1000;
	position:absolute;
	background: #eee;
}
.recorded {
	color: #cc0000;
	font-weight: bold;
}
.pbar {
	width:710px;
	text-align:center;
}
.pbar_frame {
	border:#000000 1px solid;
	padding:4px;
}
.pbar_gauge {
	text-align:left;
}
#pbar_img {
	height: 16px;
	width:0px;
}

.dom_div {
	overflow:auto;
}
.dom_tab {
	table-layout:fixed;	
}
.dom_col {
	overflow:hidden;
	width:200px;
}
.dom_cell_tab {
	border:#000000 1px solid;
	overflow:hidden;
}

.dom_tab2 {
	display: table;
}
.dom_row2 {
	display: table-row;
	height: 140px;
}
.dom_col2 {
	display: table-cell;
}
.dom_cell2_h {
	display: block;
	width: 200px;
	height: 140px;
	overflow: hidden;
	background: none repeat scroll 0 0 #EEEEEE;
	border: 1px solid #CCCCCC;
	font-weight: bold;
	text-align: center;
}
.dom_cell2 {
	display: block;
	height: 140px;
	overflow: hidden;
	background: none repeat scroll 0 0 #F6DCDC;
	border: 1px solid #CCCCCC;
}
.dom_sel {
	width: 190px;
}
/*Suggestions multiples */
.tab_sug {
	table-layout: fixed;
}

table{
	border-collapse:collapse;
	margin: 10px 0;
	width:100%;
}
.tab_sug th, .tab_sug td{
	border:1px solid #CCCCCC;	
	/*vertical-align:center;*/
	text-align: center;
	overflow:scroll;
	width:100%;
}

.tab_sug  input, .tab_sug textarea{
   width:95%;
   height:100%;
   background:#F3F3F3;
}
.tab_sug select{
	width:95%;
}


.erreur_saisie {
	background-color: #ff0000;
}

table.sortable tr td {
	padding-top: 0px;
	padding-bottom: 0px;
	padding-left: 5px;
	padding-right: 5px;	
}

#recept_frame {
	border:2px solid #777799;
	border-radius:5px 5px;
	-moz-border-radius:10px;
	padding:5px;
	z-Index:1000;
	position:absolute;
	background: #C0F1C3;
	display:none;
}

#f_ex_note, #f_ex_comment {
	width: 90%;
}

body.alter h2 .bdd_version {
	font-size: 15px;
}

.notice-parent .left {
	margin-left: 5px;
    float: none;
}

.notice-parent .right {
	margin-top: -15px;
    text-align: right;
    float: none;
}

/*********************************
*    CATALOGUE - SEGMENTATION    *
*********************************/

body.catalog #conteneur #contenu form #speech_timeline #speech_timeline_edit_menu ul {
	background-color: #FAF5BC;
    box-shadow: -1px 0 3px #999999 inset;
    border-radius: 5px;
    color: #000000;
    font-size: 8pt;
    text-decoration: underline;
    padding: 1px 3px;
    margin-left: -16em;
    margin-top: calc(-1.84em - 15pt);
}

body.catalog #conteneur #contenu form #speech_timeline #speech_timeline_edit_menu ul li {
	background-color: #FAF5BC;
    box-shadow: -1px 0 3px #999999 inset;
    padding: 3px 10px;
    margin-bottom: 2px;
    margin-top: 2px;
    cursor: pointer;
    list-style-type: none;
}