/* pour les mises en pages sur deux colonnes */


.colonne2 {
  float: left;
  width: 50%;
}

.colonne60 {
  float: left;
  width: 60%;
}

.colonne40 {
  float: left;
  width: 40%;
}

.colonne_suite {
  float: left;
}

/* pour les mises en pages sur 4 colonnes */
.colonne4 {
  float: left;
  width: 25%;
}

/* pour les mises en pages sur 5 colonnes */
.colonne5 {
  float: left;
  width: 20%;
}

/* pour les mises en pages sur 3 colonnes */
.colonne3 {
  float: left;
  width: 33%;
}

/* pour avoir une colonne toute petite ! */
.colonne10 {
  float: left;
  width: 10%;
}

.colonne80 {
  float: left;
  width: 80%;
}


/* une colonne entete de table */
.colonneth {
   	border-top: 1px solid #aaa;
   	border-right: 1px solid #aaa;
   	border-bottom: 1px solid #aaa;
   	border-left: 1px solid #aaa;
   	font-weight: bold;
   	text-align: left; 
   	padding: 3px 10px;
	white-space: nowrap;
   	overflow: hidden;
	background: #ccc;
}

/* une colonne table */
.colonnetd {
	border: 1px solid #CCCCCC;
	border-top: 0px;
	padding: 3px 10px;
	white-space: nowrap;	
   	overflow: hidden;
	height: 40px;
}

		
.content {
    padding: 8px 12px 12px 12px;
    border: 1px solid #666;
    z-index: 500;
    background-color: #f3f6f9;
}
          
.content .padder {
    height: 200px;
}
     
div.tabs {
	font-size: 14px;
    line-height: 16px;
	position: absolute;
    top: 11px;
    left: 174px;
    white-space: nowrap;
    cursor: default !important;
    z-index: 1000;
}

.content div.tabs {
    top: 20px;
    left: 52px;
}
      
.tab {
    border: 1px solid #347;
    background-color: #bcd;
    color: #303036;
    padding: 3px 3px 3px 3px;
    z-index: 100;
}

.tabHover {
    background-color: #46596f;
    color: #ffffff;
    z-index: 1200;
}

.tabActive { 
	padding: 3px 9px 3px 9px;
 	color: #060610 ;
	background-color: #f3f6f9;
	z-index: 10000;
}
      
#viewsrc {
	width: 130px;
	border: 1px solid #003;
	margin: 8px;
	background-color: #f3f6fc;
}

