/* +--------------------------------------------------------------------------+
// 2011 PMB Services / www.sigb.net pmb@sigb.net et contributeurs (voir www.sigb.net)
// +-------------------------------------------------+
// $Id: pmb4.css,v 1.37 2013-06-13 09:13:02 trenon Exp $ */


/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                         ATTRIBUTS GENERAUX                                 */
/*                                                                            */
/*                     attrbitus generaux de la page                          */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/


* {
	margin: 0px;
	padding: 0px;	
}

body#pmbopac {
	background-color: #eeeeee;
	background-image: url("images/fond.jpg");
	background-position: center top;
	background-repeat: no-repeat;
	color: #444444;
}

body {
	font-family: 'Dosis', sans-serif;
	font-weight: 500; 
	font-size : 13px;
}

#container {
	margin: 0px auto;
	width: 980px;
	position: relative;
}


/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                                  IFRAME                                    */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/


/* -----------------------------------------------------*/
/*                         Panier                       */
/* -----------------------------------------------------*/


#resume_panier {
	margin-bottom: 0px !important;
	border-bottom: none !important;
    padding-bottom: 0px !important;
}

body.cart_info_body {
	background-color : transparent;
	font-family : arial, verdana, helvetica, sans-serif;
	margin: 0px;
	font-size: 13px;
	font-weight: bold;
}

iframe#iframe_resume_panier {
	width:100%;
	height:35px;
	border:none;
}

#cart_action {
	margin-bottom: 20px;
}


/* --------------lien panier----------------*/


body.cart_info_body a {
	color: #2C2E8C;
	text-decoration: underline;
}

body.cart_info_body a:hover {
	-moz-text-shadow: 0px 0px 2px #ffffff;
	-webkit-text-shadow: 0px 0px 2px #ffffff;
	text-shadow: 0px 0px 2px #ffffff;
	text-decoration: none;
}


/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                            Intro_bibli                                     */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/


#intro {
	position: absolute;
	top: 0px;
	width: 966px;
	height: 125px;
	padding-left: 15px;
	padding-top: 15px;
}

#intro_bibli h3 {
	display: none;
}


/* -----------------------------------------------------*/
/*                 biblio_preamble_p1                   */
/* -----------------------------------------------------*/


#intro .p1 {
	height: 165px;
	width: 165px;
	padding-top: 10px;
	padding-right: 10px;
	padding-left: 10px;
	padding-bottom: 10px;
	background-color: #2c2e8c;
	-moz-transform: rotate(-5deg);
	-webkit-transform: rotate(-5deg);
	-o-transform: rotate(-5deg);
	-ms-transform: rotate(-5deg);
	transform: rotate(-5deg);
	text-align: center;
	border-top: 1px solid #6669C4;
	border-bottom: 1px solid #101360;
	position: absolute;
}

#intro .p1 img {
	-moz-transform: rotate(5deg);
	-webkit-transform: rotate(5deg);
	-o-transform: rotate(5deg);
	-ms-transform: rotate(5deg);
	transform: rotate(5deg);
}


/* ou */

/*
#intro .p1 {
	text-align: center;
	position: absolute;
	left: 30px;
}

#btn {
	height: 165px;
	width: 165px;
	position: absolute;
	z-index: 2;
	background-color: #d6dbde;
	background: -webkit-linear-gradient(bottom, rgb(215,219,222) 0, rgb(216,220,221) 60%, rgb(193,199,202) 100%);		
	background: -moz-linear-gradient(bottom, rgb(215,219,222) 0, rgb(216,220,221) 60%, rgb(193,199,202) 100%);
	background: linear-gradient(bottom, rgb(215,219,222) 0, rgb(216,220,221) 60%, rgb(193,199,202) 100%);
	-webkit-box-shadow: inset 0px 0px 5px rgba(0,0,0,.2), 0px 1px 1px rgba(0,0,0,.5);
	-moz-box-shadow: inset 0px 0px 5px rgba(0,0,0,.2), 0px 1px 1px rgba(0,0,0,.5);
	box-shadow: inset 0px 0px 5px rgba(0,0,0,.2), 0px 1px 1px rgba(0,0,0,.5);
	text-align: center;
	-moz-border-radius: 5px;
	-webkit-border-radius: 5px;
	border-radius: 5px;
	line-height: 35px;
	color: #4a66a7;
	font-family: 'lucida grande', tahoma, verdana, arial, sans-serif;
	font-size: .8em;
	font-weight: bold;
	
	-webkit-perspective: 1000;
	-webkit-perspective-origin: 50% 0;
		
	-moz-perspective: 1000;
	-moz-perspective-origin: 50% 0;
	
	perspective: 1000;
	perspective-origin: 50% 0;
}
	
#btn a {
	display: block;
}
	
#btn a img {
	width: 150px;
	margin-top: 39px;
	margin-bottom: 10px;
}
	
#pmb_services {
	height: 165px;
	width: 165px;
	text-indent: -9999px;
	cursor: pointer;
	position: relative;
	bottom: 100%;
		
	-webkit-transform-origin: bottom;
	-webkit-transform-style: preserve-3d;
	-webkit-transition: -webkit-transform .4s ease;
	-webkit-transform: translateY(0) rotateX(0);
		
	-moz-transition: -moz-transform .4s ease;
	-moz-transform: translate(0);
}

#shadow {
	display: block;
	width: 180px;
	height: 0px;
	position: absolute;
	z-index: -1;
	top: 160px;
	left: -5px;
	-webkit-transition: height 1s ease, opacity .5s ease;
	-moz-transition: height 1s ease, opacity .5s ease;
	opacity: 0;
}
	
#shadow img {
	width: 100%;
	height: 100%;
	float: left;
}
		
.top {
	position: absolute;
	width: 165px; 
	height: 5px;
	top: 0;
	left: 0;
	background-color: rgba(28,30,124,1);
	
	-webkit-transform-origin: top;
	-webkit-transform: rotateX(-90deg);
	-webkit-transition: background-color .5s ease-out;
	
	-moz-transform-origin: top;
	-moz-transform: rotateX(-90deg);
	-moz-transition: background-color .5s ease-out;
}

.logo {
	position: absolute; 
	background: rgba(0,0,0,1) url(images/pmb_services.jpg) no-repeat;
	width: 100%; 
	height: 100%;
}

.recto {
	background-color: rgba(0,0,0,0);
	display: block;
	width: 100%;
	height: 100%;
	-webkit-transition: background-color .5s ease-in;
	-moz-transition: background-color .5s ease-in;
}
	
.verso {
	-webkit-transform: rotateX(-180deg) translateZ(5px);
}

#btn:hover #pmb_services {
	-webkit-transform: translateY(5px) rotateX(-120deg);
	-moz-transform: translate(0px, 35px);
}
	
#btn:hover #shadow { height: 45px; opacity: .5}
*/


/* -----------------------------------------------------*/
/*                 biblio_preamble_p2                   */
/* -----------------------------------------------------*/


#intro .p2 {
	height: 105px;
	position: absolute;
	top: 35px;
	left: 225px;
	width: 755px;
}

#titre_bienvenue {
	-moz-transform: rotate(-4deg);
	-webkit-transform: rotate(-4deg);
	-o-transform: rotate(-4deg);
	-ms-transform: rotate(-4deg);
	transform: rotate(-4deg);
	color: #ffffff;
	text-shadow: 0px 0px 3px #2C2E8C;
	font-family: arial, helvetica, sans-serif;
	font-weight: bold;
	font-size: 24px;
}

#menuDeroulant {
	bottom: 0px;
    margin-left: 3%;
    margin-right: 3%;
    position: absolute;
}

#menuDeroulant li {
	position: relative;
}

#menuDeroulant li a {
	font-size: 18px;
	text-decoration: none;
}

#menuDeroulant li a:hover {

}


/******************* sous-menu ********************/


#menuDeroulant .sousMenu {
    display: none;
    width: 150px;
    position: absolute;
    left: 0px;
    top: 30px;
    z-index: 100;
}

#menuDeroulant .sousMenu li {
    display: block;
    width: 100%;
    opacity : 0.9;
    filter : alpha(opacity=90);   
}

#menuDeroulant .sousMenu li:hover {
    opacity : 1;
    filter : alpha(opacity=100);
}

#menuDeroulant .sousMenu li a {
    font-size: 16px;
}

#menuDeroulant li:hover > .sousMenu {
    display: block;
}


/******************* sous-sous-menu ********************/


#menuDeroulant .sousMenu2, .cms_menu_deep2 {
    margin-left: 150px;
}


/* pour les menus du portail */


.cms_menu_deep0 li {
    position: relative;  
    display: block;
    float: left;
}

.cms_menu_deep1 {
    display: none;
    width: 150px;
    position: absolute;
    left: 0px;
    top: 24px;
    z-index: 100;
}

.cms_menu_deep1 li {
    display: block;
    width: 100%;
    opacity : 0.9;
    filter : alpha(opacity=90);   
}

.cms_menu_deep1 li:hover {
    opacity : 1;
    filter : alpha(opacity=100);
}

.cms_menu_deep1 li a {
    font-size: 16px;
}

.cms_menu_deep0 li:hover > .cms_menu_deep1 {
    display: block;
}


/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                            Contenu du Bandeau                              */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/


#bandeau { 
	padding-left: 20px;
	padding-right: 20px;
	padding-top: 20px;
	padding-bottom: 20px;
    position: absolute;
    top: 240px;
    left: -10px;
    width: 200px;
    background-color: #d6de39;
    -moz-box-shadow: 0px 0px 5px #666666;
	-webkit-box-shadow: 0px 0px 5px #666666;
	box-shadow: 0px 0px 5px #666666;
	border-top: 1px solid #F1F3BA;
	border-bottom: 1px solid #C7CE46;
}

#bandeau div {
	margin-bottom: 20px;
}

#bandeau div div {
	margin-bottom: 0px;
}

#bandeau a { 
	color: #2C2E8C;
	text-decoration: underline;
}


/* -----------------------------------------------------*/
/*                        Accueil                       */
/* -----------------------------------------------------*/


#accueil h3, #accueil p.centered {
	display: none;
}


/* ------------lang_select------------*/


#lang_select h3 {
	display: none;
}


/* -----------------------------------------------------*/
/*                      Connexion                       */
/* -----------------------------------------------------*/


#connexion {
}

#login_form form label, #login_form form br {
	display: none;
}

#login_form b {
	font-size: 15px;
}

#login_form a {
	font-size: 12px;
}


/* ---------------Input---------------*/


input.login, input.password {
	width: 95px;
	margin-bottom: 3px;
}

#login_form input.bouton {
	text-transform: uppercase;
	padding-left: 5px;
	padding-right: 5px;
	text-align: center;
}


/* -----------------------------------------------------*/
/*                       Adresse                        */
/* -----------------------------------------------------*/


#adresse {

}


/* -----------------------------------------------------*/
/*                 biblio_post_adress                   */
/* -----------------------------------------------------*/


#post_adress {

}


/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*             Affichage aléatoire si placement dans le bandeau               */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/


#bandeau ul li a {
	color: #ffffff !important;
	text-decoration: none !important;
}

#bandeau ul.search_tabs li a:hover {
	color: #2C2E8C !important;
	background: #ffffff;
}

#bandeau ul.search_tabs li#current {
	color: #e1e774 !important;
	background: #ffffff !important;
}

#bandeau #search select[name='typdoc'], #bandeau #search select[name='cnl_bibli'] {
	width: 195px;
}

#bandeau form input.text_query {
	width: 173px;
	margin-bottom: 5px;
}

#bandeau #search #zsimplesChild {
	width: 370px !important;
}

#bandeau #search .notice-parent {
    border-bottom: none !important;
}

#bandeau .notice-parent {
    border-bottom: 1px dotted #ffffff !important;
}

#bandeau .notice-child {
    width: 400px;
}


/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                            Contenu du Bandeau 2                            */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/


#bandeau_2 { 
	padding-left: 20px;
	padding-right: 20px;
	padding-top: 20px;
	padding-bottom: 20px;
    position: absolute;
    top: 240px;
    right: 0px;
    width: 125px;
}


/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                            Contenu du Main                                 */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/


#main {
    margin-top: 140px;
    padding-right: 165px;
    padding-left: 250px;
	padding-bottom: 50px;
	padding-top: 10px;
	background-color: #ffffff;
	position: absolute;
	width: 550px;
	border: 10px solid rgba(255,255,255,0.4);
	-moz-box-shadow: 0px 0px 5px #666666;
	-webkit-box-shadow: 0px 0px 5px #666666;
	box-shadow: 0px 0px 5px #666666;
	-moz-background-clip: padding; /* for Mozilla browsers*/
	-webkit-background-clip: padding;   /* Webkit */
	background-clip: padding-box; /*  browsers with full support */
}

#main_hors_footer {
	min-height: 615px;
	padding-bottom: 5px;
}

#main_hors_footer div {
	margin-bottom: 25px;
}

#main_hors_footer div div {
	margin-bottom: 0px;
}


/* ---------------------------------------------------------------------------*/
/*                                Main_header                                 */
/* ---------------------------------------------------------------------------*/


#main_header {
	text-align: justify;
}


/* -----------------------------------------------------*/
/*                     Intro_message                    */
/* -----------------------------------------------------*/


#main_hors_footer #intro_message {
	border-bottom: none !important;
	margin-bottom: 0px;
}


/* --------biblio_important_p1-----------*/

#intro_message .p1 {
	margin-bottom: 20px;
}


/* -----------------------------------------------------*/
/*                        Navigator                     */
/* -----------------------------------------------------*/


#navigator {
	border-bottom: none !important;
}

#navigator a {
	padding-left: 10px;
	padding-right: 10px;
	padding-top: 2px;
	padding-bottom: 2px;
	display: block;
	-moz-border-radius: 5px;
	-webkit-border-radius: 5px;
	border-radius: 5px;
}


/* -----------------------------------------------------*/
/*                        Search                        */
/* -----------------------------------------------------*/


#search ul.search_tabs {
    font-size: 13px;
}

#search ul.search_tabs li {
    margin-bottom: 3px;
}

#search ul.search_tabs li#current {
	border-top: 1px solid #f1f3ba;
	border-bottom: 1px solid #c7ce46;
	color: #ffffff;
	font-weight: bold;
	padding-left: 10px; 
	padding-right: 10px; 
	padding-top: 3px; 
	padding-bottom: 3px;
	-moz-border-radius: 5px;
	-webkit-border-radius: 5px;
	border-radius: 5px;
	background: #e1e774; /* Old browsers */
	background: -moz-linear-gradient(top,  #e1e774 0%, #d8e03c 100%); /* FF3.6+ */
	background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#e1e774), color-stop(100%,#d8e03c)); /* Chrome,Safari4+ */
	background: -webkit-linear-gradient(top,  #e1e774 0%,#d8e03c 100%); /* Chrome10+,Safari5.1+ */
	background: -o-linear-gradient(top,  #e1e774 0%,#d8e03c 100%); /* Opera 11.10+ */
	background: -ms-linear-gradient(top,  #e1e774 0%,#d8e03c 100%); /* IE10+ */
	background: linear-gradient(to bottom,  #e1e774 0%,#d8e03c 100%); /* W3C */
	filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#e1e774', endColorstr='#d8e03c',GradientType=0 ); /* IE6-9 */
}

#search p.p1 {
	margin-bottom: 5px;
}

#search_crl {
	clear: left;
}

#search form select {
	margin-right: 10px;
}

#search input.text_query {
	width: 360px;
}

#simple_search_zone {
	margin-top: 10px;
}

#zsimples {
	border-bottom: none !important;
	padding-bottom: 0px;
}

#zsimplesChild {
	border-bottom: none;
	margin-bottom: 0px !important;
	width: auto !important;
}

#zsimples .notice-heada {
	color: #000000;
}


/*----Recherche multi-criteres----*/


.ext_search_txt {
	width: 260px;
}

#external_simple_search_zone {
	margin-top: 15px;
}

#search form .form-contenu br {
	display: none;
}


/*------Recherche par termes------*/


iframe.frame_term_search {
	border: 1px solid #A79E86 !important;
}

.colonne_suite a, .colonne2 a {
	font-size: 12px;
}


/*-------Recherche externe-------*/


#search .row form .row span {
	padding-top: 5px;
}


/*-----Resultats de recherche-----*/


#search_result {
	margin-bottom: 20px;
}

#resultatrech h3 span {
	font-size: 13px;
}

#resultatrech_liste blockquote {
	margin-top: 20px;
	margin-left: 0px;
}


/*-----Onglets de recherche-----*/


#search_onglet ul.search_tabs {
}

#search_onglet ul.search_tabs li {
	margin-right: 3px;
}

#search_onglet ul.search_tabs li.current a {
	border-top: 1px solid #f1f3ba;
	border-bottom: 1px solid #c7ce46;
	color: #ffffff;
	font-weight: bold;
	padding-left: 10px; 
	padding-right: 10px; 
	padding-top: 3px; 
	padding-bottom: 3px;
	-moz-border-radius: 5px;
	-webkit-border-radius: 5px;
	border-radius: 5px;
	background: #e1e774; /* Old browsers */
	background: -moz-linear-gradient(top,  #e1e774 0%, #d8e03c 100%); /* FF3.6+ */
	background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#e1e774), color-stop(100%,#d8e03c)); /* Chrome,Safari4+ */
	background: -webkit-linear-gradient(top,  #e1e774 0%,#d8e03c 100%); /* Chrome10+,Safari5.1+ */
	background: -o-linear-gradient(top,  #e1e774 0%,#d8e03c 100%); /* Opera 11.10+ */
	background: -ms-linear-gradient(top,  #e1e774 0%,#d8e03c 100%); /* IE10+ */
	background: linear-gradient(to bottom,  #e1e774 0%,#d8e03c 100%); /* W3C */
	filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#e1e774', endColorstr='#d8e03c',GradientType=0 ); /* IE6-9 */
}


/* -----------------------------------------------------*/
/*                 Liste periodiques                    */
/* -----------------------------------------------------*/


#perio_a2z {
}

#perio_a2z_search {
	width :	50%;
}
 
#perio_a2z .onglets_isbd_public {
	padding-bottom: 0px;	
}

table.a2z_contens {
	margin-top: 10px;
}

table.a2z_perio_list {
	width: 200px;
}

table.a2z_perio_list tr td {
	border-bottom: 1px solid #737373;
	padding-bottom: 3px;
}

#a2z_perio b .header_title {
	font-size: 16px;
	text-transform: uppercase;
}

#a2z_perio .notice-child h3 span {
    padding-left: 0px;
}

#a2z_perio .navbar {
	margin-top: 10px;
}

input#a2z_abt_actif {
	vertical-align: middle;
	margin-left: 2px;
	margin-right: 2px;
}


/* -----------------------------------------------------*/
/*                       Categories                     */
/* -----------------------------------------------------*/


#categories {
}

#categories ul.search_tabs {
	margin-left: 15px;
}

#categories ul.search_tabs li {
	font-size: 13px;
	margin-bottom: 3px;
}                 
                 
#categories ul.search_tabs li#current {
	border-top: 1px solid #f1f3ba;
	border-bottom: 1px solid #c7ce46;
	color: #ffffff;
	font-weight: bold;
	padding-left: 10px; 
	padding-right: 10px; 
	padding-top: 3px; 
	padding-bottom: 3px;
	-moz-border-radius: 5px;
	-webkit-border-radius: 5px;
	border-radius: 5px;
	background: #e1e774; /* Old browsers */
	background: -moz-linear-gradient(top,  #e1e774 0%, #d8e03c 100%); /* FF3.6+ */
	background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#e1e774), color-stop(100%,#d8e03c)); /* Chrome,Safari4+ */
	background: -webkit-linear-gradient(top,  #e1e774 0%,#d8e03c 100%); /* Chrome10+,Safari5.1+ */
	background: -o-linear-gradient(top,  #e1e774 0%,#d8e03c 100%); /* Opera 11.10+ */
	background: -ms-linear-gradient(top,  #e1e774 0%,#d8e03c 100%); /* IE10+ */
	background: linear-gradient(to bottom,  #e1e774 0%,#d8e03c 100%); /* W3C */
	filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#e1e774', endColorstr='#d8e03c',GradientType=0 ); /* IE6-9 */
}

#categories ul {
	margin-top: 2px;
	margin-bottom: 10px;
}

#categories-container {
    margin-bottom: 15px;
    padding-left: 25px;
}

#categories-container h2 {
	font-size: 13px;
}

#categories-container h2 img {
	margin-right: 3px;
}
		
#categories-container ul {
	margin-left: 18px;
    border-bottom: 1px solid #D6DE39;
    padding-bottom: 5px;
}

#categories-container li a {
	display: inline;
	border-top: none;
	border-bottom: none;
	color: #2C2E8C;
	padding-top: 0px;
	padding-bottom: 0px;
	padding-left: 0px;
	padding-right: 0px;
	background: none;
}

#categories-container li a:hover {
	color: #d6de39;
}

#categories-container li:after  {
	content: " - "; 
}

#aut_see {
   	margin-top: 10px;
   	margin-bottom: 15px;
}

#aut_see table {
   	width: 93%;
}

#aut_details_liste{
	margin-top: 20px;
}


/* -----------------------------------------------------*/
/*                    Localisations                     */
/* -----------------------------------------------------*/


#location {
    padding-bottom: 4px !important;
}

#location h3 {
    margin-bottom: 0px;
}

#location-container {
    margin-bottom: 15px;
    -moz-border-radius: 10px;
    -webkit-border-radius: 10px;
	border-radius: 10px;
	border-top: 3px solid #F0A935;
	border-bottom: 3px solid #F0A935;
	border-left: 1px solid #F0A935;
	border-right: 1px solid #F0A935;
	background-color: #ffffff;
}

#location-container table tr td a b {
    font-weight: normal;
    font-size: 14px;
}

.loc_comment {
	margin-bottom: 10px;	
}


/* -----------------------------------------------------*/
/*               Dernieres Acquisitions                 */
/* -----------------------------------------------------*/


#last_entries {
}

#last_entries-container {
	margin-right: 20px;
	margin-left: 20px;
	margin-top: 10px;
}

#last_entries .notice-child h3 {
	margin-top: 5px;
	margin-left: 2px;
}


/* -----------------------------------------------------*/
/*                        Etageres                      */
/* -----------------------------------------------------*/


#etageres {
	padding-bottom: 20px !important;
}

#etagere-container {
	margin-left: 20px;
	margin-right: 20px;
}

.etagere {
    margin-top: 20px;
    -moz-border-radius: 10px;
    -webkit-border-radius: 10px;
	border-radius: 10px;
	border-bottom: 3px solid #F0A935;
	padding-bottom: 10px;
}

#etagere-titre {
	display: block;
	float: left;
	margin-bottom: 10px;
}

#etagere-titre h1 {
	font-size: 16px;
}

#etagere-titre h1 a {
	text-decoration: none;
}

#etagere-comment h2 {
	font-style: italic;
	font-size: 15px;
	float: right;
	font-weight: normal;
}

#etagere-notice-list {
	margin-bottom: 15px;
	clear: left;	
}

#etagere-notice-list .etagere-suite {
	text-decoration: underline;
}


/* -----------------------------------------------------*/
/*                        Footer                        */
/* -----------------------------------------------------*/


#footer {
	width: 783px;
	text-align: center;
	position: absolute;
	left: 0;
	bottom: -50px;
    margin-left: 10%;
    margin-right: 10%;
    background-color: #d6de39;
	border: 10px solid rgba(44,46,140,0.1);
	-moz-box-shadow: 0px 0px 5px #666666;
	-webkit-box-shadow: 0px 0px 5px #666666;
	box-shadow: 0px 0px 5px #666666;
	-moz-background-clip: padding; /* for Mozilla browsers*/
	-webkit-background-clip: padding;   /* Webkit */
	background-clip: padding-box; /*  browsers with full support */
	-moz-border-radius: 10px;
	-webkit-border-radius: 10px;
	border-radius: 10px;
	-moz-transform: rotate(-1deg);
	-webkit-transform: rotate(-1deg);
	-o-transform: rotate(-1deg);
	-ms-transform: rotate(-1deg);
	transform: rotate(-1deg);
}

#footer a {
	text-decoration: none;
}

#footer a:hover {
	text-decoration: underline;
	color: #2c2e8c;
}



/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                         Balises HTML de base                               */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/


a {
	text-decoration: none;
	color: #2c2e8c;
	-webkit-transition: all 0.3s ease-in-out;
	-moz-transition: all 0.3s ease-in-out;
	transition: all 0.3s ease-in-out;
}

a:hover {
	text-decoration: underline;
	color: #d6de39;
}

h3 {
	margin-bottom: 5px;
	font-size: 18px;
	font-weight: normal;
	padding-bottom: 2px;
	padding-left: 5px;
	border-bottom: 1px solid #444444;
}

img {
	border: none;
}

ul {
	list-style: none;	
}

li {
	display: inline-block;
	margin-right: 5px;
}

li a {
	display: block;
	-moz-border-radius: 5px;
	-webkit-border-radius: 5px;
	border-radius: 5px;
	border-top: 1px solid #c2cbe2;
	border-bottom: 1px solid #252667;
	color: #ffffff;
	text-decoration: none;
	padding-top: 3px;
	padding-bottom: 3px;
	padding-left: 15px;
	padding-right: 15px;
	background: #506bad; /* Old browsers */
	background: -moz-linear-gradient(top,  #506bad 0%, #2c2e8c 100%); /* FF3.6+ */
	background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#506bad), color-stop(100%,#2c2e8c)); /* Chrome,Safari4+ */
	background: -webkit-linear-gradient(top,  #506bad 0%,#2c2e8c 100%); /* Chrome10+,Safari5.1+ */
	background: -o-linear-gradient(top,  #506bad 0%,#2c2e8c 100%); /* Opera 11.10+ */
	background: -ms-linear-gradient(top,  #506bad 0%,#2c2e8c 100%); /* IE10+ */
	background: linear-gradient(to bottom,  #506bad 0%,#2c2e8c 100%); /* W3C */
	filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#506bad', endColorstr='#2c2e8c',GradientType=0 ); /* IE6-9 */
}

li a:hover {
	border-top: 1px solid #f1f3ba;
	border-bottom: 1px solid #c7ce46;
	color: #2C2E8C;
	text-decoration: none;
	background: #e1e774; /* Old browsers */
	background: -moz-linear-gradient(top,  #e1e774 0%, #d8e03c 100%); /* FF3.6+ */
	background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#e1e774), color-stop(100%,#d8e03c)); /* Chrome,Safari4+ */
	background: -webkit-linear-gradient(top,  #e1e774 0%,#d8e03c 100%); /* Chrome10+,Safari5.1+ */
	background: -o-linear-gradient(top,  #e1e774 0%,#d8e03c 100%); /* Opera 11.10+ */
	background: -ms-linear-gradient(top,  #e1e774 0%,#d8e03c 100%); /* IE10+ */
	background: linear-gradient(to bottom,  #e1e774 0%,#d8e03c 100%); /* W3C */
	filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#e1e774', endColorstr='#d8e03c',GradientType=0 ); /* IE6-9 */
}

select {
	margin-top: 3px;
	margin-bottom: 3px;
}

input, select, textarea {
	border: 1px solid #cccccc;
	-moz-box-shadow: 0 1px 2px #666666 inset;
	-webkit-box-shadow: 0 1px 2px #666666 inset;
	box-shadow: 0 1px 2px #666666 inset;
}

input, textarea {
	padding-top: 2px;
	padding-bottom: 2px;
	padding-left: 10px;
	padding-right: 10px;
	-moz-border-radius: 10px;
	-webkit-border-radius: 10px;
	border-radius: 10px;
}

input.bouton, input.boutonrechercher {
	color: #ffffff;
    cursor: pointer;
	-webkit-transition: all 0.3s ease-in-out;
	-moz-transition: all 0.3s ease-in-out;
	transition: all 0.3s ease-in-out;
	background: #f2d5d2; /* Old browsers */
	background: -moz-linear-gradient(top,  #f2d5d2 0%, #bfa9a4 11%, #c4b2aa 49%, #af9b97 51%, #9b827d 100%); /* FF3.6+ */
	background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#f2d5d2), color-stop(11%,#bfa9a4), color-stop(49%,#c4b2aa), color-stop(51%,#af9b97), color-stop(100%,#9b827d)); /* Chrome,Safari4+ */
	background: -webkit-linear-gradient(top,  #f2d5d2 0%,#bfa9a4 11%,#c4b2aa 49%,#af9b97 51%,#9b827d 100%); /* Chrome10+,Safari5.1+ */
	background: -o-linear-gradient(top,  #f2d5d2 0%,#bfa9a4 11%,#c4b2aa 49%,#af9b97 51%,#9b827d 100%); /* Opera 11.10+ */
	background: -ms-linear-gradient(top,  #f2d5d2 0%,#bfa9a4 11%,#c4b2aa 49%,#af9b97 51%,#9b827d 100%); /* IE10+ */
	background: linear-gradient(to bottom,  #f2d5d2 0%,#bfa9a4 11%,#c4b2aa 49%,#af9b97 51%,#9b827d 100%); /* W3C */
	filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#f2d5d2', endColorstr='#9b827d',GradientType=0 ); /* IE6-9 */
}

input.bouton:hover, input.boutonrechercher:hover {
	-moz-box-shadow: 0 -1px 3px #444444 inset;
	-webkit-box-shadow: 0 -1px 3px #444444 inset;
	box-shadow: 0 -1px 3px #444444 inset;
}

input[type=checkbox] {
	border: none;
}

hr {
	background-color: #eeeeee;
	color: #eeeeee;
	border: 0px;
	height: 1px;
	margin-bottom: 5px;
}

.row {
	clear: both;
	border-bottom: none !important;
    margin-bottom: 0px !important;
    padding-bottom: 0px !important;
}


/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                                   Tableaux                                 */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/


table {
	border-collapse: separate;
	width: 100%;
}

.exemplaires { 
	border-collapse: separate;
}

th {
	text-align: left ;
	background-color: #F2F2F2;
	padding: 2px;
}

td {
	vertical-align: top;
}


/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                                  Carrousel                                 */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/


.bx-wrapper {
}

.bx-window ul li {
	margin-right: 0px;
}

.bx-window ul li a {
	border-top: none;
	border-bottom: none;
	color: #2C2E8C;
	padding-top: 0px;
	padding-bottom: 0px;
	padding-left: 5px;
	padding-right: 5px;
	background-color: transparent;
	background-image: none;
}

.bx-window ul li a:hover {
	background-color: transparent;
	background-image: none;
}

.bx-window ul li a img {
	height: 160px;
	background-repeat: no-repeat;
	background-position: center center;
	background-image: url("images/no_image.jpg");
}


/*next button*/
.bx-next {
	z-index: 999;
	width: 20px;
	height: 20px;
	background-image: url("images/next-v.png");
	background-repeat: no-repeat;
	background-position: 0 0px;
}

/*previous button*/
.bx-prev {
	z-index:999;
	width: 20px;
	height: 20px;
	background-image: url("images/prev-v.png");
	background-repeat: no-repeat;
	background-position: 0 0px;
}

.bx-pager {
	bottom: 0;
    position: absolute;
    width: 100%;
    z-index: 99;
}

.bx-pager a {
	background-color: #D6DE39;
}

.bx-pager a.pager-active {
	background-color: #2C2E8C;
}


/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                         Petit module de recherche                          */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/


.searchbox {
	text-align: center;
}

.searchbox input[name="user_query"] {
	margin-bottom: 5px;
}

.searchbox .bouton {
}


/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                                   Facettes                                 */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/


#facette h3 {
	margin-bottom: 0px;
}

#facette table th {
	padding-top: 1px;
	padding-bottom: 1px;
	padding-left: 5px;
	padding-right: 5px;
}

#facette table td a {
	display: block;
	padding-right: 10px;
	padding-left: 10px;
	padding-top: 1px;
	padding-bottom: 1px;
	-moz-border-radius: 5px;
	-webkit-border-radius: 5px;
	border-radius: 5px;
}

#facette table td a:hover {
	background: #506bad; /* Old browsers */
	background: -moz-linear-gradient(top,  #506bad 0%, #2c2e8c 100%); /* FF3.6+ */
	background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#506bad), color-stop(100%,#2c2e8c)); /* Chrome,Safari4+ */
	background: -webkit-linear-gradient(top,  #506bad 0%,#2c2e8c 100%); /* Chrome10+,Safari5.1+ */
	background: -o-linear-gradient(top,  #506bad 0%,#2c2e8c 100%); /* Opera 11.10+ */
	background: -ms-linear-gradient(top,  #506bad 0%,#2c2e8c 100%); /* IE10+ */
	background: linear-gradient(to bottom,  #506bad 0%,#2c2e8c 100%); /* W3C */
	filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#506bad', endColorstr='#2c2e8c',GradientType=0 ); /* IE6-9 */
	color: #ffffff;
}


/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                                  Portail                                   */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/


/* ----------------------Accueil-------------------------*/


#cms_module_recordslist_23 .bx-window ul li {
	width: 150px;
}


/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                              Page Inscription                              */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/


#subs_form table td h4 {
	margin: 0px;
}

#subs_form table td input.subsform {
	width: 195px;
	background-color: #ffffff;
}


/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                           Carroussel bulletin                              */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/


.carroussel_bulletin {
	text-align : center;
}

.carroussel_bulletin img {
	border: none;
}

.carroussel_bulletin .active a {
	color: #ffffff;
	cursor : pointer;
}

.carroussel_bulletin .current_bull_carroussel {
	font-weight : bold;
}


/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                  Mise en forme de la fiche emprunteur	                  */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/


#empr_onglet ul.empr_tabs, #onglets_list ul.list_tabs {
	font-size: 14px;
}

#empr_onglet ul.empr_tabs li {
    margin-bottom: 5px;
}

#empr_onglet ul.empr_tabs li#current, #onglets_list ul.list_tabs li#current {
    margin-bottom: 5px;
}

#empr_onglet ul.empr_tabs li#current a, #onglets_list ul.list_tabs li#current a {
    border-top: 1px solid #f1f3ba;
	border-bottom: 1px solid #c7ce46;
	color: #ffffff;
	font-weight: bold;
	padding-left: 10px; 
	padding-right: 10px; 
	padding-top: 3px; 
	padding-bottom: 3px;
	-moz-border-radius: 5px;
	-webkit-border-radius: 5px;
	border-radius: 5px;
	background: #e1e774; /* Old browsers */
	background: -moz-linear-gradient(top,  #e1e774 0%, #d8e03c 100%); /* FF3.6+ */
	background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#e1e774), color-stop(100%,#d8e03c)); /* Chrome,Safari4+ */
	background: -webkit-linear-gradient(top,  #e1e774 0%,#d8e03c 100%); /* Chrome10+,Safari5.1+ */
	background: -o-linear-gradient(top,  #e1e774 0%,#d8e03c 100%); /* Opera 11.10+ */
	background: -ms-linear-gradient(top,  #e1e774 0%,#d8e03c 100%); /* IE10+ */
	background: linear-gradient(to bottom,  #e1e774 0%,#d8e03c 100%); /* W3C */
	filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#e1e774', endColorstr='#d8e03c',GradientType=0 ); /* IE6-9 */
}

ul.empr_subtabs {
	margin-bottom: 10px;
    margin-top: 15px;
}

ul.empr_subtabs li {
	margin-bottom: 5px;
	border-left: 10px;
	padding-right: 10px;
	border-right: 1px solid #2C2E8C;
}

ul.empr_subtabs li a {
	border-top: none;
	border-bottom: none;
	color: #2C2E8C;
	padding-top: 0px;
	padding-bottom: 0px;
	padding-left: 0px;
	padding-right: 0px;
	background: none;
}

ul.empr_subtabs li a:hover {
	color: #d6de39;
}

#empr-all, #empr-late, #empr-old, #empr-resa, #empr-dsi, #empr-sugg,
#empr-list, #empr-dema {
	margin-top: 25px;
} 

#list_cadre {
	border: none !important;
	padding-top: 15px !important;
	height: auto ! important;
	clear: both;
}

#list_cadre img {
	vertical-align: bottom;
}

.form_liste_lecture .form-contenu .row .colonne2 .row textarea {
	max-width: 445px;	
}

.form_liste_lecture h3 {
	margin-top: 20px;
}

#fiche-empr h3 {
	margin-bottom: 10px;
}

#view_sugg h3 span span {
	background-image: none;
	margin: 0px;
	padding: 0px;
}

#inscrit_list {
	border: 1px solid #231F20 !important;
	padding-left: 5px;
	padding-tight: 5px;
	padding-top: 2px;
	padding-bottom: 2px;
}

#make_sugg-container table tr td {
	padding-bottom: 5px;
}


/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                               Notices affichage                            */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/


.bg-grey {
	padding-right: 0.2em;
	padding-top: 1px;
	padding-bottom: 1px;
	width: 150px;
	background: #e1e774; /* Old browsers */
	background: -moz-linear-gradient(top,  #e1e774 0%, #d8e03c 100%); /* FF3.6+ */
	background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#e1e774), color-stop(100%,#d8e03c)); /* Chrome,Safari4+ */
	background: -webkit-linear-gradient(top,  #e1e774 0%,#d8e03c 100%); /* Chrome10+,Safari5.1+ */
	background: -o-linear-gradient(top,  #e1e774 0%,#d8e03c 100%); /* Opera 11.10+ */
	background: -ms-linear-gradient(top,  #e1e774 0%,#d8e03c 100%); /* IE10+ */
	background: linear-gradient(to bottom,  #e1e774 0%,#d8e03c 100%); /* W3C */
	filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#e1e774', endColorstr='#d8e03c',GradientType=0 ); /* IE6-9 */
}

#resultatrech_liste tbody tr td table, #resultatrech_liste tbody {
	padding-top:5px;
}

.notice-parent {
	padding-bottom: 5px !important;
    margin-bottom: 5px !important;
    border-bottom: 1px dotted #cccccc !important;
}

.notice-parent .img_plus {
    margin-right: 5px;
}

.notice-parent span a img {
    vertical-align: bottom;
}

.notice-child {
    margin-bottom: 20px!important;
    -moz-box-shadow: 0 1px 2px #CCCCCC;
    -webkit-box-shadow: 0 1px 2px #CCCCCC;
    box-shadow: 0 1px 2px #CCCCCC;
    padding-left: 20px;
    padding-right: 20px;
    padding-top: 5px;
    padding-bottom: 10px !important;
    background-color: #ffffff;
}

.notice-child h3, #notice h3 {
    margin-top: 10px;
    margin-left: 2px;
    margin-bottom: 0px;
    font-size: 18px;
    padding-left: 0px;
}

#bt_resa {
    margin-left: 3px;
}

.vignetteimg {
	max-width: 140px;
	max-height: 200px;
	width: expression(this.width > 140 ? "140px" : true);
	height: expression(this.height > 200 ? "200px" : true);
	-moz-box-shadow: 1px 1px 5px #666666;
	-webkit-box-shadow: 1px 1px 5px #666666;
	box-shadow: 1px 1px 5px #666666;
}

.child {
    margin-left: 25px;
    padding-left: 4px;
    padding-right: 4px;
    text-align: justify;
    border-bottom-style: solid;
    border-bottom-width: 1px;
    border-bottom-color: #c0c0c0;
    border-left-style: solid;
    border-left-width: 1px;
    border-left-color: #c0c0c0;
    border-right-style: none;
    border-top-style: none;
}

.liste_bulletins {
    padding-left: 3px;
    padding-right: 3px;
    float: left;
	width: 31%;
	color:#ffffff;
}

.colonne2 {
  float: left;
  width: 50%;
}

.colonne_suite {
  float: left;
}


/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                       Onglets de l'affichage public/ISBD                   */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/


ul.onglets_isbd_public {
    padding-bottom: 5px;
}

li.isbd_public_active a {
	border-top: 1px solid #f1f3ba;
	border-bottom: 1px solid #c7ce46;
	color: #2C2E8C;
	text-decoration: none;
	background: #e1e774; /* Old browsers */
	background: -moz-linear-gradient(top,  #e1e774 0%, #d8e03c 100%); /* FF3.6+ */
	background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#e1e774), color-stop(100%,#d8e03c)); /* Chrome,Safari4+ */
	background: -webkit-linear-gradient(top,  #e1e774 0%,#d8e03c 100%); /* Chrome10+,Safari5.1+ */
	background: -o-linear-gradient(top,  #e1e774 0%,#d8e03c 100%); /* Opera 11.10+ */
	background: -ms-linear-gradient(top,  #e1e774 0%,#d8e03c 100%); /* IE10+ */
	background: linear-gradient(to bottom,  #e1e774 0%,#d8e03c 100%); /* W3C */
	filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#e1e774', endColorstr='#d8e03c',GradientType=0 ); /* IE6-9 */
}

ul.onglets_isbd_public li img {
    vertical-align: bottom;
}


/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                                   Pop-up                                   */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/


#make_sugg {
	margin-left: 20px;
	margin-right: 20px;
	margin-top: 10px;
	margin-bottom: 10px;
	padding-left: 20px;
	padding-right: 20px;
	padding-top: 10px;
	padding-bottom: 10px;	
	-moz-box-shadow: 0 1px 5px #666666;
	-webkit-box-shadow: 0 1px 5px #666666;
	box-shadow: 0 1px 5px #666666;
	-moz-border-radius: 5px;
	-webkit-border-radius: 5px;
	border-radius: 5px;
}
	
#titre-popup {
	font-size: 16px;
	font-weight: bold;
	margin-top: 5px;
	margin-bottom: 10px;
	margin-left: 10px;
	margin-right: 10px;
	border-bottom: 2px solid #F26702;
    color: #F26702;
    padding-bottom: 3px;
}

form#f {
	margin-left: 10px;
}

.echelle_avis {
	padding: 7px;
}

.alerte {
	color: #ff0000;
	font-size:14px;
}

#print_options {
	margin-right: 10px;
	margin-left: 10px;
	margin-top: 10px;
	margin-bottom: 20px;
}

#print_options b {
	color: #005EA8;
}

#print_options blockquote {
	-moz-box-shadow: 0 0 5px #666666;
	-webkit-box-shadow: 0 0 5px #666666;
	box-shadow: 0 0 5px #666666;
    padding-bottom: 5px;
    padding-left: 5px;
    padding-right: 5px;
    padding-top: 5px;
    text-align: justify;
}

#print_options textarea {
	margin-top: 5px;
	max-width: 90%;
}

#help-container h2 {
	font-size: 22px;
	font-weight: bold;
	margin-bottom: 10px;
	margin-left: 10px;
	margin-right: 10px;
	border-bottom: 2px solid #444444;
    color: #444444;
    padding-bottom: 3px;
}

#help-container p, #help-container ul {
	margin-bottom: 10px;
	margin-top: 0px;
	margin-right: 10px;
	margin-left: 10px;
}

body.popup {
	background-image: none;
	margin-left: 25px;
	margin-right: 25px;
}

body.popup blockquote {
	background-color: #ffffff;
	padding-left: 20px;
	padding-right: 20px;
	padding-top: 10px;
	padding-bottom: 10px;
	border: 10px solid rgba(255,255,255,0.4);
	-moz-box-shadow: 0px 0px 5px #666666;
	-webkit-box-shadow: 0px 0px 5px #666666;
	box-shadow: 0px 0px 5px #666666;
	-moz-background-clip: padding; /* for Mozilla browsers*/
	-webkit-background-clip: padding;   /* Webkit */
	background-clip: padding-box; /*  browsers with full support */
}
	
	
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                               Liens Sociaux                                */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/


table td div.addthis_toolbox {
	margin-bottom: 10px;
	margin-top: 10px;
}

a.addthis_button_facebook_like iframe {
	height: 20px !important;
    width: 60px !important;
}

a.addthis_button_tweet iframe {
    width: 105px !important;
}


/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                            CLASSES GENERIQUES                              */
/*                 divers pour les affichages simples de texte                */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/


.right-50 {
	width: 50%;
}

.right-15 {
	width: 15%;
}

.right-85 {
	width: 85%;
}

.right-clear-right, .right-50-clear-right {
	float: right;
	clear: right;
}

.left-clear-left, .left-50-clear-left {
	float: left;
	clear: left;
}

.left, .left-50, .left-15 {
	float: left;
}

.left-50 {
	width: 50%;
}

.left-15 {
	width: 15%;
}

.left-85 {
	width: 85%;
}

.spacer {
	clear: both;
	visibility: hidden;
	display: none;
	margin-bottom: -10px;
	margin-top: -10px;
}


/* Bannettes */
#bannette { 
	border: 1px solid #666666;
	padding:5px;
}

.bannette-container { 
	margin-bottom: 20px;
}

.text_search0 {
	background-color: #E7E63E;
	text-decoration: underline;
}

.text_search1 {
	background-color: #E7E63E;
	text-decoration: underline;
}

.text_search2 {
	background-color: #E7E63E;
	text-decoration: underline;
}

.text_search3 {
	background-color: #E7E63E;
	text-decoration: underline;
}

.text_search4 {
	background-color: #E7E63E;
	text-decoration: underline;
}

.text_search5 {
	background-color: #E7E63E;
	text-decoration: underline;
}

.etiq_champ {
	font-weight:bold;
}

/*Suggestion Multiple*/

.tab_sug {
	table-layout: fixed;
}

.tab_sug th, .tab_sug td {
	border:1px solid #CCCCCC;
	border-collapse:collapse;
	overflow:hidden;	
	vertical-align:center;
	text-align: center;
	width : 100%;
}

.tab_sug input, .tab_sug textarea {
   width:95%;
   height:100%;
}

.tab_sug select{
	width:95%;
}

.erreur_saisie {
	background-color: #ff0000;
}

.categmouseout {
	border: solid 2px #555555;
	position: absolute;
	visibility:hidden;
	z-index: 2000;
}
.categmouseover {
	border: solid 2px #555555;
	position: absolute;
	visibility:visible;
	z-index: 2000;
	margin-top: 2px;
}

.listedescription {
	border: 2px solid #CECE0B;
	background-color: #ffffff;
	position: absolute;
	visibility:hidden;
	z-index: 2000;
}

#aut_details_container table img {
	max-height: 74px;
	mzrgin-left: 2px;
	margin-right: 2px;
}

#history_action {
	margin-bottom: 15px;
}


