/* +--------------------------------------------------------------------------+
// | PMB est sous licence GPL, la reutilisation du code est cadree            |
// +--------------------------------------------------------------------------+
// $Id: acidule.css,v 1.35 2012-03-27 09:06:02 trenon Exp $                 */

/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                         ATTRIBUTS GENERAUX                                 */
/*                                                                            */
/*  attributs generaux de la page                                             */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/

body {
	font-size: 11pt;
	font-family: Verdana, Geneva, Arial, Helvetica, sans-serif;
	background-color: #F5FFEC;
	margin: 0;
	padding: 0;
	color: #7686D2;
}

td{
	font-size : 11px;	
}


/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                            ID FIXES                                        */
/*                                                                            */
/*  feuilles de styles appliquees a des id fixes                              */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/

/* #container : partie d'affichage principal */
#container {
	position: absolute;
	margin: 0;
	padding: 0; 
	width: 100%;
}

#intro {
	background : url("livre.png")                  no-repeat top left; 
	margin: 0 0 0 18%;
	width: 85%;
	padding: 0;
}
	
#intro_bibli {
	border-bottom: 2px solid #FE9D43;
	border-top: 8px solid #FFFFFF; /* pour decoller texte du bas */
}
	
#intro_bibli h3 {
	font-weight: semibold;
	font-size: 15pt;
	color : #7686D2;
	text-align: center;
	margin: 0;
	padding: 0 5px 5px 0;
	border-bottom: 2px solid #FE9D43;

	}
	
#intro_bibli h3 {
	padding-left:10px;
	background : #0023A4;
	margin-top: 0px;
	padding-top: 0px;
	}
	

#intro_pmb {
	width:100%;
	display:none;
	}

#intro_pmb h1, h1 a, h1 a visited {
	text-align: right;
	font-size0.7em;
	color:#6B7B3B;
	margin-top: 0px;
	margin-left: 0px;
	margin-bottom: 0px;
	margin-right: 0px;	
}

#intro_pmb h2 {
	text-align: right;
	font-size:2.2em;
	
	margin-top: 0px;
	margin-left: 0px;
	margin-bottom: 0px;
	margin-right: 0px;
}

#intro_message {
	font-style:italic;
	}

#intro_message .p1,		
#intro_message .p2 {
/*	display:none; */ 
	margin: 0 0 0 0;
	padding : 0 0 0 0;
}
		
#intro_bibli p.p1{
 	background : url("intro_message.gif") no-repeat top left;
	padding: 0 8px;
	margin: 4px 0;
	text-align: center;
	font-size: 0.85em;
	color:#0000A8;
}
#intro_bibli p.p2 {
	padding: 0 8px;
	margin: 4px 0;
	text-align: justify;
	font-size: 1.15em;
	color:#D24400;
 	
}

#main {
	position: absolute;
	left: 15%;
	width: 83%;
	top: 160px;
	margin: 0px;
	padding: 0px;
	height: 100%;
}

#main h3 { 
	margin: 5px 0 15px 0;
	padding: 4px 0 5px 5px;
	font-weight: bold;
	text-align: left;
	border-bottom: dotted 1px #7686D2;
	font-size: 12pt;
}

#main h3 span {
	color: #7686D2;
	padding: 0 20px -10px -10px;
	margin-bottom: -10px;
	margin: 0;
}

#main ul.search_tabs, #onglets_list ul.list_tabs {
	margin: 0;
	padding: 0;
	list-style: none;
	clear: right;
	height: 24px;
	font-size: 11pt; 
	background : url("pointvert.gif") repeat-x bottom left;
}

#main ul.search_tabs li, #onglets_list ul.list_tabs li{
	float: left;
	padding: 3px 6px 0px 6px;
	border: 1px solid #7686D2;  
	margin-right: 4px;
	margin-bottom: 5px;
	border-bottom: none; 
	height: 19px;
	background: #C7D1FF;
	color: #7686D2;
}


#main ul.search_tabs li a, #onglets_list ul.list_tabs li a{
	text-decoration: none;
	font-weight: normal;
	color: #7686D2;
	border-bottom: none;
}
          
#main ul.search_tabs li a:hover #onglets_list ul.list_tabs li a:hover{
	text-decoration: none;
	font-weight: normal;
	color: #FE9D43;
	background-color: #FFCEA1;
}

#main ul.search_tabs li:hover a,
#main ul.search_tabs li:hover, #onglets_list ul.list_tabs li:hover a, #onglets_list ul.list_tabs li:hover{ 
/* Au survol, tout l'onglet change de couleur, comme "a". Ne fonctionne pas avec IE */
	text-decoration: none;
	font-weight: normal;
	color: #FE9D43;
	background-color: #FFCEA1;
}

#main ul.search_tabs li#current, #onglets_list ul.list_tabs li#current{
	float: left;
	padding: 3px 6px 0px 6px;
	background: #FFF1A2;
	border-bottom: 1px solid #FFF1A2; 
	margin-bottom: 4px; 
	height: 19px;
}
          
#search_crl { clear:both; }      

.div_clr { clear:both; }  


#location {
	clear:both;
	margin: 5px 0;
	padding: 0 5px 5px 5px;
	border:2px solid #FE9D43;
	background-color: #FFF8D1;
}

/* informations a ajouter pour afficher les categories */
#categories {
	margin: 10px 0 5px 0;
	padding: 0 5px 5px 5px;
	border: 2px solid #FE9D43;
	background-color: #FFF8D1;
}
	
#categories H1 {
	font-weight: 500; 
	font-size: 1.5em; 
	background-color: transparent; 
	letter-spacing: 150%; 
	margin: 0.5em 0.2em 0.5em 0.5em; 
}

/* informations a ajouter pour afficher les categories */
#categories-container {
	}

/* informations a ajouter pour afficher les categories */
div.row_categ {
	display: block ;
	clear: left;
	}

div.category 
	{ 	
	float:left;
	margin: 0.5em 0.2em; 
	width: 31%; 
	}

#categories-container h2 {
	font-weight: bold; 
	font-size: 1em; 
	background: transparent; 
	margin-top: 0em; 
	margin-bottom: 0.2em; 
}
		
#categories-container li {
	font-size: 0.9em; 
	line-height: 1.4em;
	display: inline;
}

#categories-container li:after {
	font-size: 0.8em; 
	content: ", "; 
}
		
#categories-container ul {
	margin-top: 0em;
	margin-bottom: 0em; 
	padding-left: 0em; 
}

/*	Couleurs des liens des 'CATEGORIES' */
#categories a {
	color: #7686D2;
	text-decoration: none;
	border-bottom: 1px solid #7686D2;
}

#categories a:hover {
	color: #FE9D43;
	background-color: #FFCEA1;
	border-top: 1px solid #FE9D43;
	border-bottom: 1px solid #FE9D43;
}

/* Mise en page des colonnes d'affichage des recherches 
   par auteurs, editeurs, collections , sous-collections et categories */
.categ_colonne {
	width:33%;
	float:left;
}
/* reset des largeurs de #categories */
/* apres un float:left; l'element bloc suivant doit avoir l'attribut clear:both s?lectionn? pour ?viter un bug d'affichage */
#last_entries { clear:both; }

/* reset des largeurs de #categories */
/* apres un float:left; l'element bloc suivant doit avoir l'attribut clear:both s?lectionn? pour ?viter un bug d'affichage */
.last_entries { clear:both; }


#bandeau{
	
		font-size: 0.8em;
		text-align: left;
		color:#000;
		background : url("csp1.jpg")                  no-repeat top left; 
		position: absolute;
		margin: 0px;
		padding: 0px;
		padding-left:5px;
		padding-right:5px;
		padding-bottom:50px;
		height:170%;
		width: 13.7%;
		top:0px;
	
}

#bandeau a {
	color: #555555;

}

#bandeau form {
	padding: 0 0 0 0 ;
	margin: 0 0 0 0 ;
}

#bandeau h3 {
	color: #7686D2;
	font-weight: bold;
	font-size:9pt;
	text-align: left;
	width: 100%;
	background-color: #FFF1A2;
	margin: 0 0 0 0 ;
}

#bandeau ul 
	{
	margin-top: 0px;
	margin-bottom: 0px;
	margin-left: 0px;
	margin-right: 0px;
	padding: 0px;
	}
		
#bandeau li 
	{
	line-height: 1em;
	list-style-type: none;
	background: transparent no-repeat top center;
	display: block;
	padding-top: 0px;
	margin-bottom: 0px;
	}

#bandeau div h3 span
	{
	background: #FFF1A2;
	color: #7686D2;
	padding-left: 0px;
	}

	
#footer {
	margin: 0;
	padding: 3px 0 0 0;
	border-top: 2px solid #FE9D43;
	border-bottom: 8px solid #FFFFFF; /* pour decoller texte du bas */
	text-align: center;
	voice-family: "\"}\"";
	voice-family:inherit;
}
	
#footer a:link, #footer a:visited {
	margin-left: 10px;
	margin-right: 10px;
	margin-top: 0px;
	margin-bottom: 0px;
	color: #7686D2;
	font-size:9pt;
	font-weight: bold;
}

#notice {
	font-size:10pt;
}

#notice h3 {
	border-bottom: 1px solid #ddcB8C;
	border-top: 1px solid #ddcB8C;
}
		
#notice span {
	margin-left: 10px;
	margin-right: 10px;
	margin-top: 5px;
	margin-bottom: 5px;
}

.liste_bulletins {
    padding-left: 3px;
    padding-right: 3px;
    	}  

.notice-parent {
	font-family: verdana, helvetica, arial, geneva, sans-serif;
	color: #000000;
	margin-left: 0px;
	font-size: 8pt;
	text-decoration: none
	}
.img_plus {
	background-color: #8CC6FF;
}
.notice-child {
	font-family: arial, helvetica, geneva, sans-serif;
	font-size: 0.9em;
	margin-left: 30px;
	width: 98%;
	padding-left: 4px;
	padding-right: 4px;
	text-align: justify;
	border-bottom-style: solid;
	border-bottom-width: 1px;
	border-bottom-color: #c0c0c0;
	border-left-style: solid;
	border-left-width: 1px;
	border-left-color: #c0c0c0;
	border-right-style: none;
	border-top-style: none;
	}

#bandeau DIV {	
	margin-bottom: 20px; 
	}

#bandeau DIV H3 {	
	color: #FFFFFF; 
	
	}


/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                            BALISES HTML                                    */
/*                                                                            */
/*  feuilles de styles appliquees a des balises sans classes ni id specifies  */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
p { 	
	margin:8px;
	}

p.centered {	
	text-align:center;
	}

a {	
	color: #A75204;
	}

a:hover { 
	color: #000000; 
	}

.categmouseout {
	border: solid 2px #555555;
	background-color: #FFFFFF;
	color: #000000;
	position: absolute;
	visibility:hidden;
	z-index: 2000;
}
.categmouseover {
	border: solid 2px #555555;
	background-color: #FFFFFF;
	color: #000000;
	position: absolute;
	visibility:visible;
	z-index: 2000;
	margin-top: 2px;
}

.listedescription {
	border: solid 2px #555555;
	background-color: #fff;
	color: #000000;
	position: absolute;
	visibility:hidden;
	z-index: 2000;
}

/* ------------------------------------ */
/*	tableaux */
/* ------------------------------------ */
table
	{
	border-collapse: collapse;
	}

tr
	{ }

th
	{ 
	background: #C8D79B;
	text-align: left; 
	}

td.visible
	{	border-bottom: 1px solid #ddcB8C;
		border-top: 1px solid #ddcB8C; }

td.visible-centered
	{	border-bottom: 1px solid #ddcB8C;
		border-top: 1px solid #ddcB8C;
		text-align:center; }

.text_search0 {
	background-color: yellow;
	text-decoration: underline;
}

.text_search1 {
	background-color: red;
	text-decoration: underline;
}

.text_search2 {
	background-color: green;
	text-decoration: underline;
}

.text_search3 {
	background-color: blue;
	text-decoration: underline;
}

.text_search4 {
	background-color: maroon;
	text-decoration: underline;
}

.text_search5 {
	background-color: blank;
	text-decoration: underline;
}

tr.even
	{
	background: #DDF0A7;
	color: #000;
	}

tr.odd
	{
	background: #ECF7C9;
	color: #000;
	}
tr.surbrillance {
	background: #EECCCC;
	}
tr.tr_spacer 
	{
	height: 0px;
	}
td.td_spacer 
	{
	height: 0px;
	}

/*------------------------------------
/*	tableaux des exemplaires de la fiche emprunteur
/------------------------------------*/
table.liste-expl-empr-late 
	{
	}
table.liste-expl-empr-all 
	{
	}

td.expl-empr-retard {
	background: #DD0000;
	color: #FFFFFF;
	}

/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                            CLASSES GENERIQUES                              */
/*                                                                            */
/*  feuilles de styles appliquees a classes de balises                        */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/


/* divers pour les affichages simples de texte   */
/*-----------------------------------------------*/
.row
	{ clear: both;
	  width: 80%;
	  margin-left:30px; }

.right,
.right-50,
.right-15,
.right-85 
	{	float: right; }

.right-50 {	width: 50%; }

.right-15 {	width: 15%; }

.right-85 {	width: 85%; }


.right-clear-right,
.right-50-clear-right
	{	float: right;
		clear: right; }

.left-clear-left,
.left-50-clear-left
	{	float: left;
		clear: left; }

.left,
.left-50,
.left-15
	{	float: left;}

.left-50
	{	width: 50%;}

.left-15
	{	width: 15%;}

.left-85
	{	width: 85%;}

.spacer
	{	clear: both;
		visibility: hidden;
		display: none;
		margin-bottom: -10px;
		margin-top: -10px; }

.p1 {	font-size:10pt; }
	
.text_query 
	{ 	width: 20em; }

.fond-mere {
	background-color: #4f72ff;
	}

.fond-article {
	background-color: #68df00;
	}


/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                            CLASSES LIEES A L'APPLICATION                   */
/*                                                                            */
/*  feuilles de styles appliquees a des balises sans classes ni id specifies  */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/

input.bouton, input.boutonrechercher 
	{	background:#DFD087;
		color:#7F7027;
		margin-left: 0px;
		margin-right: 0px; }

/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                       MODIFICATIONS POUR L'IMRPESSION                      */
/*                                                                            */
/* pour l'impression, masquage de tags                                        */
/*                                                                            */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/

/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                       ONGLETS DE L'AFFICHAGE PUBLIC/ISBD                   */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/

ul.onglets_isbd_public {
    font: bold 11px verdana, arial, sans-serif;
    list-style-type: none;
    padding-bottom: 24px;
    border-bottom: 1px solid #6c6;
    clear: both;
    padding-left:2px;
}

ul.onglets_isbd_public li {
    float: left;
    height: 21px;
    background-color: #cfc;
    margin: 2px 2px 0 2px;
    border: 1px solid #6c6;
    background-color: #B9A8F0;
}

ul.onglets_isbd_public li.isbd_public_active {
    border-bottom: 1px solid #DDF0A7;
    background-color: #DDF0A7;
}

.onglets_isbd_public a {
    float: left;
    display: block;
    color: #666;
    text-decoration: none;
    padding: 4px;
    cursor: default ;
}
.onglets_isbd_public li.isbd_public_inactive a:hover {
    background: #FFF;
    cursor: pointer ;
    }

ul.onglets_isbd_public li.onglet_basket,
ul.onglets_isbd_public li.onglet_basket a {
    border: none;
	background:none;
    cursor: pointer ;
	width:25px;
	}

ul.onglets_isbd_public li.onglet_tags,
ul.onglets_isbd_public li.onglet_tags a {
    border: none;
	background:none;
    cursor: pointer ;
	text-decoration:underline;
	}

/* Colonnes */
.colonne2 {
  float: left;
  width: 50%;
}

.colonne_suite {
  float: left;
}

/* Gestion de l'affichage des 'ETAGERES' */
#etageres {
	margin: 5px 0 10px 0;
	padding: 0 5px 5px 5px;
	border:2px solid #FE9D43;
	background-color: #FFF8D1;
}

#etagere-container {
}

.etagere {
	margin-bottom: 15px;
	padding: 0 5px 5px 5px;
}

#etagere-titre h1 {
	width: 99%;
	margin: -10px 0 0 0;
	padding: 0 5px 0 5px;
	font-size: 1.3em;
	font-weight: bold;
}

#etagere-titre h1 a {
	color: #A75204
	}

#etagere-titre a {
}

#etagere-comment h2 {
	text-align: left;
	font-style: italic;
	font-size: 14px;
	color: #6B7B3B;
	margin: 0px;
	padding: 5px;
}

#etagere-notice-list { padding-left:5px;}
#etagere-notice-list a { }
#etagere-notice-list A:hover { }

/* Cartouche de navigation : 'A PARTIR D ECETTE PAGE...' */
#navigator {
	margin: 5px 0;
	padding: 0 5px 5px 5px;
	border:2px solid #FE9D43;
	background-color: #FFF8D1;
}

#navigator table {
	background-color: #FFF8D1;
	border-collapse:collapse;
	}

#navigator td {
	border-left:3px #FFF8D1 solid;
	border-right:3px #FFF8D1 solid;
	text-align:center;
	font-size:0.9em;
	font-style:italic;
	}

/* Informations a ajouter pour l'affichage du cadre 'RECHERCHE' */
#search {
	margin: 5px 0;
	padding: 5px;
	border:2px solid #FE9D43;
	background-color: #FFF8D1;
}
	
#all_footer {
	position:absolute;
	top:500px;
	padding-left:0px;
	width: 13%;
	left:0;
}
	
iframe#iframe_resume_panier {
	width:100%;
	height:35px;
	border:none;
	}

.alerte {
	color: red;
	font-size:14px;
	}
.etiq_champ {
	font-weight:bold;
	}

/*Suggestion Multiple*/

.tab_sug{
	table-layout: fixed;
}

table{
	border-collapse:collapse;
	margin: 10px 0;
	width:100%;
}
.tab_sug th, .tab_sug td{
	border:1px solid #CCCCCC;
	border-collapse:collapse;
	overflow:hidden;	
	vertical-align:center;
	text-align: center;
	width : 100%;
}

.tab_sug  input, .tab_sug textarea{
   width:95%;
   height:100%;
}
.tab_sug select{
	width:95%;
}

.erreur_saisie {
	background-color: #ff0000;
}

/***********************
 * Carroussel bulletin *
 ***********************/
.carroussel_bulletin{
	text-align : center;
	/*border : 1px solid black;*/
}

.carroussel_bulletin .active{
	border : 1px solid black;
	cursor : pointer;
}

.carroussel_bulletin .current_bull_carroussel{
	border : 1px solid black;
	font-weight : bold;
}



/*---------------------------------------------------------------*
 *---------------------------------------------------------------* 
 * 		      Mise en forme de la fiche emprunteur				 *
 *---------------------------------------------------------------*
 *---------------------------------------------------------------*/
  
#empr_onglet {
 	    padding:0 10px;
}

#empr_onglet ul.empr_tabs{
	list-style:none;
	font-size:11px;
    clear:right;
    height:24px;
	position:absolute;
	margin-top:-0px;
	padding-left: 0px;
}

#empr_onglet ul.empr_tabs li{
	float:left;
	font-weight:bold;
	margin: 0 5px;
}

#empr_onglet ul.empr_tabs li a{
	background-color: #C7D1FF;
	background-repeat: no-repeat;
	background-position: left top;
	color:#7686D2;
	display:block;
	font-weight:normal;
	height:17px;
	padding:2px 7px;
	position:relative;
	text-decoration:none;
	border-top: 1px solid #7686D2;
	border-left: 1px solid #7686D2;
	border-right: 1px solid #7686D2 
}

#empr_onglet ul.empr_tabs li a:hover{
   	text-decoration: none;
	font-weight: normal;
	color: #FE9D43;
	background-color: #FFCEA1;
}

#empr_onglet ul.empr_tabs li#current{
	float:left;
	font-weight:bold;
    height:21px;
    background-color: #FFF1A2;
	color: #7686D2;
}

#empr_onglet ul.empr_tabs li#current a {
	background: #FFF1A2;
}

ul.empr_subtabs{
	padding:0;
	list-style:none;
    clear:right;
    padding-top: 40px;
    margin-left: -25px;
}

ul.empr_subtabs li{
	margin-right: 5px;
	margin-bottom: 15px;
	display:inline-block;
}

 ul.empr_subtabs li a{
	text-decoration:none;
	height:17px;
	background-color: #FFF8D1;
    border: 2px solid #FE9D43;
    padding-top: 3px;
    padding-bottom: 4px;
    padding-left: 4px;
    padding-right: 4px;
}

#fiche-empr,#empr-all, #empr-late, #empr-old, #empr-resa, #empr-dsi, #empr-sugg, #empr-list, #empr-dema {
	padding:5px 12px 15px 12px;
} 

#empr-list #onglets_list #div_mylist #list_cadre {
	border: none !important;
}

#empr-list #onglets_list ul.list_tabs li {
	border:1px solid #7686D2;
	margin:0 2px;
	display:inline-block;
}

#empr-list #onglets_list ul.list_tabs li a {
	text-decoration: none;
}

.authorities{
	background : #A8A8A8;
}

.vignetteimg {
  max-width: 140px;
  max-height: 200px;
  width: expression(this.width > 140 ? "140px" : true);
  height: expression(this.height > 200 ? "200px" : true);
}

#search_onglet ul.search_tabs li.current {
	background-color: #FFF1A2;
    border-bottom: 1px solid #FFF1A2;
    height: 18px;
    margin-bottom: 4px;
    padding: 3px 6px 0;	
}

#search_onglet ul.search_tabs li.current a:hover, #search_onglet ul.search_tabs li.current:hover a {
	background-color: #FFF1A2 !important;
}
	

/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                               Liens Sociaux                                */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/


table td div.addthis_toolbox {
	margin-bottom: 10px;
}

a.addthis_button_facebook_like iframe {
	height: 20px !important;
    width: 60px !important;
}

a.addthis_button_tweet iframe {
    width: 105px !important;
}


/* -----------------------------------------------------*/
/*                 Liste p�riodiques                    */
/* -----------------------------------------------------*/


#perio_a2z {
	margin-bottom: 5px;
	margin-top: 5px;
	background-color: #FFF8D1;
    border: 2px solid #FE9D43;
    padding: 5px;
}

#perio_a2z #perio_a2z_search {
	margin-top: 10px;
	margin-bottom: 10px;
	width :	50%;
}

#perio_a2z .onglets_isbd_public {
	margin-bottom: 0px;	
}

table.a2z_contens {
	margin-top: 10px;
}

table.a2z_perio_list {
	width: 250px;
}

table.a2z_perio_list tr td {
	border-bottom: 2px solid #c4bd14;
	padding-bottom: 3px;
}

#a2z_perio b .header_title {
	font-size: 16px;
	text-transform: uppercase;
}

#a2z_perio .notice-child h3 span {
    padding-left: 0px;
    background-color: inherit;
    color: #451414;
}

#a2z_perio .navbar {
	margin-top: 10px;
}

input#a2z_abt_actif {
	vertical-align: middle;
	margin-left: 2px;
	margin-right: 2px;
}


