/* +--------------------------------------------------------------------------+
// 2011 PMB Services / www.sigb.net pmb@sigb.net et contributeurs (voir www.sigb.net)
// +-------------------------------------------------+
// $Id: pmb35.css,v 1.19 2012-05-16 07:55:20 trenon Exp $ */


/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                         ATTRIBUTS GENERAUX                                 */
/*                                                                            */
/*                     attrbitus generaux de la page                          */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/

* {
	margin: 0px;
	padding: 0px;
}

body { 
	font-family : Arial, Verdana, Helvetica, sans-serif;
	font-size : 11px;
	color: #000000;
}

body#pmbopac { 
	background-color: #9b827d;
	background-repeat: no-repeat;
    background-position: top left;
    background-image: url('images/coin_gauche.jpg');
}

#container {
	background-repeat: repeat-x;
	background-image: url('images/fond_haut.jpg');
	background-position: top left;
	background-color: #ffffff;
	position: relative;
	min-width: 970px;
}


/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                                  IFRAME                                    */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/


/* -----------------------------------------------------*/
/*                         Panier                       */
/* -----------------------------------------------------*/


iframe#iframe_resume_panier {
	width: 70%;
	height: 35px;
	border: none;
}

body.cart_info_body {
	background-color: transparent;
	font-size: 13px;
}

.img_basket img {
}

#cart_info_iframe_content a {
	font-weight: bold;
}

#cart_action {
	margin-bottom: 15px;
}


/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                            Intro_bibli                                     */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/


#intro {
	height: 100%;
    left: 0px;
    position: absolute;
    top: 0px;
    width: 254px;
    background-position: top left;
	background-repeat: repeat-y;
	background-image: url('images/fond_gauche.jpg');
}

#intro #intro_bibli {
	padding-left: 56px;
	background-repeat: no-repeat;;
	background-image: url('images/coin_gauche.jpg');
	background-position: left top;
}

#intro #intro_bibli h3 {
	display: none;
}


/* -----------------------------------------------------*/
/*                 biblio_preamble_p1                   */
/* -----------------------------------------------------*/



#intro #intro_bibli .p1 {
	background-image: url("images/fond_haut.jpg");
    background-position: left top;
    background-repeat: repeat-x;
    padding-top: 40px;
}


/* -----------------------------------------------------*/
/*                 biblio_preamble_p2                   */
/* -----------------------------------------------------*/


#intro #intro_bibli .p2 {
	margin-top: 15px;
}

#intro #intro_bibli .p2 h3 {
	display: block;
	background-color: #D6DE39;
    border-left: 12px solid #2C2E8C;
    color: #2C2E8C;
    padding-bottom: 2px;
    padding-left: 10px;
    padding-top: 2px;
}

#intro #intro_bibli .p2 ul li {
	background-color: #d0dae8;
    padding-bottom: 3px;
    padding-left: 20px;
    padding-right: 15px;
    padding-top: 3px;
    margin-top: 2px;
}

#intro #intro_bibli .p2 ul li a {
	text-decoration: none;
	font-size: 13px;
    color: #2c2e8c;
    font-weight: bold;
}

#intro #intro_bibli .p2 ul li:hover {
	background-color: #e3eaf1;
    padding-left: 25px;
}

#intro #intro_bibli .p2 ul li a:hover {
	color: #3f4198;
}

#intro #intro_bibli .p2 #recherche_plus {
	margin-left: 15px;
    margin-right: 15px;
    margin-top: 20px;
    text-align: justify;
}

#intro #intro_bibli .p2 #recherche_plus em {
	font-weight: bold;
}

#intro #intro_bibli .p2 #recherche_plus form {
	margin-top: 5px;
}

#intro #intro_bibli .p2 #recherche_plus form input.text_query {
	width: 95px;
}


/*-------------------------------------------------------------------------
---------------------------------------------------------------------------
                            Contenu du Bandeau                              
---------------------------------------------------------------------------
-------------------------------------------------------------------------*/
 
 #bandeau { 
	background-image: url("images/coin_droit.jpg");
    background-position: right top;
    background-repeat: no-repeat;
    padding-top: 8px;
    position: absolute;
    right: 0;
    top: 0;
    width: 295px;
    height: 40px;
}


/* -----------------------------------------------------*/
/*                        Accueil                       */
/* -----------------------------------------------------*/


#bandeau #accueil h3 {
	display: none;
}

#bandeau #accueil p.centered {
	display: none;
}


/* ------------lang_select------------*/


#bandeau #accueil #lang_select {
	text-align: right;
    width: 250px;
}

#bandeau #accueil #lang_select h3 {
	display: block;
	color: #ffffff;
	font-size: 13px;
	float: left;
}


/* -----------------------------------------------------*/
/*                      Connexion                       */
/* -----------------------------------------------------*/


#bandeau #connexion {
	position: absolute;
    top: 85px;
    left: 90px;
}

#connexion h3 {
	color: #2c2e8c;
	font-size: 13px;
}

#connexion #login_form form label, #connexion #login_form form br {
	display: none;
}

#connexion #login_form b {
	font-size: 16px;
	color: #ffffff;
}	

/*---------------Input---------------*/


#connexion #login_form input.login, #connexion #login_form input.password {
	width: 110px;
	margin-top: 5px;
	margin-bottom: 5px;
}

#connexion #login_form input.bouton {
    text-transform: uppercase;
}


/* -----------------------------------------------------*/
/*                       Adresse                        */
/* -----------------------------------------------------*/


#adresse {
	display: none;
}


/* -----------------------------------------------------*/
/*                 biblio_post_adress                   */
/* -----------------------------------------------------*/


#post_adress {
	display: none;
}


/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                            Contenu du Main                                 */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/


#main {
	margin-left: 254px;
	padding-right: 40px;
	padding-top: 45px;
	background-repeat: repeat-y;
	background-image: url('images/fond_droit.jpg');
	background-position: right top;
}

#main #main_hors_footer {
	margin-left: 25px;
	margin-right: 25px;
	padding-bottom: 25px;
	min-height: 510px;
	height: auto !important;
	height: 510px;
}

#main #main_hors_footer hr {
	display: none;
}


/* ---------------------------------------------------------------------------*/
/*                                Main_header                                 */
/* ---------------------------------------------------------------------------*/


#main_header {
	position: relative;
}

#menuDeroulant {
    position: absolute;
    right: 10px;
    z-index: 10;
}

#menuDeroulant li {
    border: 0px;
    float: left;
    font-size: 16px;
    margin-left: 30px;
}

#menuDeroulant li a:link, #menuDeroulant li a:visited {
    display: block;
    padding: 4px 8px;
}

#menuDeroulant .sousMenu {
    border: 0px;
    display: none;
    width: 185px;
}

#menuDeroulant .sousMenu li {
    border: 1px solid transparent;
    float: none;
    width: 100%;
    margin-left: 0px;
    font-size: 14px;
    opacity: 0.9;
    -o-box-shadow: 1px 1px 3px #333333;
    -moz-box-shadow: 1px 1px 3px #333333;
    -webkit-box-shadow: 1px 1px 3px #333333;
    box-shadow: 1px 1px 3px #333333;
}

#menuDeroulant .sousMenu li a:link, #menuDeroulant .sousMenu li a:visited {
    background-color: #D0DAE8;
    border: 0px;
    color: #2C2E8C;
    display: block;
    text-decoration: none;
}

#menuDeroulant .sousMenu li a:hover {
    background-color: #E3eaf1;
    padding-left: 15px;
}

#menuDeroulant li:hover > .sousMenu {
    display: block;
}

#main_header #bandeau_vert {
	background-repeat: repeat-x;
	background-image: url("images/fond_bandeau.jpg");
	background-position: left bottom;
	height: 155px;
	padding-top: 30px;
	color: #2C2E8C;
}

#main_header #bandeau_vert span {
    font-size: 32px;
    margin-left: 70px;
	top: 47px;
	position: relative;
}


/* -----------------------------------------------------*/
/*                     Intro_message                    */
/* -----------------------------------------------------*/


#intro_message {
	margin-bottom: 20px;
}

#intro_message .p1 a img {
	vertical-align: top;
}


/* -----------------------------------------------------*/
/*                        Navigator                     */
/* -----------------------------------------------------*/


#navigator {
	margin-bottom: 20px;
	width: 70%;
}

#navigator table {
	margin-top: 10px;
	width: auto;
}

#navigator td a {
	padding-left: 10px;
	padding-right: 10px;
	padding-top: 3px;
	padding-bottom: 3px;
	margin-right: 15px;
	border: 1px solid #a8cee6;
	background-color: #d5e4ee;
	background-image: url('images/btn.jpg');
	background-repeat: repeat-x;
	cursor: pointer;
	text-decoration: none;
	display: block;
	
	/*--CSS3--*/
	-webktit-border-radius: 3px;
	-moz-border-radius: 3px;
	border-radius: 3px;
	-webkit-transition: all 0.5s ease;   
    -moz-transition: all 0.5s ease;
    -o-transition: all 0.5s ease;
    transition: all 0.5s ease;
}

#navigator td a:hover {
	border: 1px solid #277c9f;
}


/* -----------------------------------------------------*/
/*                        Search                        */
/* -----------------------------------------------------*/


#search_block {
    margin-top: 10px;
}

#search_block h3 {
    background-color: #D6DE39;
    border-left: 12px solid #2C2E8C;
    color: #2C2E8C;
    padding-bottom: 2px;
    padding-left: 10px;
    padding-top: 2px;
}

#search {
    margin-top: 15px;
    padding-bottom: 35px;
}
	
#main #search ul.search_tabs, #onglets_list ul.list_tabs {
    font-size: 14px;
    border-bottom: 6px solid #D6DE39;
    padding-bottom: 28px;
}

#main #search ul.search_tabs li, #onglets_list ul.list_tabs li, #empr_onglet ul.empr_tabs li {
	padding-left: 10px;
	padding-right: 10px;
	padding-top: 3px;
	padding-bottom: 3px;
	margin-right: 5px;
	border: 1px solid #a8cee6;
	background-color: #e2ebf0;
	background-image: url('images/btn.jpg');
	background-repeat: repeat-x;
	cursor: pointer;
	display: block;
	float: left;
	
	/*--CSS3--*/
	-webktit-border-radius: 3px;
	-moz-border-radius: 3px;
	border-radius: 3px;
	-webkit-transition: all 0.5s ease;   
    -moz-transition: all 0.5s ease;
    -o-transition: all 0.5s ease;
    transition: all 0.5s ease;
}

#main #search ul.search_tabs li:hover, #onglets_list ul.list_tabs li:hover, #empr_onglet ul.empr_tabs li:hover {
    border: 1px solid #277c9f;
}

#main #search ul.search_tabs li#current, #onglets_list ul.list_tabs li#current,
#empr_onglet ul.empr_tabs li#current {
	border: 1px solid #277c9f;
}

#main #search ul.search_tabs li a, #onglets_list ul.list_tabs li a, #empr_onglet ul.empr_tabs li a {
	text-decoration:none;
	color: #333333;
}

#search #search_crl {
	clear: left;
}

#search p.p1 {
	margin: 0px;
	padding-top: 5px;
	clear: left;
}

#search form {
	margin-top: 10px;
}

#search form select {
	margin-right: 10px;
	margin-bottom: 10px;
}

#search form input.text_query {
	width: 437px;
}

#search form #simple_search_zone {
	margin-top: 10px;
}

#search #zsimplesChild {
	margin-bottom: 0px!important;
    padding-bottom: 0px;
    padding-left: 0px;
    padding-top: 5px;
	-moz-box-shadow: inherit;
    -webkit-box-shadow: inherit;
    -o-box-shadow: inherit;
    box-shadow: inherit;
}

#search .notice-parent {
	margin-top: 15px;
}

#search .notice-child {
	margin-bottom: 0px!important;
    padding-bottom: 0px;
    padding-left: 0px;
    padding-top: 0px;
	-moz-box-shadow: inherit;
    -webkit-box-shadow: inherit;
    -o-box-shadow: inherit;
    box-shadow: inherit;
}

#search .notice-child img {
	vertical-align: inherit;
}

.search_result .notice-parent img {
	vertical-align: top;
}


/*-----Recherche par termes-----*/


#search .form- .form-contenu {
	padding-top: 20px;
}

iframe.frame_term_search {
	border: 1px solid #963F4D !important;
}


/*---Recherche multi-critères---*/


.ext_search_txt {
	width: 260px;
}

#external_simple_search_zone {
	margin-top:15px;
}

#search .form-contenu table td span.search_cancel input.bouton {
    margin-bottom: 10px;
    margin-top: -9px;
}


/*-----Onglets de Recherche-----*/


#search_onglet {
	margin-top: 10px;
	margin-bottom: 20px;
}

#search_onglet ul.search_tabs {
	padding-bottom: 25px;
	border-bottom : 6px solid #D6DE39;;
}

#search_onglet ul.search_tabs li {
	padding-left: 10px;
	padding-right: 10px;
	padding-top: 3px;
	padding-bottom: 3px;
	margin-right: 5px;
	border: 1px solid #a8cee6;
	background-color: #e2ebf0;
	background-image: url('images/btn.jpg');
	background-repeat: repeat-x;
	cursor: pointer;
	display: block;
	float: left;
	
	/*--CSS3--*/
	-webktit-border-radius: 3px;
	-moz-border-radius: 3px;
	border-radius: 3px;
	-webkit-transition: all 0.5s ease;   
    -moz-transition: all 0.5s ease;
    -o-transition: all 0.5s ease;
    transition: all 0.5s ease;
}

#search_onglet ul.search_tabs li:hover {
	border: 1px solid #277C9F;
}

#search_onglet ul.search_tabs li a {
	text-decoration: none;
}

#search_onglet ul.search_tabs li.current {
	border: 1px solid #277C9F;
}

#search_onglet ul.search_tabs li.current a {
	color: #000000;
}

#resultatrech {
	width: 70%;
}

#resultatrech h3 {	
	clear: both;
}

#resultatrech_liste {
	margin-top: 10px;
}

#resultatrech_see h3 {
	margin-bottom: 10px;
	margin-top: 15px;
}

#resultatrech_liste blockquote {
	margin-top: 20px;
}

#form_values_block {
  clear: both;
  display: block;  
}


/* -----------------------------------------------------*/
/*                 Liste périodiques                    */
/* -----------------------------------------------------*/


#perio_a2z {
	margin-bottom: 20px
}

#perio_a2z h3 {
	color: #2c2e8c;
	background-color: #d6de39;
	padding-bottom: 2px;
    padding-left: 10px;
    padding-top: 2px;
	border-left: 12px solid #2c2e8c;
}

#perio_a2z #perio_a2z_search {
	margin-top: 5px;
	margin-bottom: 10px;
	width: 50%;
}
	
table.a2z_contens {
	margin-top: 10px;
}

table.a2z_contens td {
	vertical-align: top;
}

table.a2z_perio_list {
	width: 220px;
	margin-right: 10px;
}

table.a2z_perio_list tr td {
    padding-bottom: 3px;
    padding-top: 2px;
    border-bottom: 1px solid #D7D7D7;
}

#a2z_perio b .header_title {
	font-size: 16px;
	text-transform: uppercase;
}

#a2z_perio .navbar {
	margin-top: 10px;
}

input#a2z_abt_actif {
	vertical-align: middle;
	margin-left: 2px;
	margin-right: 2px;
}

#form_search_bull form {
	margin-top: 10px;
}

#form_search_bull form table td {
	vertical-align: middle;
}


/* -----------------------------------------------------*/
/*                       Categories                     */
/* -----------------------------------------------------*/


#categories {
}

#categories h3 {
	color: #2c2e8c;
	background-color: #d6de39;
	padding-bottom: 2px;
    padding-left: 10px;
    padding-top: 2px;
	border-left: 12px solid #2c2e8c;
}

#categories ul.search_tabs {
	width: 165px;
	margin-top: 15px;
	float: left;
}

#categories ul.search_tabs li {
	padding-top: 3px;
	padding-bottom: 3px;
	padding-left: 10px;
	padding-right: 10px;
	background-color: #D0DAE8;
    display: block;
    margin-bottom: 2px;
    font-size: 12px;
    font-weight: bold;
}

#categories ul.search_tabs li:hover {
	background-color: #e3eaf1;
}

#categories ul.search_tabs li a {
	text-decoration: none;
	color: #2C2E8C;
}

#categories ul.search_tabs li a:hover {
	padding-left: 5px;
}

#categories ul.search_tabs li#current {
	background-color: #e3eaf1;
    color: #3f4198;
}

#categories-container {
    padding-top: 15px;
    padding-bottom: 15px;
    padding-right: 40px;
    margin-bottom: 10px;
    margin-left: 170px;
}

#categories-container h2 {
	font-size:13px;
}

#categories-container h2 a {
}

#categories-container h2 img {
	vertical-align: baseline;
	margin-right: 5px;
}
		
#categories-container ul {
	margin-top: 2px;
	padding-bottom: 10px;
	margin-bottom: 10px;
	border-bottom: 1px solid #d7d7d7;
}

#categories-container li  {
	display: inline;
}

#aut_see {
   	margin-top: 10px;
}


/* -----------------------------------------------------*/
/*                    Localisations                     */
/* -----------------------------------------------------*/


#location {
	margin-bottom: 45px;
	clear: left;
}

#location h3 {
	color: #2c2e8c;
	background-color: #d6de39;
	padding-bottom: 2px;
    padding-left: 10px;
    padding-top: 2px;
	border-left: 12px solid #2c2e8c;
}

#location-container {
    padding-left: 15px;
    padding-bottom: 10px;
    padding-right: 15px;
    padding-top: 10px;
}


/* -----------------------------------------------------*/
/*               Dernieres Acquisitions                 */
/* -----------------------------------------------------*/


#last_entries {
    margin-top: 30px;
    padding-bottom: 15px;
    padding-left: 27px;
    padding-right: 15px;
}

#last_entries h3 {
	margin-bottom: 10px;
	margin-left: -27px;
	color: #2c2e8c;
	background-color: #d6de39;
	padding-bottom: 2px;
    padding-left: 10px;
    padding-top: 2px;
	border-left: 12px solid #2c2e8c;	
}

#last_entries h3 span {
}

#last_entries .notice-child h3 {
	margin-top: 5px;
	margin-bottom: 0px;
	margin-left: 0px;
	background-color: inherit;
}

#last_entries .notice-child h3 span {
	padding: 0px;
    background-image: none;
}


/* -----------------------------------------------------*/
/*                        Etageres                      */
/* -----------------------------------------------------*/


#etageres {
	margin-top: 35px;
}

#etageres h3 {
	color: #2c2e8c;
	background-color: #d6de39;
	padding-bottom: 2px;
    padding-left: 10px;
    padding-top: 2px;
	border-left: 12px solid #2c2e8c;
}

#etagere-container {
    padding-left: 0px;
    padding-bottom: 5px;
    padding-right: 0px;
    padding-top: 15px;
}

.etagere {
    margin-bottom: 15px;
}

#etagere-titre {
    background-color: #d5dcea;
    padding-left: 5px;
    padding-bottom: 2px;
    padding-right: 5px;
    padding-top: 2px;
}

#etagere-container #etagere-titre h1 {
	font-size: 15px;
}

#etagere-container #etagere-titre h1 a {
	color: #2c2e8c;
}

#etagere-container #etagere-comment {
	margin-bottom: 10px;
}

#etagere-container #etagere-comment h2 {
	text-align: right;
	font-style: italic;
	font-size: 12px;
	color: #333333;
	padding-right: 10px;
}

#etagere-notice-list {
	margin-left: 20px;
	margin-bottom: 20px;
}


/* -----------------------------------------------------*/
/*                        Footer                        */
/* -----------------------------------------------------*/


#footer {
	left: 0;
    margin-bottom: 0;
    margin-left: 0;
    background-repeat: repeat-x;
    background-image: url("images/footer.jpg");
    position: absolute;
    text-align: center;
    width: 100%;
    padding-top: 10px;
	padding-bottom: 10px;
	z-index: 10;
}

#footer a {
    margin-right: 10px;
	margin-left: 10px;
	color: #ffffff;
}

#footer #footer_gauche {
    top: 0px;
    left: 0px;
    position: absolute;
    z-index: -1;
}

#footer #footer_droit {
    top: 0px;
    right: 0px;
    position: absolute;
    z-index: -1;
}
	

/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                                  Infopages                                 */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/


/*-----infopage recherche id_top-----*/


#infopage_recherche h3 {
	background-color: #D6DE39;
    border-left: 12px solid #2C2E8C;
    color: #2C2E8C;
    padding-bottom: 2px;
    padding-left: 10px;
    padding-top: 2px;
}


/*-----infopage actualités-----*/


#actualites .bloc_actu {
	margin-top: 20px;	
}

#actualites .bloc_actu h3 {
	background-color: #D6DE39;
    border-left: 12px solid #2C2E8C;
    color: #2C2E8C;
    padding-bottom: 2px;
    padding-left: 10px;
    padding-top: 2px;
    margin-bottom: 10px;
}

#actualites .bloc_actu table td {
	vertical-align: top;
}

#actualites .bloc_actu table td img {
	max-width: 200px;
	max-height: 220px;
	width: expression(this.width > 200 ? "200px" : true);
	height: expression(this.height > 220 ? "220px" : true);
}


/*-----infopage reglement-----*/

#reglement h3 {
	background-color: #D6DE39;
    border-left: 12px solid #2C2E8C;
    color: #2C2E8C;
    padding-bottom: 2px;
    padding-left: 10px;
    padding-top: 2px;
    margin-bottom: 10px;
    margin-top: 20px;
}


/*-----infopage horaires-----*/

#horaires table {
    margin-bottom: 10px;
    border-collapse: separate;
}

#horaires table td {
    margin-bottom: 10px;
    padding: 2px;
}


/*-----infopage animation-----*/


#animation .animation_container {
	margin-top: 20px;
}

#animation .animation_container table td {
	vertical-align: top;
}

#animation .animation_container table td img {
	max-width: 300px;
	max-height: 260px;
	width: expression(this.width > 300 ? "300px" : true);
	height: expression(this.height > 260 ? "260px" : true);
}


/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                                 Facettes                                   */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/


#facette {
	position: absolute;
	width: 190px;
	top: 240px;
	right: 55px;
}

#facette h3 {
	margin-bottom: 5px;
}

#facette_list th {
	border-left: 8px solid #2C2E8C;
    color: #2C2E8C;
    font-weight: bold;
    text-transform: uppercase;
    text-decoration: none !important;
}

#facette_list td {
	padding-left: 2px;
	padding-right: 0px;
	padding-top: 2px;
	padding-bottom: 2px;
	border-bottom: 1px solid #D7D7D7;
}

#active_facette tr.surbrillance {
    text-decoration: underline;
}

#active_facette td {
    padding-left: 2px;
	padding-right: 2px;
	padding-top: 2px;
	padding-bottom: 2px;
}


/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                           Carroussel bulletin                              */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/


.carroussel_bulletin {
	text-align : center;
	border: 1px solid #963F4D;
}

.carroussel_bulletin img {
	border: none;
}

.carroussel_bulletin .active {
	background-color : #d0c6b4;
}

.carroussel_bulletin .active a {
	color: #ffffff;
	cursor : pointer;
	border: 1px solid #963F4D;
}

.carroussel_bulletin .current_bull_carroussel {
	font-weight : bold;
	border: 1px solid #963F4D;
	background-color : #d0c6b4;
}


/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                         Balises HTML de base                               */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/


a {
	text-decoration: none;
	color: #333333;
	/*--CSS3--*/
	-webkit-transition: all 0.5s ease;   
    -moz-transition: all 0.5s ease;
    -o-transition: all 0.5s ease;
    transition: all 0.5s ease;
}

a:hover {
	text-decoration: underline;
	color: #313234;
}

blockquote {
	margin-top: 10px;
	margin-bottom: 20px;
	margin-left: 6px;
	margin-right: 6px;
}

ul {
	margin-top: 0px;
	margin-bottom: 0px;
	margin-left: 0px;
	list-style: none;
	padding-left: 0px;
}

li {
	/*--CSS3--*/
	-webkit-transition: all 0.5s ease;   
    -moz-transition: all 0.5s ease;
    -o-transition: all 0.5s ease;
    transition: all 0.5s ease;
}

img {
	border: none;
	/*--CSS3--*/
	-webkit-transition: all 0.5s ease;   
    -moz-transition: all 0.5s ease;
    -o-transition: all 0.5s ease;
    transition: all 0.5s ease;
}

.row {
	clear: both;	
}

input[type=checkbox] {
	border: none;
}

input, textarea, select {
	border: 1px solid #343691;
}

select {
	-webktit-border-top-left-radius: 3px;
	-webktit-border-bottom-left-radius: 3px;
	-moz-border-radius-topleft: 3px;
	-moz-border-radius-bottomleft: 3px;
	border-top-left-radius: 3px;
	border-bottom-left-radius: 3px;
}

input, textarea {
	padding: 1px;
	-webktit-border-radius: 3px;
	-moz-border-radius: 3px;
	border-radius: 3px;
}

input.bouton, input.boutonrechercher {
	color: #333333;
	padding-left: 2px;
	padding-right: 2px;
	padding-top: 1px;
	padding-bottom: 1px;
	border: 1px solid #a8cee6;
	background-color: #e2ebf0;
	background-image: url('images/btn.jpg');
	background-repeat: repeat-x;
	cursor: pointer;
	
	/*--CSS3--*/
	-webktit-border-radius: 3px;
	-moz-border-radius: 3px;
	border-radius: 3px;
	-webkit-transition: all 0.5s ease;   
    -moz-transition: all 0.5s ease;
    -o-transition: all 0.5s ease;
    transition: all 0.5s ease;
}

input.bouton:hover, input.boutonrechercher:hover {
	border: 1px solid #287c9f;
}

input.bouton:disabled, input.bouton:disabled:hover {
	color: #aaaaaa;
	border: 1px solid #a8cee6;
}

h1 {
	color: #2C2E8C;
	font-size: 20px;
}

h2 {
	font-size: 18px;
	color: #2C2E8C;
}

h3 {
	font-size: 16px;
	color: #2c2e8c;
}


/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                                   Tableaux                                 */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/


table {
	border-collapse: collapse;
	width: 100%;
}

.exemplaires { 
	border-collapse: separate;
	clear: both;
}

th {
	text-align: left ;
	padding-left: 5px;
	padding-right: 5px;
	padding-top: 2px;
	padding-bottom: 2px;
	background-color: #D6DE39;
}

tr.even {
	background-color: #ffffff;
}

tr.odd {
	background-color: #E3EAF1;
}

tr.surbrillance {
	background-color: #D6DE39;
}


td {
	vertical-align: top;
}


/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                              Page Inscription                              */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/


#websubscribe h1 {
	font-size: 16px;
	margin-bottom: 5px;
}

#websubscribe #subs_form table td h4 {
	margin: 0px;
}

#websubscribe #subs_form table td h4 {
	margin: 0px;
}

#websubscribe #subs_form table td input.subsform {
	width: 195px;
	background-color: #ffffff;
}


/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                  Mise en forme de la fiche emprunteur	                  */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/


#empr_onglet ul.empr_tabs {
	list-style:none;
	font-size:14px;
	height: 30px;
	margin-top: 0px;
	margin-left: 0px;
	margin-bottom: 10px;
	border-bottom: 6px solid #D6DE39;
}

ul.empr_subtabs li {
    padding-top: 3px;
    padding-bottom: 3px;
    padding-left: 10px;
    padding-right: 10px;
    background-color: #D0DAE8;
    -moz-border-radius: 3px;
    -webkit-border-radius: 3px;
    border-radius: 3px;
    margin-bottom: 2px;
    font-size: 12px;
    font-weight: bold;
}

ul.empr_subtabs li a {
    color: #2C2E8C;
}

ul.empr_subtabs li:hover {
	background-color: #e3eaf1;
}

ul.empr_subtabs li a {
	text-decoration:none;
}

#fiche-empr,#empr-all, #empr-late, #empr-old, #empr-resa, #empr-dsi, #empr-sugg,
#empr-list, #empr-dema {
	margin-top: 25px;
} 

#list_cadre {
	border: none !important;
	padding-top: 15px !important;
	overflow: visible ! important;
	height: auto ! important;
}

#list_cadre img {
	vertical-align: bottom;
}

#empr-list #onglets_list {
	margin-top: 10px;
}

#onglets_list ul.list_tabs {
	margin-left: 0px;
}

.form_liste_lecture .form-contenu .row .colonne2 .row textarea {
	max-width: 290px;	
}

#fiche-empr #fiche-empr-container table tr td {
    padding-bottom: 3px;
    padding-left: 5px;
    padding-right: 5px;
}

#empr-sugg #make_sugg #make_sugg-container table tr td {
    padding-bottom: 3px;
    padding-left: 5px;
    padding-right: 5px;
    vertical-align: middle;
}

#empr-sugg #make_sugg #make_sugg-container table tr td textarea {
    max-width: 550px;
    min-width: 300px;
}


/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                               Notices affichage                            */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/


.bg-grey {
	padding-right: 0.2em;
	width: 150px;
	color: #2c2e8c;
	background-image: url("images/bg_grey.jpg");
	background-repeat: repeat-y;
}

td-spacer {
	padding-right: 0.2em;
	width: 150px;
	color: #2c2e8c;
	background-image: url("images/bg_grey.jpg");
	background-repeat: repeat-y;
}

#resultatrech_liste tbody tr td table, #resultatrech_liste tbody {
	padding-top:5px;
}

.notice-heada {
    font-size: 12px;
}

.header_title {
    font-weight: bold;
}

.notice-parent {
    margin-bottom: 5px;
}

.notice-parent img {
	vertical-align: bottom;
}

.notice-parent .img_plus {
	margin-right: 5px;
}

.notice-child {
    margin-left: 15px;
    text-align: justify;
    margin-bottom: 20px!important;
    padding-left: 5px;
    padding-bottom: 5px;
    padding-top: 5px;
    -moz-box-shadow: -2px 2px 2px #cccccc;
    -webkit-box-shadow: -2px 2px 2px #cccccc;
    -o-box-shadow: -2px 2px 2px #cccccc;
    box-shadow: -2px 2px 2px #cccccc;
}

.notice-child h3, #notice .parent h3 {
    margin-top: 10px;
    font-size: 13px!important;
    background-color: inherit !important;
    padding-top: 0px !important;
    padding-bottom: 0px !important;
    padding-left: 5px !important;
    border-left: 12px solid #2C2E8C;
    margin-top: 8px !important;
}

.notice-child a#bt_resa, #notice a#bt_resa {
    margin-left: 18px;
}

.notice-child table td div table td a {
    text-decoration: underline;
}

.notice-child table td div table tr td, #notice .parent table tr td {
    padding-bottom: 3px;
    padding-left: 5px;
    padding-right: 5px;
    padding-right: 5px;
}

.notice-child table.exemplaires td a {
    text-decoration: underline;
}

.vignetteimg {
	max-width: 200px;
	max-height: 285px;
	width: expression(this.width > 200 ? "200px" : true);
	height: expression(this.height > 285 ? "285px" : true);
	margin-top: 60px;
	margin-left: 20px;
	-moz-box-shadow: 0px 0px 3px #333333;
	-webkit-box-shadow: 0px 0px 3px #333333;
	box-shadow: 0px 0px 3px #333333;
}

.child {
    margin-left: 25px;
    padding-left: 4px;
    padding-right: 4px;
    text-align: justify;
    border-bottom-style: solid;
    border-bottom-width: 1px;
    border-bottom-color: #c0c0c0;
    border-left-style: solid;
    border-left-width: 1px;
    border-left-color: #c0c0c0;
    border-right-style: none;
    border-top-style: none;
}

.liste_bulletins {
    padding-left: 3px;
    padding-right: 3px;
}

.notice-global-photo {
    float:left;
    min-height:230px;
    width:280px;
    background-color:#f7f7f7;
    -moz-border-radius:8px;
    margin:4px;
    padding:4px;
    valign:bottom;
    display: table-cell;
    vertical-align: bottom;
}

.notice-global-nophoto {
    float:left;
    min-height:230px;
    width:280px;
    background-color:#f7f7f7;
    -moz-border-radius:8px;
    margin:4px;
    padding:4px;
}

.notice-global-nophoto .child,
.notice-global-photo .child {
    font-family: arial, helvetica, geneva, sans-serif;
    padding-left: 4px;
    padding-right: 4px;
    text-align: justify;
    margin:0;
    padding:0;
    border:none;
}

.notice-global-photo A IMG {
    margin-top:10px;
    margin-bottom:10px;
}

.notice-global-photo .notice-child {
    font-family: arial, helvetica, geneva, sans-serif;
    padding-left: 4px;
    padding-right: 4px;
    text-align: justify;
    margin:0;
    padding:0;
    border:none;
}

#notice .parent h3 {
	margin-left: 3px;
}


/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                       Onglets de l'affichage public/ISBD                   */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/

ul.onglets_isbd_public {
    padding-bottom: 10px;
    margin-top: 10px;
}

ul.onglets_isbd_public li {
    display: inline;
    padding-top: 4px;
    padding-bottom: 4px;
    padding-left: 10px;
    padding-right: 10px;
    background-position: top left;
    background-repeat: repeat-x;
    background-image: url("images/btn.jpg");
    border: 1px solid #a4cce5;
    -moz-border-radius: 3px;
    -webkit-border-radius: 3px;
    border-radius: 3px;
    margin-right: 2px;
    display: block;
    float: left;
    height: 13px;
    margin-bottom: 5px;
}

ul.onglets_isbd_public li:hover {
    border: 1px solid #197399;
}

ul.onglets_isbd_public li img {
    padding-right: 2px;
}

ul.onglets_isbd_public a {
    text-decoration: none;
    cursor: pointer;
}


/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                                   Pop-up                                   */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/


#att #serialcirc_ask_copy {
	border: 2px solid #2C2E8C !important;
}

#titre-popup {
	font-size: 16px;
	font-weight: bold;
	margin-top: 10px;
	margin-bottom: 10px;
	margin-left: 10px;
}

form#f {
	margin-left: 10px;
}

.echelle_avis {
	padding: 7px;
}

.alerte {
	color: #ff0000;
	font-size:14px;
}


/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                               Liens Sociaux                                */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/


table td div.addthis_toolbox {
	margin-bottom: 10px;
}

a.addthis_button_facebook_like iframe {
	height: 20px !important;
    width: 60px !important;
}

a.addthis_button_tweet iframe {
    width: 105px !important;
}


/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/
/*                            CLASSES GENERIQUES                              */
/*                 divers pour les affichages simples de texte                */
/* ---------------------------------------------------------------------------*/
/* ---------------------------------------------------------------------------*/


.right, .right-50, .right-15, .right-85 {
	float: right;
}

.right-50 {
	width: 50%;
}

.right-15 {
	width: 15%;
}

.right-85 {
	width: 85%;
}

.right-clear-right, .right-50-clear-right {
	float: right;
	clear: right;
}

.left-clear-left, .left-50-clear-left {
	float: left;
	clear: left;
}

.left, .left-50, .left-15 {
	float: left;
}

.left-50 {
	width: 50%;
}

.left-15 {
	width: 15%;
}

.left-85 {
	width: 85%;
}

.spacer {
	clear: both;
	visibility: hidden;
	display: none;
	margin-bottom: -10px;
	margin-top: -10px;
}


/* Bannettes */
#bannette { 
	padding:5px;
	border: 1px solid #963F4D;
	margin-bottom: 10px;
}

.bannette-container { 
	margin-bottom: 20px;
}

.bannette-titre h1 {
	margin:0px;
	font-size:13px;
	font-weight:bold;
}

.bannette-titre h1 a {
	margin-right: 5px;
}

.text_search0 {
	background-color: yellow;
	text-decoration: underline;
}

.text_search1 {
	background-color: #dd9797;
	text-decoration: underline;
}

.text_search2 {
	background-color: #ddb397;
	text-decoration: underline;
}

.text_search3 {
	background-color: #cd97dd;
	text-decoration: underline;
}

.text_search4 {
	background-color: #97c2dd;
	text-decoration: underline;
}

.text_search5 {
	background-color: #97ddae;
	text-decoration: underline;
}

.etiq_champ {
	font-weight:bold;
}

/*Suggestion Multiple*/

.tab_sug{
	table-layout: fixed;
}

.tab_sug th, .tab_sug td{
	border:1px solid #CCCCCC;
	border-collapse:collapse;
	overflow:hidden;	
	vertical-align:center;
	text-align: center;
	width : 100%;
}

.tab_sug  input, .tab_sug textarea{
   width:95%;
   height:100%;
}
.tab_sug select{
	width:95%;
}

.erreur_saisie {
	background-color: #ff0000;
}

.categmouseout {
	border: solid 2px #555555;
	position: absolute;
	visibility:hidden;
	z-index: 2000;
}
.categmouseover {
	border: solid 2px #555555;
	position: absolute;
	visibility:visible;
	z-index: 2000;
	margin-top: 2px;
}

.listedescription {
	border: solid 2px #555555;
	position: absolute;
	visibility:hidden;
	z-index: 2000;
}

.authorities {
	background-color : #CBDB2A;
}

#history_action {
	margin-bottom: 20px;
}

